alias presentWeather1PresentTrend4=zero;
alias presentWeather2PresentTrend4=zero;
alias presentWeather3PresentTrend4=zero;
if (g is "NSW") {
		rename(g,nswTrend4);
		group g : dump; non_alpha na;

} else {

		if (is_in_list(g,"metar/present_weather.list")) {
				rename(g,presentWeather1Trend4);
				group g : dump; non_alpha na;
				alias presentWeather1PresentTrend4=one;
				if (is_in_list(g,"metar/present_weather.list")) {
						rename(g,presentWeather2Trend4);
						group g : dump; non_alpha na;
						alias presentWeather2PresentTrend4=one;
				}
				if (is_in_list(g,"metar/present_weather.list")) {
						rename(g,presentWeather3Trend4);
						group g : dump; non_alpha na;
						alias presentWeather3PresentTrend4=one;
				}
		}
		if (substr(g,0,1) is "-" || substr(g,0,1) is "+" || substr(g,0,2) is "FZ" || g is "//" ) {
				rename(g,wrongPresentWeatherTrend4);
				group g : dump; non_alpha na;
		}
		if (! presentWeather1PresentTrend4 && is_in_list(g,"metar/present_weather.list")) {
				rename(g,presentWeather1Trend4);
				group g : dump; non_alpha na;
				alias presentWeather1PresentTrend4=one;
		}
		if (!presentWeather2PresentTrend4 && is_in_list(g,"metar/present_weather.list")) {
						rename(g,presentWeather2Trend4);
						group g : dump; non_alpha na;
						alias presentWeather2PresentTrend4=one;
		}
		if (!presentWeather3PresentTrend4 && is_in_list(g,"metar/present_weather.list")) {
						rename(g,presentWeather3TrendTrend41);
						group g : dump; non_alpha na;
						alias presentWeather3PresentTrend4=one;
		}
}

