# (C) Copyright 2005- ECMWF.

#  Number of tens of thousands of years of offset
signed[2] numberOfTensOfThousandsOfYearsOfOffset = missing() : can_be_missing,dump,no_copy,edition_specific;
alias paleontologicalOffset=numberOfTensOfThousandsOfYearsOfOffset ;
