# Automatically generated by ./create_def.pl, do not edit
#Pressure (S) (not reduced)
'500000' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 1 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Pressure
'500001' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 1 ;
	}
#Pressure Reduced to MSL
'500002' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 2 ;
	 indicatorOfTypeOfLevel = 102 ;
	}
#Pressure Tendency (S)
'500003' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 3 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Geopotential (S)
'500004' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 6 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Geopotential (full lev)
'500005' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 6 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Geopotential
'500006' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 6 ;
	}
#Geometric Height of the earths surface above sea level
'500007' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 8 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Geometric Height of the layer limits above sea level(NN)
'500008' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 8 ;
	 indicatorOfTypeOfLevel = 109 ;
	}
#Total Column Integrated Ozone
'500009' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 10 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Temperature (G)
'500010' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 11 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#2m Temperature (AV)
'500012' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 11 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	 timeRangeIndicator = 3 ;
	}
#Climat. temperature, 2m Temperature
'500013' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 11 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	 timeRangeIndicator = 3 ;
	}
#Temperature
'500014' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 11 ;
	}
#Max 2m Temperature (i)
'500015' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 15 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	 timeRangeIndicator = 2 ;
	}
#Min 2m Temperature (i)
'500016' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 16 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	 timeRangeIndicator = 2 ;
	}
#2m Dew Point Temperature
'500017' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 17 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}
#2m Dew Point Temperature (AV)
'500018' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 17 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	 timeRangeIndicator = 3 ;
	}
#Radar spectra (1)
'500019' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 21 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Wave spectra (1)
'500020' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 28 ;
	}
#Wave spectra (2)
'500021' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 29 ;
	}
#Wave spectra (3)
'500022' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 30 ;
	}
#Wind Direction (DD_10M)
'500023' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 31 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	}
#Wind Direction (DD)
'500024' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 31 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Wind speed (SP_10M)
'500025' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 32 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	}
#Wind speed (SP)
'500026' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 32 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#U component of wind
'500027' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 33 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	}
#U component of wind
'500028' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 33 ;
	}
#V component of wind
'500029' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 34 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	}
#V component of wind
'500030' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 34 ;
	}
#Vertical Velocity (Pressure) ( omega=dp/dt )
'500031' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 39 ;
	}
#Vertical Velocity (Geometric) (w)
'500032' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 40 ;
	}
#Specific Humidity (S)
'500033' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 51 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Specific Humidity (2m)
'500034' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 51 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}
#Specific Humidity
'500035' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 51 ;
	}
#2m Relative Humidity
'500036' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 52 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}
#Relative Humidity
'500037' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 52 ;
	}
#Total column integrated water vapour
'500038' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 54 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Evaporation (s)
'500039' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 57 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 4 ;
	}
#Total Column-Integrated Cloud Ice
'500040' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 58 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Total Precipitation rate (S)
'500041' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 61 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 4 ;
	}
#Large-Scale Precipitation rate
'500042' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 62 ;
	 timeRangeIndicator = 4 ;
	}
#Convective Precipitation rate
'500043' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 63 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 4 ;
	}
#Snow depth water equivalent
'500044' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 65 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Snow Depth
'500045' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 66 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Total Cloud Cover
'500046' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 71 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Convective Cloud Cover
'500047' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 72 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Cloud Cover (800 hPa - Soil)
'500048' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 73 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Cloud Cover (400 - 800 hPa)
'500049' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 74 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Cloud Cover (0 - 400 hPa)
'500050' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 75 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Total Column-Integrated Cloud Water
'500051' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 76 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Convective Snowfall rate water equivalent (s)
'500052' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 78 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 4 ;
	}
#Large-Scale snowfall rate water equivalent (s)
'500053' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 79 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 4 ;
	}
#Land Cover (1=land, 0=sea)
'500054' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 81 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Surface Roughness length Surface Roughness
'500055' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 83 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Albedo (in short-wave)
'500056' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 84 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Albedo (in short-wave)
'500057' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 84 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}
#Soil Temperature  ( 36 cm depth, vv=0h)
'500058' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 85 ;
	 indicatorOfTypeOfLevel = 111 ;
	 level = 36 ;
	}
#Soil Temperature (41 cm depth)
'500059' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 85 ;
	 indicatorOfTypeOfLevel = 111 ;
	 level = 41 ;
	}
#Soil Temperature
'500060' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 85 ;
	 indicatorOfTypeOfLevel = 111 ;
	 level = 9 ;
	}
#Soil Temperature
'500061' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 85 ;
	 indicatorOfTypeOfLevel = 111 ;
	 level = 0 ;
	}
#Column-integrated Soil Moisture
'500062' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 86 ;
	 indicatorOfTypeOfLevel = 112 ;
	 bottomLevel = 190 ;
	 topLevel = 100 ;
	}
#Column-integrated Soil Moisture (1) 0 -10 cm
'500063' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 86 ;
	 indicatorOfTypeOfLevel = 112 ;
	 bottomLevel = 10 ;
	 topLevel = 0 ;
	}
#Column-integrated Soil Moisture (2) 10-100cm
'500064' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 86 ;
	 indicatorOfTypeOfLevel = 112 ;
	 bottomLevel = 100 ;
	 topLevel = 10 ;
	}
#Plant cover
'500065' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 87 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Water Runoff (10-100)
'500066' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 90 ;
	 indicatorOfTypeOfLevel = 112 ;
	 bottomLevel = 100 ;
	 topLevel = 10 ;
	 timeRangeIndicator = 4 ;
	}
#Water Runoff (10-190)
'500067' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 90 ;
	 indicatorOfTypeOfLevel = 112 ;
	 bottomLevel = 190 ;
	 topLevel = 10 ;
	 timeRangeIndicator = 4 ;
	}
#Water Runoff (s)
'500068' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 90 ;
	 indicatorOfTypeOfLevel = 112 ;
	 bottomLevel = 10 ;
	 topLevel = 0 ;
	 timeRangeIndicator = 4 ;
	}
#Sea Ice Cover ( 0= free, 1=cover)
'500069' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 91 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#sea Ice Thickness
'500070' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 92 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Significant height of combined wind waves and swell
'500071' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 100 ;
	}
#Direction of wind waves
'500072' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 101 ;
	}
#Significant height of wind waves
'500073' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 102 ;
	}
#Mean period of wind waves
'500074' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 103 ;
	}
#Direction of swell waves
'500075' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 104 ;
	}
#Significant height of swell waves
'500076' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 105 ;
	}
#Mean period of swell waves
'500077' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 106 ;
	}
#Net short wave radiation flux (m) (at the surface)
'500078' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 111 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}
#Net short wave radiation flux
'500079' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 111 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 0 ;
	}
#Net long wave radiation flux (m) (at the surface)
'500080' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 112 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}
#Net long wave radiation flux
'500081' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 112 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 0 ;
	}
#Net short wave radiation flux (m) (on the model top)
'500082' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 113 ;
	 indicatorOfTypeOfLevel = 8 ;
	 timeRangeIndicator = 3 ;
	}
#Net short wave radiation flux
'500083' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 113 ;
	 indicatorOfTypeOfLevel = 8 ;
	 timeRangeIndicator = 0 ;
	}
#Net long wave radiation flux (m) (on the model top)
'500084' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 114 ;
	 indicatorOfTypeOfLevel = 8 ;
	 timeRangeIndicator = 3 ;
	}
#Net long wave radiation flux
'500085' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 114 ;
	 indicatorOfTypeOfLevel = 8 ;
	 timeRangeIndicator = 0 ;
	}
#Latent Heat Net Flux (m)
'500086' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 121 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}
#Sensible Heat Net Flux (m)
'500087' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 122 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}
#Momentum Flux, U-Component (m)
'500088' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 124 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}
#Momentum Flux, V-Component (m)
'500089' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 125 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}
#Photosynthetically active radiation (m) (at the surface)
'500090' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 5 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}
#Photosynthetically active radiation
'500091' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 5 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 0 ;
	}
#Solar radiation heating rate
'500092' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 13 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Thermal radiation heating rate
'500093' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 14 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Latent heat flux from bare soil
'500094' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 18 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}
#Latent heat flux from plants
'500095' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 19 ;
	 indicatorOfTypeOfLevel = 111 ;
	 timeRangeIndicator = 3 ;
	}
#Sunshine
'500096' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 20 ;
	 timeRangeIndicator = 4 ;
	}
#Stomatal Resistance
'500097' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 21 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 0 ;
	}
#Cloud cover
'500098' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 29 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Non-Convective Cloud Cover, grid scale
'500099' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 30 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Cloud Mixing Ratio
'500100' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 31 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Cloud Ice Mixing Ratio
'500101' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 33 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Rain mixing ratio
'500102' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 35 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Snow mixing ratio
'500103' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 36 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Total column integrated rain
'500104' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 37 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Total column integrated snow
'500105' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 38 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Grauple
'500106' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 39 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Total column integrated grauple
'500107' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 40 ;
	}
#Total Column integrated water (all components incl. precipitation)
'500108' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 41 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#vertical integral of divergence of total water content (s)
'500109' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 42 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#subgrid scale cloud water
'500110' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 43 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#subgridscale cloud ice
'500111' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 44 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#cloud cover CH (0..8)
'500112' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 51 ;
	}
#cloud cover CM (0..8)
'500113' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 52 ;
	}
#cloud cover CL (0..8)
'500114' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 53 ;
	}
#cloud base above msl, shallow convection
'500115' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 58 ;
	 indicatorOfTypeOfLevel = 2 ;
	}
#cloud top above msl, shallow convection
'500116' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 59 ;
	 indicatorOfTypeOfLevel = 3 ;
	}
#specific cloud water content, convective cloud
'500117' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 61 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Height of Convective Cloud Base (i)
'500118' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 68 ;
	 indicatorOfTypeOfLevel = 2 ;
	}
#Height of Convective Cloud Top (i)
'500119' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 69 ;
	 indicatorOfTypeOfLevel = 3 ;
	}
#base index (vertical level) of main convective cloud (i)
'500120' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 72 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#top index (vertical level) of main convective cloud (i)
'500121' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 73 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Temperature tendency due to convection
'500122' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 74 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Specific humitiy tendency due to convection
'500123' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 75 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#zonal wind tendency due to convection
'500124' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 78 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#meridional wind tendency due to convection
'500125' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 79 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#height of top of dry convection
'500126' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 82 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#height of 0 degree celsius level code 0,3,6 ?
'500127' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 84 ;
	 indicatorOfTypeOfLevel = 4 ;
	}
#Height of snow fall limit
'500128' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 85 ;
	 indicatorOfTypeOfLevel = 4 ;
	}
#Tendency of specific cloud liquid water content due to conversion
'500129' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 88 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#tendency of  specific cloud ice content due to convection
'500130' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 89 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Specific content of precipitation particles (needed for water loadin)g
'500131' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 99 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Large scale rain rate
'500132' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 100 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Large scale snowfall rate water equivalent
'500133' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 101 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Large scale rain rate (s)
'500134' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 102 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 4 ;
	}
#Convective rain rate
'500135' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 111 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Convective snowfall rate water equivalent
'500136' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 112 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Convective rain rate (s)
'500137' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 113 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 4 ;
	}
#rain amount, grid-scale plus convective
'500138' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 122 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#snow amount, grid-scale plus convective
'500139' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 123 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Temperature tendency due to grid scale precipation
'500140' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 124 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Specific humitiy tendency due to grid scale precipitation
'500141' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 125 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#tendency of specific cloud liquid water content due to grid scale precipitation
'500142' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 127 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Fresh snow factor (weighting function for albedo indicating freshness of snow)
'500143' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 129 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#tendency of specific cloud ice content due to grid scale precipitation
'500144' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 130 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Graupel (snow pellets) precipitation rate
'500145' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 131 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Graupel (snow pellets) precipitation rate
'500146' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 132 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 4 ;
	}
#Snow density
'500147' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 133 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Pressure perturbation
'500148' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 139 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#supercell detection index 1 (rot. up+down drafts)
'500149' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 141 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#supercell detection index 2 (only rot. up drafts)
'500150' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 142 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Convective Available Potential Energy, most unstable
'500151' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 143 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Convective Inhibition, most unstable
'500152' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 144 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Convective Available Potential Energy, mean layer
'500153' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 145 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Convective Inhibition, mean layer
'500154' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 146 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Convective turbulent kinetic enery
'500155' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 147 ;
	}
#Tendency of turbulent kinetic energy
'500156' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 148 ;
	 indicatorOfTypeOfLevel = 109 ;
	}
#Kinetic Energy
'500157' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 149 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Turbulent Kinetic Energy
'500158' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 152 ;
	 indicatorOfTypeOfLevel = 109 ;
	}
#Turbulent diffusioncoefficient for momentum
'500159' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 153 ;
	 indicatorOfTypeOfLevel = 109 ;
	}
#Turbulent diffusion coefficient for heat (and moisture)
'500160' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 154 ;
	 indicatorOfTypeOfLevel = 109 ;
	}
#Turbulent transfer coefficient for impulse
'500161' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 170 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Turbulent transfer coefficient for heat (and Moisture)
'500162' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 171 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#mixed layer depth
'500163' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 173 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#maximum Wind 10m
'500164' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 187 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	 timeRangeIndicator = 2 ;
	}
#Air concentration of Ruthenium 103
'500165' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 194 ;
	 indicatorOfTypeOfLevel = 100 ;
	}
#Soil Temperature (multilayers)
'500166' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 197 ;
	 indicatorOfTypeOfLevel = 111 ;
	}
#Column-integrated Soil Moisture (multilayers)
'500167' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 198 ;
	 indicatorOfTypeOfLevel = 111 ;
	}
#soil ice content (multilayers)
'500168' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 199 ;
	 indicatorOfTypeOfLevel = 111 ;
	}
#Plant Canopy Surface Water
'500169' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 200 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Snow temperature (top of snow)
'500170' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 203 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Minimal Stomatal Resistance
'500171' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 212 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#sea Ice Temperature
'500172' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 215 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Base reflectivity
'500173' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 230 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Base reflectivity
'500174' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 230 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Base reflectivity (cmax)
'500175' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 230 ;
	 indicatorOfTypeOfLevel = 200 ;
	}
#unknown
'500176' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 232 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Effective transmissivity of solar radiation
'500177' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 233 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#sum of contributions to evaporation
'500178' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 236 ;
	}
#total transpiration from all soil layers
'500179' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 237 ;
	}
#total forcing at soil surface
'500180' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 238 ;
	}
#residuum of soil moisture
'500181' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 239 ;
	}
#Massflux at convective cloud base
'500182' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 240 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Convective Available Potential Energy
'500183' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 241 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#moisture convergence for Kuo-type closure
'500184' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 243 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#total wave direction
'500185' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 4 ;
	}
#wind sea mean period
'500186' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 7 ;
	 indicatorOfTypeOfLevel = 102 ;
	}
#wind sea peak period
'500187' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 7 ;
	}
#swell mean period
'500188' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 8 ;
	 indicatorOfTypeOfLevel = 102 ;
	}
#swell peak period
'500189' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 8 ;
	}
#total wave peak period
'500190' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 9 ;
	}
#total wave mean period
'500191' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 10 ;
	}
#total Tm1 period
'500192' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 17 ;
	}
#total Tm2 period
'500193' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 18 ;
	}
#total directional spread
'500194' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 19 ;
	}
#analysis error(standard deviation), geopotential(gpm)
'500195' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 40 ;
	 indicatorOfTypeOfLevel = 100 ;
	}
#analysis error(standard deviation), u-comp. of wind
'500196' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 41 ;
	 indicatorOfTypeOfLevel = 100 ;
	}
#analysis error(standard deviation), v-comp. of wind
'500197' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 42 ;
	 level = 100 ;
	}
#zonal wind tendency due to subgrid scale oro.
'500198' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 44 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#meridional wind tendency due to subgrid scale oro.
'500199' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 45 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Standard deviation of sub-grid scale orography
'500200' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 46 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Anisotropy of sub-gridscale orography
'500201' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 47 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Angle of sub-gridscale orography
'500202' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 48 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Slope of sub-gridscale orography
'500203' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 49 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#surface emissivity
'500204' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 56 ;
	 indicatorOfTypeOfLevel = 1 ;
	 level = 0 ;
	 timeRangeIndicator = 0 ;
	}
#Soil Type
'500205' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 57 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Leaf area index
'500206' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 61 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#root depth of vegetation
'500207' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 62 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#height of ozone maximum (climatological)
'500208' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 64 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#vertically integrated ozone content (climatological)
'500209' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 65 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Plant covering degree in the vegetation phase
'500210' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 67 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Plant covering degree in the quiescent phas
'500211' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 68 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Max Leaf area index
'500212' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 69 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Min Leaf area index
'500213' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 70 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Orographie + Land-Meer-Verteilung
'500214' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 71 ;
	}
#variance of soil moisture content (0-10)
'500215' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 74 ;
	 indicatorOfTypeOfLevel = 112 ;
	 bottomLevel = 10 ;
	 topLevel = 0 ;
	}
#variance of soil moisture content (10-100)
'500216' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 74 ;
	 indicatorOfTypeOfLevel = 112 ;
	 bottomLevel = 100 ;
	 topLevel = 10 ;
	}
#evergreen forest
'500217' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 75 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#deciduous forest
'500218' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 76 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#normalized differential vegetation index
'500219' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 77 ;
	 timeRangeIndicator = 3 ;
	}
#normalized differential vegetation index (NDVI)
'500220' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 78 ;
	 timeRangeIndicator = 3 ;
	}
#ratio of monthly mean NDVI (normalized differential vegetation index) to annual maximum
'500221' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 79 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#ratio of monthly mean NDVI (normalized differential vegetation index) to annual maximum
'500222' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 79 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 0 ;
	}
#Total sulfate aerosol
'500223' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 84 ;
	}
#Total sulfate aerosol (12M)
'500224' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 84 ;
	 timeRangeIndicator = 3 ;
	}
#Total soil dust aerosol
'500225' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 86 ;
	}
#Total soil dust aerosol (12M)
'500226' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 86 ;
	 timeRangeIndicator = 3 ;
	}
#Organic aerosol
'500227' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 91 ;
	}
#Organic aerosol (12M)
'500228' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 91 ;
	 timeRangeIndicator = 3 ;
	}
#Black carbon aerosol
'500229' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 92 ;
	}
#Black carbon aerosol (12M)
'500230' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 92 ;
	 timeRangeIndicator = 3 ;
	}
#Sea salt aerosol
'500231' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 93 ;
	}
#Sea salt aerosol (12M)
'500232' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 93 ;
	 timeRangeIndicator = 3 ;
	}
#tendency of specific humidity
'500233' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 104 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#water vapor flux
'500234' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 105 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Coriolis parameter
'500235' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 113 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#geographical latitude
'500236' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 114 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#geographical longitude
'500237' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 115 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Friction velocity
'500238' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 120 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Delay of the GPS signal trough the (total) atm.
'500239' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 121 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Delay of the GPS signal trough wet atmos.
'500240' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 122 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Delay of the GPS signal trough dry atmos.
'500241' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 123 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Ozone Mixing Ratio
'500242' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 180 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Air concentration of Ruthenium 103 (Ru103- concentration)
'500243' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 194 ;
	}
#Ru103-dry deposition
'500244' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 195 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Ru103-wet deposition
'500245' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 196 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Air concentration of Strontium 90
'500246' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 197 ;
	}
#Sr90-dry deposition
'500247' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 198 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Sr90-wet deposition
'500248' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 199 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#I131-concentration
'500249' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 200 ;
	}
#I131-dry deposition
'500250' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 201 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#I131-wet deposition
'500251' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 202 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Cs137-concentration
'500252' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 203 ;
	}
#Cs137-dry deposition
'500253' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 204 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Cs137-wet deposition
'500254' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 205 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Air concentration of Tellurium 132 (Te132-concentration)
'500255' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 206 ;
	}
#Te132-dry deposition
'500256' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 207 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Te132-wet deposition
'500257' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 208 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Air concentration of Zirconium 95 (Zr95-concentration)
'500258' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 209 ;
	}
#Zr95-dry deposition
'500259' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 210 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Zr95-wet deposition
'500260' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 211 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Air concentration of Krypton 85  (Kr85-concentration)
'500261' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 212 ;
	}
#Kr85-dry deposition
'500262' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 213 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Kr85-wet deposition
'500263' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 214 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#TRACER - concentration
'500264' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 215 ;
	}
#TRACER - dry deposition
'500265' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 216 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#TRACER - wet deposition
'500266' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 217 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Air concentration of Xenon 133 (Xe133  - concentration)
'500267' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 218 ;
	}
#Xe133  - dry deposition
'500268' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 219 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Xe133  - wet deposition
'500269' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 220 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#I131g - concentration
'500270' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 221 ;
	}
#Xe133  - wet deposition
'500271' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 222 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#I131g  - wet deposition
'500272' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 223 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#I131o  - concentration
'500273' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 224 ;
	}
#I131o  - dry deposition
'500274' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 225 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#I131o  - wet deposition
'500275' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 226 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Air concentration of Barium 40
'500276' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 227 ;
	}
#Ba140 - dry deposition
'500277' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 228 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Ba140  - wet deposition
'500278' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 229 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#u-momentum flux due to SSO-effects
'500279' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 231 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}
#u-momentum flux due to SSO-effects
'500280' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 231 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 0 ;
	}
#v-momentum flux due to SSO-effects
'500281' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 232 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}
#v-momentum flux due to SSO-effects
'500282' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 232 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 0 ;
	}
#Gravity wave dissipation (vertical integral)
'500283' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 233 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}
#Gravity wave dissipation (vertical integral)
'500284' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 233 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 0 ;
	}
#UV_Index_Maximum_W  UV_Index clouded (W), daily maximum
'500285' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 248 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#wind shear
'500286' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 29 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#storm relative helicity
'500287' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 30 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#absolute vorticity advection
'500288' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 33 ;
	 indicatorOfTypeOfLevel = 100 ;
	}
#NiederschlagBew.-ArtKombination Niederschl.-Bew.-Blautherm. (283..407)
'500289' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 90 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Konvektions-U-GrenzeHoehe der Konvektionsuntergrenze ueber Grund
'500290' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 91 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Konv.-U-Grenze-nn   Hoehe der Konvektionsuntergrenze ueber nn
'500291' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 94 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#weather interpretation (WMO)
'500292' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 99 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#geostrophische  Vorticityadvektion
'500293' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 101 ;
	 indicatorOfTypeOfLevel = 100 ;
	}
#Geo Temperatur Adv  geostrophische Schichtdickenadvektion
'500294' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 103 ;
	 indicatorOfTypeOfLevel = 101 ;
	}
#Schichtdicken-Advektion
'500295' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 107 ;
	 indicatorOfTypeOfLevel = 101 ;
	}
#Winddivergenz
'500296' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 109 ;
	 indicatorOfTypeOfLevel = 100 ;
	}
#Qn-Vektor Q isother-senkr-KompQn ,Komp. Q-Vektor senkrecht zu den Isothermen
'500297' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 124 ;
	 indicatorOfTypeOfLevel = 100 ;
	}
#Isentrope potentielle Vorticity
'500298' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 130 ;
	 indicatorOfTypeOfLevel = 100 ;
	}
#XIPV Wind X-Komp     Wind X-Komponente auf isentropen Flaechen
'500299' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 131 ;
	 indicatorOfTypeOfLevel = 100 ;
	}
#YIPV Wind Y-Komp     Wind Y-Komponente auf isentropen Flaechen
'500300' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 132 ;
	 indicatorOfTypeOfLevel = 100 ;
	}
#Druck einer isentropen Flaeche
'500301' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 133 ;
	 indicatorOfTypeOfLevel = 100 ;
	}
#KO index
'500302' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 140 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Aequivalentpotentielle Temperatur
'500303' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 154 ;
	 indicatorOfTypeOfLevel = 100 ;
	}
#Ceiling
'500304' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 157 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Icing Grade (1=LGT,2=MOD,3=SEV)
'500305' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 196 ;
	 indicatorOfTypeOfLevel = 100 ;
	}
#modified cloud depth for media
'500306' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 203 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#modified cloud cover for media
'500307' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 204 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Monthly Mean of RMS of difference FG-AN of pressure reduced to MSL
'500308' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 1 ;
	}
#Monthly Mean of RMS of difference IA-AN of pressure reduced to MSL
'500309' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 2 ;
	}
#Monthly Mean of RMS of difference FG-AN of u-component of wind
'500310' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 3 ;
	}
#Monthly Mean of RMS of difference IA-AN of u-component of wind
'500311' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 4 ;
	}
#Monthly Mean of RMS of difference FG-AN of v-component of wind
'500312' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 5 ;
	}
#Monthly Mean of RMS of difference IA-AN of v-component of wind
'500313' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 6 ;
	}
#Monthly Mean of RMS of difference FG-AN of geopotential
'500314' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 7 ;
	}
#Monthly Mean of RMS of difference IA-AN of geopotential
'500315' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 8 ;
	}
#Monthly Mean of RMS of difference FG-AN of relative humidity
'500316' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 9 ;
	}
#Monthly Mean of RMS of difference IA-AN of relative humidity
'500317' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 10 ;
	}
#Monthly Mean of RMS of difference FG-AN of temperature
'500318' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 11 ;
	}
#Monthly Mean of RMS of difference IA-AN of temperature
'500319' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 12 ;
	}
#Monthly Mean of RMS of difference FG-AN of vert.velocity (pressure)
'500320' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 13 ;
	}
#Monthly Mean of RMS of difference IA-AN of vert.velocity (pressure)
'500321' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 14 ;
	}
#Monthly Mean of RMS of difference FG-AN of kinetic energy
'500322' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 15 ;
	}
#Monthly Mean of RMS of difference IA-AN of kinetic energy
'500323' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 16 ;
	}
#Synth. Sat. brightness temperature cloudy
'500324' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 1 ;
	 indicatorOfTypeOfLevel = 222 ;
	 localElementNumber = 1 ;
	}
#Synth. Sat. brightness temperature clear sky
'500325' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 1 ;
	 indicatorOfTypeOfLevel = 222 ;
	 localElementNumber = 2 ;
	}
#Synth. Sat. radiance cloudy
'500326' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 1 ;
	 indicatorOfTypeOfLevel = 222 ;
	 localElementNumber = 3 ;
	}
#Synth. Sat. radiance cloudy
'500327' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 1 ;
	 indicatorOfTypeOfLevel = 222 ;
	 localElementNumber = 4 ;
	}
#Synth. Sat. brightness temperature cloudy
'500328' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 2 ;
	 indicatorOfTypeOfLevel = 222 ;
	 localElementNumber = 1 ;
	}
#Synth. Sat. brightness temperature clear sky
'500329' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 2 ;
	 indicatorOfTypeOfLevel = 222 ;
	 localElementNumber = 2 ;
	}
#Synth. Sat. radiance cloudy
'500330' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 2 ;
	 indicatorOfTypeOfLevel = 222 ;
	 localElementNumber = 3 ;
	}
#Synth. Sat. radiance cloudy
'500331' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 2 ;
	 indicatorOfTypeOfLevel = 222 ;
	 localElementNumber = 4 ;
	}
#Synth. Sat. brightness temperature clear sky
'500332' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 3 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 2 ;
	 localElementNumber = 1 ;
	}
#Synth. Sat. brightness temperature cloudy
'500333' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 3 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 1 ;
	 localElementNumber = 1 ;
	}
#Synth. Sat. brightness temperature clear sky
'500334' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 3 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 2 ;
	 localElementNumber = 2 ;
	}
#Synth. Sat. brightness temperature cloudy
'500335' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 3 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 1 ;
	 localElementNumber = 2 ;
	}
#Synth. Sat. radiance clear sky
'500336' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 3 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 2 ;
	 localElementNumber = 3 ;
	}
#Synth. Sat. radiance cloudy
'500337' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 3 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 1 ;
	 localElementNumber = 3 ;
	}
#Synth. Sat. radiance clear sky
'500338' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 3 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 2 ;
	 localElementNumber = 4 ;
	}
#Synth. Sat. radiance cloudy
'500339' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 3 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 1 ;
	 localElementNumber = 4 ;
	}
#Synth. Sat. brightness temperature cloudy
'500340' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 6 ;
	 localElementNumber = 1 ;
	}
#Synth. Sat. brightness temperature cloudy
'500341' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 7 ;
	 localElementNumber = 1 ;
	}
#Synth. Sat. brightness temperature cloudy
'500342' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 8 ;
	 localElementNumber = 1 ;
	}
#Synth. Sat. brightness temperature cloudy
'500343' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 1 ;
	 localElementNumber = 1 ;
	}
#Synth. Sat. brightness temperature cloudy
'500344' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 4 ;
	 localElementNumber = 1 ;
	}
#Synth. Sat. brightness temperature cloudy
'500345' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 5 ;
	 localElementNumber = 1 ;
	}
#Synth. Sat. brightness temperature cloudy
'500346' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 2 ;
	 localElementNumber = 1 ;
	}
#Synth. Sat. brightness temperature cloudy
'500347' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 3 ;
	 localElementNumber = 1 ;
	}
#Synth. Sat. brightness temperature clear sky
'500348' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 4 ;
	 localElementNumber = 2 ;
	}
#Synth. Sat. brightness temperature clear sky
'500349' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 6 ;
	 localElementNumber = 2 ;
	}
#Synth. Sat. brightness temperature clear sky
'500350' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 7 ;
	 localElementNumber = 2 ;
	}
#Synth. Sat. brightness temperature clear sky
'500351' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 8 ;
	 localElementNumber = 2 ;
	}
#Synth. Sat. brightness temperature clear sky
'500352' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 1 ;
	 localElementNumber = 2 ;
	}
#Synth. Sat. brightness temperature clear sky
'500353' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 5 ;
	 localElementNumber = 2 ;
	}
#Synth. Sat. brightness temperature clear sky
'500354' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 2 ;
	 localElementNumber = 2 ;
	}
#Synth. Sat. brightness temperature clear sky
'500355' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 3 ;
	 localElementNumber = 2 ;
	}
#Synth. Sat. radiance cloudy
'500356' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 6 ;
	 localElementNumber = 3 ;
	}
#Synth. Sat. radiance cloudy
'500357' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 7 ;
	 localElementNumber = 3 ;
	}
#Synth. Sat. radiance cloudy
'500358' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 8 ;
	 localElementNumber = 3 ;
	}
#Synth. Sat. radiance cloudy
'500359' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 1 ;
	 localElementNumber = 3 ;
	}
#Synth. Sat. radiance cloudy
'500360' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 4 ;
	 localElementNumber = 3 ;
	}
#Synth. Sat. radiance cloudy
'500361' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 5 ;
	 localElementNumber = 3 ;
	}
#Synth. Sat. radiance cloudy
'500362' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 2 ;
	 localElementNumber = 3 ;
	}
#Synth. Sat. radiance cloudy
'500363' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 3 ;
	 localElementNumber = 3 ;
	}
#Synth. Sat. radiance clear sky
'500364' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 6 ;
	 localElementNumber = 4 ;
	}
#Synth. Sat. radiance clear sky
'500365' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 7 ;
	 localElementNumber = 4 ;
	}
#Synth. Sat. radiance clear sky
'500366' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 8 ;
	 localElementNumber = 4 ;
	}
#Synth. Sat. radiance clear sky
'500367' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 1 ;
	 localElementNumber = 4 ;
	}
#Synth. Sat. radiance clear sky
'500368' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 4 ;
	 localElementNumber = 4 ;
	}
#Synth. Sat. radiance clear sky
'500369' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 5 ;
	 localElementNumber = 4 ;
	}
#Synth. Sat. radiance clear sky
'500370' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 2 ;
	 localElementNumber = 4 ;
	}
#Synth. Sat. radiance clear sky
'500371' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 3 ;
	 localElementNumber = 4 ;
	}
#smoothed forecast, temperature
'500372' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 11 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}
#smoothed forecast, maximum temp.
'500373' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 15 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	 timeRangeIndicator = 2 ;
	}
#smoothed forecast, minimum temp.
'500374' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 16 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	 timeRangeIndicator = 2 ;
	}
#smoothed forecast, dew point temp.
'500375' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 17 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}
#smoothed forecast, u comp. of wind
'500376' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 33 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	}
#smoothed forecast, v comp. of wind
'500377' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 34 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	}
#smoothed forecast, total precipitation rate
'500378' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 61 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#smoothed forecast, total cloud cover
'500379' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 71 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#smoothed forecast, cloud cover low
'500380' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 73 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#smoothed forecast, cloud cover medium
'500381' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 74 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#smoothed forecast, cloud cover high
'500382' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 75 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#smoothed forecast, large-scale snowfall rate w.e.
'500383' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 79 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#smoothed forecast, soil temperature
'500384' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 85 ;
	 indicatorOfTypeOfLevel = 111 ;
	 level = 0 ;
	}
#smoothed forecast, wind speed (gust)
'500385' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 187 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	}
#calibrated forecast, total precipitation rate
'500386' = {
	 table2Version = 207 ;
	 indicatorOfParameter = 61 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#calibrated forecast, large-scale snowfall rate w.e.
'500387' = {
	 table2Version = 207 ;
	 indicatorOfParameter = 79 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#calibrated forecast, wind speed (gust)
'500388' = {
	 table2Version = 207 ;
	 indicatorOfParameter = 187 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
}
