# (C) Copyright 2005- ECMWF.

# GRID DEFINITION Stretched Gaussian latitude/longitude grid
# grib 1 -> 2
constant gridDefinitionTemplateNumber     = 42;

template commonBlock "grib1/grid_definition_gaussian.def";

# Stretching parameters
include "grib1/grid_stretching.def"
