# Automatically generated by ./create_def.pl, do not edit
#Sea ice area fraction
'siconc' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 31 ;
	}
#Maximum 10 metre wind gust since previous post-processing
'fg10' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 49 ;
	}
#Maximum temperature at 2 metres in the last 24 hours
'mx2t24' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 51 ;
	}
#Minimum temperature at 2 metres in the last 24 hours
'mn2t24' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 52 ;
	}
#Maximum temperature at 2 metres in the last 6 hours
'mx2t6' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 121 ;
	}
#Minimum temperature at 2 metres in the last 6 hours
'mn2t6' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 122 ;
	}
#10 metre U wind component
'u10' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 165 ;
	}
#10 metre U wind component
'u10' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 165 ;
	}
#10 metre U wind component
'u10' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 165 ;
	}
#10 metre U wind component
'u10' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 165 ;
	}
#10 metre V wind component
'v10' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 166 ;
	}
#10 metre V wind component
'v10' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 166 ;
	}
#10 metre V wind component
'v10' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 166 ;
	}
#10 metre V wind component
'v10' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 166 ;
	}
#2 metre temperature
't2m' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 167 ;
	}
#2 metre temperature
't2m' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 167 ;
	}
#2 metre temperature
't2m' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 167 ;
	}
#2 metre temperature
't2m' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 167 ;
	}
#2 metre dewpoint temperature
'd2m' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 168 ;
	}
#2 metre dewpoint temperature
'd2m' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 168 ;
	}
#2 metre dewpoint temperature
'd2m' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 168 ;
	}
#2 metre dewpoint temperature
'd2m' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 168 ;
	}
#Maximum temperature at 2 metres since previous post-processing
'mx2t' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 201 ;
	}
#Maximum temperature at 2 metres since previous post-processing
'mx2t' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 201 ;
	}
#Maximum temperature at 2 metres since previous post-processing
'mx2t' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 201 ;
	}
#Minimum temperature at 2 metres since previous post-processing
'mn2t' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 202 ;
	}
#Minimum temperature at 2 metres since previous post-processing
'mn2t' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 202 ;
	}
#Minimum temperature at 2 metres since previous post-processing
'mn2t' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 202 ;
	}
#10 metre wind speed
'si10' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 207 ;
	}
#10 metre wind gust difference
'fgdiff10' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 49 ;
	}
#10 metre wind gust in the last 6 hours difference
'fg6diff10' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 123 ;
	}
#10 metre U wind component difference
'udiff10' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 165 ;
	}
#10 metre V wind component difference
'vdiff10' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 166 ;
	}
#2 metre temperature difference
'difft2' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 167 ;
	}
#10 metre wind speed difference
'sidiff10' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 207 ;
	}
#10 metre wind gust of at least 10 m/s
'fgg1010' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 100 ;
	}
#100 metre U wind component anomaly
'ua100' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 6 ;
	}
#100 metre V wind component anomaly
'va100' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 7 ;
	}
#100 metre wind speed anomaly
'sia100' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 8 ;
	}
#2 metre specific humidity
'sh2' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 96 ;
	}
#Maximum temperature at 2 metres in the last 3 hours
'mx2t3' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 26 ;
	}
#Minimum temperature at 2 metres in the last 3 hours
'mn2t3' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 27 ;
	}
#Maximum 10 metre wind gust in the last 3 hours
'fg310' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 28 ;
	}
#2 metre relative humidity with respect to water
'rhw2' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 37 ;
	}
#200 metre U wind component
'u200' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 239 ;
	}
#200 metre V wind component
'v200' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 240 ;
	}
#200 metre wind speed
'si200' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 241 ;
	}
#100 metre wind speed
'si100' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 249 ;
	}
#10 metre wind gust gradient
'fggrd10' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 49 ;
	}
#10 metre wind gust in the last 6 hours gradient
'fg6grd10' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 123 ;
	}
#10 metre U wind component gradient
'ugrd10' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 165 ;
	}
#10 metre V wind component gradient
'vgrd10' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 166 ;
	}
#2 metre temperature gradient
'grd2t' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 167 ;
	}
#2 metre dewpoint temperature gradient
'grd2d' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 168 ;
	}
#10 metre wind speed gradient
'sigrd10' = {
	 table2Version = 129 ;
	 indicatorOfParameter = 207 ;
	}
#2m temperature anomaly of at least +2K
't2ag2' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 1 ;
	}
#2m temperature anomaly of at least +1K
't2ag1' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 2 ;
	}
#2m temperature anomaly of at least 0K
't2ag0' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 3 ;
	}
#2m temperature anomaly of at most -1K
't2alm1' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 4 ;
	}
#2m temperature anomaly of at most -2K
't2alm2' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 5 ;
	}
#10 metre wind gust probability
'g10p' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 49 ;
	}
#10 metre Wind speed of at least 10 m/s
'sp10g10' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 68 ;
	}
#10 metre Wind speed of at least 15 m/s
'sp10g15' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 69 ;
	}
#10 metre wind gust of at least 15 m/s
'fg10g15' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 70 ;
	}
#10 metre wind gust of at least 20 m/s
'fg10g20' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 71 ;
	}
#10 metre wind gust of at least 25 m/s
'fg10g25' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 72 ;
	}
#2 metre temperature less than 273.15 K
't2l273' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 73 ;
	}
#10 metre speed probability
'sp10' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 165 ;
	}
#2 metre temperature probability
't2p' = {
	 table2Version = 131 ;
	 indicatorOfParameter = 167 ;
	}
#2m temperature probability less than -10 C
't2plm10' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 1 ;
	}
#2m temperature probability less than -5 C
't2plm5' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 2 ;
	}
#2m temperature probability less than 0 C
't2pl0' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 3 ;
	}
#2m temperature probability less than 5 C
't2pl5' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 4 ;
	}
#2m temperature probability less than 10 C
't2pl10' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 5 ;
	}
#2m temperature probability greater than 25 C
't2pg25' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 6 ;
	}
#2m temperature probability greater than 30 C
't2pg30' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 7 ;
	}
#2m temperature probability greater than 35 C
't2pg35' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 8 ;
	}
#2m temperature probability greater than 40 C
't2pg40' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 9 ;
	}
#2m temperature probability greater than 45 C
't2pg45' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 10 ;
	}
#10 metre wind speed probability of at least 10 m/s
'sp10g10' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 21 ;
	}
#10 metre wind speed probability of at least 15 m/s
'sp10g15' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 22 ;
	}
#10 metre wind speed probability of at least 20 m/s
'sp10g20' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 23 ;
	}
#10 metre wind speed probability of at least 35 m/s
'sp10g35' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 24 ;
	}
#10 metre wind speed probability of at least 50 m/s
'sp10g50' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 25 ;
	}
#10 metre wind gust probability of at least 20 m/s
'gp10g20' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 26 ;
	}
#10 metre wind gust probability of at least 35 m/s
'gp10g35' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 27 ;
	}
#10 metre wind gust probability of at least 50 m/s
'gp10g50' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 28 ;
	}
#10 metre wind gust probability of at least 75 m/s
'gp10g75' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 29 ;
	}
#10 metre wind gust probability of at least 100 m/s
'gp10g100' = {
	 table2Version = 133 ;
	 indicatorOfParameter = 30 ;
	}
#2D wave spectra (multiple)
'd2sp' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 250 ;
	}
#2D wave spectra (single)
'd2fd' = {
	 table2Version = 140 ;
	 indicatorOfParameter = 251 ;
	}
#Eastward surface sea water velocity
'uoe' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 131 ;
	}
#Northward surface sea water velocity
'von' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 132 ;
	}
#10 metre wind gust during averaging time
'fgrea10' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 49 ;
	}
#10 metre wind speed
'wsrea10' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 246 ;
	}
#10 metre wind gust anomaly
'fga10' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 49 ;
	}
#10 metre U wind component anomaly
'ua10' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 165 ;
	}
#10 metre V wind component anomaly
'va10' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 166 ;
	}
#2 metre temperature anomaly
't2a' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 167 ;
	}
#2 metre dewpoint temperature anomaly
'd2a' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 168 ;
	}
#10 metre wind speed anomaly
'sia10' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 207 ;
	}
#2 metre dewpoint temperature difference
'ddiff2' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 168 ;
	}
#Time-mean 2 metre temperature
'avg_2t' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 4 ;
	}
#Time-mean 10 metre wind speed
'avg_10ws' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 5 ;
	}
#2 metre temperature significance
't2s' = {
	 table2Version = 234 ;
	 indicatorOfParameter = 167 ;
	}
#100 metre U wind component
'u100' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 246 ;
	}
#100 metre V wind component
'v100' = {
	 table2Version = 228 ;
	 indicatorOfParameter = 247 ;
}
