#include "grib_api_internal.h"

extern grib_accessor* grib_accessor_abstract_long_vector;
extern grib_accessor* grib_accessor_abstract_vector;
extern grib_accessor* grib_accessor_ascii;
extern grib_accessor* grib_accessor_bit;
extern grib_accessor* grib_accessor_bitmap;
extern grib_accessor* grib_accessor_bits;
extern grib_accessor* grib_accessor_bits_per_value;
extern grib_accessor* grib_accessor_blob;
extern grib_accessor* grib_accessor_budgdate;
extern grib_accessor* grib_accessor_bufr_data_array;
extern grib_accessor* grib_accessor_bufr_data_element;
extern grib_accessor* grib_accessor_bufr_elements_table;
extern grib_accessor* grib_accessor_bufr_extract_area_subsets;
extern grib_accessor* grib_accessor_bufr_extract_datetime_subsets;
extern grib_accessor* grib_accessor_bufr_extract_subsets;
extern grib_accessor* grib_accessor_bufr_group;
extern grib_accessor* grib_accessor_bufr_simple_thinning;
extern grib_accessor* grib_accessor_bufr_string_values;
extern grib_accessor* grib_accessor_bufrdc_expanded_descriptors;
extern grib_accessor* grib_accessor_bytes;
extern grib_accessor* grib_accessor_change_alternative_row_scanning;
extern grib_accessor* grib_accessor_change_scanning_direction;
extern grib_accessor* grib_accessor_check_internal_version;
extern grib_accessor* grib_accessor_closest_date;
extern grib_accessor* grib_accessor_codeflag;
extern grib_accessor* grib_accessor_codetable;
extern grib_accessor* grib_accessor_codetable_title;
extern grib_accessor* grib_accessor_codetable_units;
extern grib_accessor* grib_accessor_concept;
extern grib_accessor* grib_accessor_constant;
extern grib_accessor* grib_accessor_count_file;
extern grib_accessor* grib_accessor_count_missing;
extern grib_accessor* grib_accessor_count_total;
extern grib_accessor* grib_accessor_data_apply_bitmap;
extern grib_accessor* grib_accessor_data_apply_boustrophedonic;
extern grib_accessor* grib_accessor_data_apply_boustrophedonic_bitmap;
extern grib_accessor* grib_accessor_data_ccsds_packing;
extern grib_accessor* grib_accessor_data_complex_packing;
extern grib_accessor* grib_accessor_data_dummy_field;
extern grib_accessor* grib_accessor_data_g1complex_packing;
extern grib_accessor* grib_accessor_data_g1second_order_constant_width_packing;
extern grib_accessor* grib_accessor_data_g1second_order_general_extended_packing;
extern grib_accessor* grib_accessor_data_g1second_order_general_packing;
extern grib_accessor* grib_accessor_data_g1second_order_row_by_row_packing;
extern grib_accessor* grib_accessor_data_g1secondary_bitmap;
extern grib_accessor* grib_accessor_data_g1shsimple_packing;
extern grib_accessor* grib_accessor_data_g1simple_packing;
extern grib_accessor* grib_accessor_data_g22order_packing;
extern grib_accessor* grib_accessor_data_g2bifourier_packing;
extern grib_accessor* grib_accessor_data_g2complex_packing;
extern grib_accessor* grib_accessor_data_g2secondary_bitmap;
extern grib_accessor* grib_accessor_data_g2shsimple_packing;
extern grib_accessor* grib_accessor_data_g2simple_packing;
extern grib_accessor* grib_accessor_data_g2simple_packing_with_preprocessing;
extern grib_accessor* grib_accessor_data_jpeg2000_packing;
extern grib_accessor* grib_accessor_data_png_packing;
extern grib_accessor* grib_accessor_data_raw_packing;
extern grib_accessor* grib_accessor_data_run_length_packing;
extern grib_accessor* grib_accessor_data_secondary_bitmap;
extern grib_accessor* grib_accessor_data_sh_packed;
extern grib_accessor* grib_accessor_data_sh_unpacked;
extern grib_accessor* grib_accessor_data_shsimple_packing;
extern grib_accessor* grib_accessor_data_simple_packing;
extern grib_accessor* grib_accessor_decimal_precision;
extern grib_accessor* grib_accessor_dictionary;
extern grib_accessor* grib_accessor_dirty;
extern grib_accessor* grib_accessor_divdouble;
extern grib_accessor* grib_accessor_double;
extern grib_accessor* grib_accessor_element;
extern grib_accessor* grib_accessor_evaluate;
extern grib_accessor* grib_accessor_expanded_descriptors;
extern grib_accessor* grib_accessor_from_scale_factor_scaled_value;
extern grib_accessor* grib_accessor_g1_half_byte_codeflag;
extern grib_accessor* grib_accessor_g1_message_length;
extern grib_accessor* grib_accessor_g1_section4_length;
extern grib_accessor* grib_accessor_g1bitmap;
extern grib_accessor* grib_accessor_g1date;
extern grib_accessor* grib_accessor_g1day_of_the_year_date;
extern grib_accessor* grib_accessor_g1end_of_interval_monthly;
extern grib_accessor* grib_accessor_g1fcperiod;
extern grib_accessor* grib_accessor_g1forecastmonth;
extern grib_accessor* grib_accessor_g1monthlydate;
extern grib_accessor* grib_accessor_g1number_of_coded_values_sh_complex;
extern grib_accessor* grib_accessor_g1number_of_coded_values_sh_simple;
extern grib_accessor* grib_accessor_g1step_range;
extern grib_accessor* grib_accessor_g1verificationdate;
extern grib_accessor* grib_accessor_g2_aerosol;
extern grib_accessor* grib_accessor_g2_chemical;
extern grib_accessor* grib_accessor_g2_concept_dir;
extern grib_accessor* grib_accessor_g2_eps;
extern grib_accessor* grib_accessor_g2_mars_labeling;
extern grib_accessor* grib_accessor_g2_param_concept_filename;
extern grib_accessor* grib_accessor_g2bitmap;
extern grib_accessor* grib_accessor_g2bitmap_present;
extern grib_accessor* grib_accessor_g2date;
extern grib_accessor* grib_accessor_g2end_step;
extern grib_accessor* grib_accessor_g2grid;
extern grib_accessor* grib_accessor_g2latlon;
extern grib_accessor* grib_accessor_g2level;
extern grib_accessor* grib_accessor_g2lon;
extern grib_accessor* grib_accessor_g2step_range;
extern grib_accessor* grib_accessor_gaussian_grid_name;
extern grib_accessor* grib_accessor_gds_is_present;
extern grib_accessor* grib_accessor_gen;
extern grib_accessor* grib_accessor_getenv;
extern grib_accessor* grib_accessor_global_gaussian;
extern grib_accessor* grib_accessor_grid_spec;
extern grib_accessor* grib_accessor_group;
extern grib_accessor* grib_accessor_group_copy;
extern grib_accessor* grib_accessor_gts_header;
extern grib_accessor* grib_accessor_hash_array;
extern grib_accessor* grib_accessor_headers_only;
extern grib_accessor* grib_accessor_ibmfloat;
extern grib_accessor* grib_accessor_ieeefloat;
extern grib_accessor* grib_accessor_ifs_param;
extern grib_accessor* grib_accessor_iterator;
extern grib_accessor* grib_accessor_julian_date;
extern grib_accessor* grib_accessor_julian_day;
extern grib_accessor* grib_accessor_ksec1expver;
extern grib_accessor* grib_accessor_label;
extern grib_accessor* grib_accessor_latitudes;
extern grib_accessor* grib_accessor_latlon_increment;
extern grib_accessor* grib_accessor_latlonvalues;
extern grib_accessor* grib_accessor_library_version;
extern grib_accessor* grib_accessor_local_definition;
extern grib_accessor* grib_accessor_long;
extern grib_accessor* grib_accessor_long_vector;
extern grib_accessor* grib_accessor_longitudes;
extern grib_accessor* grib_accessor_lookup;
extern grib_accessor* grib_accessor_mars_param;
extern grib_accessor* grib_accessor_mars_step;
extern grib_accessor* grib_accessor_md5;
extern grib_accessor* grib_accessor_message;
extern grib_accessor* grib_accessor_message_copy;
extern grib_accessor* grib_accessor_message_is_valid;
extern grib_accessor* grib_accessor_mtg2_switch_default;
extern grib_accessor* grib_accessor_multdouble;
extern grib_accessor* grib_accessor_nearest;
extern grib_accessor* grib_accessor_non_alpha;
extern grib_accessor* grib_accessor_number_of_coded_values;
extern grib_accessor* grib_accessor_number_of_points;
extern grib_accessor* grib_accessor_number_of_points_gaussian;
extern grib_accessor* grib_accessor_number_of_values;
extern grib_accessor* grib_accessor_number_of_values_data_raw_packing;
extern grib_accessor* grib_accessor_octahedral_gaussian;
extern grib_accessor* grib_accessor_octet_number;
extern grib_accessor* grib_accessor_offset_file;
extern grib_accessor* grib_accessor_offset_values;
extern grib_accessor* grib_accessor_optimal_step_units;
extern grib_accessor* grib_accessor_pack_bufr_values;
extern grib_accessor* grib_accessor_packing_type;
extern grib_accessor* grib_accessor_pad;
extern grib_accessor* grib_accessor_padding;
extern grib_accessor* grib_accessor_padto;
extern grib_accessor* grib_accessor_padtoeven;
extern grib_accessor* grib_accessor_padtomultiple;
extern grib_accessor* grib_accessor_position;
extern grib_accessor* grib_accessor_proj_string;
extern grib_accessor* grib_accessor_raw;
extern grib_accessor* grib_accessor_rdbtime_guess_date;
extern grib_accessor* grib_accessor_reference_value_error;
extern grib_accessor* grib_accessor_round;
extern grib_accessor* grib_accessor_scale;
extern grib_accessor* grib_accessor_scale_values;
extern grib_accessor* grib_accessor_second_order_bits_per_value;
extern grib_accessor* grib_accessor_section;
extern grib_accessor* grib_accessor_section_length;
extern grib_accessor* grib_accessor_section_padding;
extern grib_accessor* grib_accessor_section_pointer;
extern grib_accessor* grib_accessor_select_step_template;
extern grib_accessor* grib_accessor_sexagesimal2decimal;
extern grib_accessor* grib_accessor_signed;
extern grib_accessor* grib_accessor_signed_bits;
extern grib_accessor* grib_accessor_simple_packing_error;
extern grib_accessor* grib_accessor_size;
extern grib_accessor* grib_accessor_smart_table;
extern grib_accessor* grib_accessor_smart_table_column;
extern grib_accessor* grib_accessor_spd;
extern grib_accessor* grib_accessor_spectral_truncation;
extern grib_accessor* grib_accessor_sprintf;
extern grib_accessor* grib_accessor_statistics;
extern grib_accessor* grib_accessor_statistics_spectral;
extern grib_accessor* grib_accessor_step_human_readable;
extern grib_accessor* grib_accessor_step_in_units;
extern grib_accessor* grib_accessor_sum;
extern grib_accessor* grib_accessor_suppressed;
extern grib_accessor* grib_accessor_time;
extern grib_accessor* grib_accessor_to_double;
extern grib_accessor* grib_accessor_to_integer;
extern grib_accessor* grib_accessor_to_string;
extern grib_accessor* grib_accessor_transient;
extern grib_accessor* grib_accessor_transient_darray;
extern grib_accessor* grib_accessor_trim;
extern grib_accessor* grib_accessor_uint16;
extern grib_accessor* grib_accessor_uint32;
extern grib_accessor* grib_accessor_uint32_little_endian;
extern grib_accessor* grib_accessor_uint64;
extern grib_accessor* grib_accessor_uint64_little_endian;
extern grib_accessor* grib_accessor_uint8;
extern grib_accessor* grib_accessor_unexpanded_descriptors;
extern grib_accessor* grib_accessor_unpack_bufr_values;
extern grib_accessor* grib_accessor_unsigned;
extern grib_accessor* grib_accessor_unsigned_bits;
extern grib_accessor* grib_accessor_validity_date;
extern grib_accessor* grib_accessor_validity_time;
extern grib_accessor* grib_accessor_values;
extern grib_accessor* grib_accessor_variable;
extern grib_accessor* grib_accessor_vector;
extern grib_accessor* grib_accessor_when;
extern grib_accessor* grib_accessor_cf_var_name;
