# (C) Copyright 2005- ECMWF.

# The section number is always 1 byte and at the 5th byte of each section (so offset=4)

lookup[1]  sectionNumber(4);
if (sectionNumber == 1 or new()){
   position sectionPosition;
   template section_01 "grib3/section.01.def"; #Originator Section
}

lookup[1]  sectionNumber(4);
if (sectionNumber == 2 or new()){
   position sectionPosition;
   template section_02 "grib3/section.02.def"; #Repetitions and Index Section
} 

lookup[1]  sectionNumber(4);
if (sectionNumber == 3 or new()){
   position sectionPosition;
   template section_03 "grib3/section.03.def"; #Time Domain Section
}

lookup[1]  sectionNumber(4);
if (sectionNumber == 4 or new()){
   position sectionPosition;
   template section_04 "grib3/section.04.def"; #Horizontal Domain Section
}

lookup[1]  sectionNumber(4);
if (sectionNumber == 5 or new()){
   position sectionPosition;
   template section_05 "grib3/section.05.def"; #Vertical Domain Section
}

lookup[1]  sectionNumber(4);
if (sectionNumber == 6 or new()){
   position sectionPosition;
   template section_06 "grib3/section.06.def"; #Generating Process Section
}

lookup[1]  sectionNumber(4);
if (sectionNumber == 7 or new()){
   position sectionPosition;
   template section_07 "grib3/section.07.def"; #Observable Property Section
}

lookup[1]  sectionNumber(4);

# Used to mark end of headers. Can be accessed with grib_get_offset()
position   endOfHeadersMarker;

meta lengthOfHeaders evaluate(endOfHeadersMarker - startOfHeaders);
meta md5Headers md5(startOfHeaders,lengthOfHeaders);

if (sectionNumber == 8 or new()){
   position sectionPosition;
   template section_08 "grib3/section.08.def"; #Data Representation Section
}

lookup[1]  sectionNumber(4);
if (sectionNumber == 9 or new()){
   position sectionPosition;
   template section_09 "grib3/section.09.def"; #Overlay Section
}

lookup[1]  sectionNumber(4);
if (sectionNumber == 10 or new()){
   position sectionPosition;
   template section_10 "grib3/section.10.def"; #Data Section
}
