# (C) Copyright 2005- ECMWF.

# GRID DEFINITION rotated latitude/longitude grid
# grib 1 -> 2
constant gridDefinitionTemplateNumber     = 1;

template commonBlock "grib1/grid_definition_latlon.def";

ascii[4] zeros : read_only;

# Rotation parameters
include "grib1/grid_rotation.def"
