alias mars.step = stepRange;

# We need this because 'postProcessing' is defined later
meta ecpt_model sprintf("%s", postProcessing) : no_copy;
alias mars.model = ecpt_model;

meta marsQuantile sprintf("%d:%d",quantileValue,totalNumberOfQuantiles);
alias   mars.quantile = marsQuantile;

