# author: Sebastien Villaume
# created: 13 May 2013
#
"none"={matchSort=0;}
"cm"={matchSort=1;}
"lncm"={matchSort=2;}
"c"={matchSort=3;}
"cc"={matchSort=3;}
"lnc"={matchSort=4;}
"nr"={matchSort=7;}
"cbq"={matchSort=9;}
"lncbq"={matchSort=10;}
"cmrefh"={matchSort=11;}
"crefh"={matchSort=12;}
"lncrefh"={matchSort=13;}
"totcolumn"={matchSort=14;}
"loncolumn"={matchSort=14;}
"highcolumn"={matchSort=14;}
"lowmax"={matchSort=14;}
"highmax"={matchSort=14;}
"lowmaxz"={matchSort=15;}
"highmaxz"={matchSort=15;}
"icm"={matchSort=21;}
"lnicm"={matchSort=22;}
"ic"={matchSort=23;}
"lnic"={matchSort=24;}
"inr"={matchSort=27;}
"icbq"={matchSort=29;}
"lnicbq"={matchSort=30;}
"clw"={matchSort=51;}
"ceqlw"={matchSort=53;}
"cnrlw"={matchSort=54;}
"cbqlwc"={matchSort=55;}
"ciw"={matchSort=61;}
"ceqiw"={matchSort=63;}
"cnriw"={matchSort=64;}
"cbqiw"={matchSort=65;}
"cprec"={matchSort=71;}
"ceqprec"={matchSort=73;}
"cnprec"={matchSort=74;}
"cbqprec"={matchSort=75;}
"drydep"={matchSort=81;}
"lndrydep"={matchSort=82;}
"drydepnr"={matchSort=84;}
"drydepbq"={matchSort=85;}
"wetdep"={matchSort=91;}
"lnwetdep"={matchSort=92;}
"wetdepnr"={matchSort=94;}
"wetdepbq"={matchSort=95;}
"totdep"={matchSort=101;}
"lntotdep"={matchSort=102;}
"totdepnr"={matchSort=104;}
"totdepbq"={matchSort=105;}
"qton"={matchSort=110;}
"qkg"={matchSort=111;}
"qg"={matchSort=112;}
"qnr"={matchSort=114;}
"qbq"={matchSort=115;}
"qkgs"={matchSort=121;}
"qgs"={matchSort=122;}
"qns"={matchSort=124;}
"qbqs"={matchSort=125;}
"aqkgs"={matchSort=131;}
"aqgs"={matchSort=132;}
"aqnrs"={matchSort=134;}
"aqbqs"={matchSort=135;}
"aq0kgs"={matchSort=136;}
"aq0gs"={matchSort=137;}
"aq0nrs"={matchSort=138;}
"aq0bqs"={matchSort=139;}
"inhdose"={matchSort=150;}
"grddose"={matchSort=151;}
"clddose"={matchSort=152;}
"sumdose"={matchSort=153;}
"vd"={matchSort=201;}
"vs"={matchSort=202;}
"lamda"={matchSort=203;}
"tsum"={matchSort=205;}
"hsum"={matchSort=206;}
"hcrit"={matchSort=207;}
"raccum"={matchSort=208;}
"corr"={matchSort=209;}
"aod"={matchSort=210;}
"timearr"={matchSort=240;}
"timelat"={matchSort=241;}
"timemax"={matchSort=242;}
"maxactiv"={matchSort=243;}
"lnmaxactiv"={matchSort=244;}
"freq"={matchSort=250;}
"flux"={matchSort=251;}
"fluxmol"={matchSort=252;}
"missing"={matchSort=255;}
