# Automatically generated by ./create_param.pl, do not edit
#Geopotential
'geopotential' = {
	 discipline = 0 ;
	 parameterNumber = 4 ;
	 parameterCategory = 3 ;
	}
#Relative vorticity
'atmosphere_relative_vorticity' = {
	 discipline = 0 ;
	 parameterNumber = 12 ;
	 parameterCategory = 2 ;
	}
#Snow depth
'lwe_thickness_of_surface_snow_amount' = {
	 discipline = 0 ;
	 parameterNumber = 11 ;
	 parameterCategory = 1 ;
	 unitsFactor = 1000 ;
	}
#Convective precipitation
'lwe_thickness_of_convective_precipitation_amount' = {
	 discipline = 0 ;
	 parameterNumber = 10 ;
	 parameterCategory = 1 ;
	 unitsFactor = 1000 ;
	}
#Boundary layer dissipation
'kinetic_energy_dissipation_in_atmosphere_boundary_layer' = {
	 discipline = 0 ;
	 parameterNumber = 20 ;
	 parameterCategory = 2 ;
	}
#Relative divergence
'divergence_of_wind' = {
	 discipline = 0 ;
	 parameterNumber = 13 ;
	 parameterCategory = 2 ;
	}
#Relative humidity
'relative_humidity' = {
	 discipline = 0 ;
	 parameterNumber = 1 ;
	 parameterCategory = 1 ;
	}
#Surface roughness
'surface_roughness_length' = {
	 discipline = 2 ;
	 parameterNumber = 1 ;
	 parameterCategory = 0 ;
}
#Total column water vapour
'lwe_thickness_of_atmosphere_mass_content_of_water_vapor' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 137 ;
	}
#Soil temperature level 1
'surface_temperature' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 139 ;
	}
#Soil wetness level 1
'lwe_thickness_of_soil_moisture_content' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 140 ;
	}
#Snow depth
'lwe_thickness_of_surface_snow_amount' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 11 ;
	}
#Large-scale precipitation
'lwe_thickness_of_stratiform_precipitation_amount' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 142 ;
	}
#Convective precipitation
'lwe_thickness_of_convective_precipitation_amount' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 10 ;
	}
#Snowfall
'lwe_thickness_of_snowfall_amount' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 144 ;
	}
#Tendency of surface pressure
'tendency_of_surface_air_pressure' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 158 ;
	}
#Total cloud cover
'cloud_area_fraction' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 164 ;
	}
#Albedo
'surface_albedo' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 174 ;
	}
#Top net solar radiation
'toa_net_upward_shortwave_flux' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 178 ;
	}
#Evaporation
'lwe_thickness_of_water_evaporation_amount' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 182 ;
	}
#Convective cloud cover
'convective_cloud_area_fraction' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 185 ;
	}
#Surface net solar radiation, clear sky
'surface_net_downward_shortwave_flux_assuming_clear_sky' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 210 ;
	}
#Surface net thermal radiation, clear sky
'surface_net_downward_longwave_flux_assuming_clear_sky' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 211 ;
	}
#Temperature of snow layer
'temperature_in_surface_snow' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 238 ;
	}
