/*
 * (C) Copyright 2005- ECMWF.
 *
 * This software is licensed under the terms of the Apache Licence Version 2.0
 * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
 *
 * In applying this licence, ECMWF does not waive the privileges and immunities granted to it by
 * virtue of its status as an intergovernmental organisation nor does it submit to any jurisdiction.
 */

#include "grib_accessor_class_abstract_long_vector.h"

grib_accessor_abstract_long_vector_t _grib_accessor_abstract_long_vector{};
grib_accessor* grib_accessor_abstract_long_vector = &_grib_accessor_abstract_long_vector;
