#if(centre == ECMWF ) {
#meta fgDate validity_date(dataDate,dataTime,endStep) : no_copy;
#meta fgTime validity_time(dataDate,dataTime,endStep) : no_copy;

#alias mars.date = fgDate;
#alias mars.time = fgTime;
#alias mars.step = startStep;
#}

alias mars.number=perturbationNumber;

