# Automatically generated by ./create_def.pl, do not edit
#Sea ice area fraction
'sea_ice_area_fraction' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Geopotential
'geopotential' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 4 ;
	}
#Temperature
'air_temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	}
#U component of wind
'eastward_wind' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	}
#V component of wind
'northward_wind' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	}
#Specific humidity
'specific_humidity' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	}
#Surface pressure
'surface_air_pressure' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Vertical velocity
'lagrangian_tendency_of_air_pressure' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	}
#Total column vertically-integrated water vapour
'lwe_thickness_of_atmosphere_mass_content_of_water_vapor' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 64 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Vorticity (relative)
'atmosphere_relative_vorticity' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 12 ;
	}
#Time-integrated boundary layer dissipation
'kinetic_energy_dissipation_in_atmosphere_boundary_layer' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 20 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated surface sensible heat net flux
'surface_upward_sensible_heat_flux' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated surface latent heat net flux
'surface_upward_latent_heat_flux' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Mean sea level pressure
'air_pressure_at_mean_sea_level' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 101 ;
	}
#Divergence
'divergence_of_wind' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 13 ;
	}
#Geopotential height
'geopotential_height' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 5 ;
	}
#Relative humidity
'relative_humidity' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	}
#Surface short-wave (solar) radiation downwards
'surface_downwelling_shortwave_flux_in_air' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Land-sea mask
'land_binary_mask' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Surface roughness (climatological)
'surface_roughness_length' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Surface net short-wave (solar) radiation
'surface_net_downward_shortwave_flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Surface net long-wave (thermal) radiation
'surface_net_upward_longwave_flux' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Top net short-wave (solar) radiation
'toa_net_upward_shortwave_flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Top net long-wave (thermal) radiation
'toa_outgoing_longwave_flux' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated eastward turbulent surface stress
'surface_downward_eastward_stress' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 62 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated northward turbulent surface stress
'surface_downward_northward_stress' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 63 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Ozone mass mixing ratio
'mass_fraction_of_ozone_in_air' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 1 ;
	}
#Surface net short-wave (solar) radiation, clear sky
'surface_net_downward_shortwave_flux_assuming_clear_sky' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Surface net long-wave (thermal) radiation, clear sky
'surface_net_downward_longwave_flux_assuming_clear_sky' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Temperature of snow layer
'temperature_in_surface_snow' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 28 ;
	}
#Snow depth
'lwe_thickness_of_surface_snow_amount' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 11 ;
	}
#Particulate matter d <= 1 um
'mass_concentration_of_pm1_ambient_aerosol_particles_in_air' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 0 ;
	 scaleFactorOfSecondSize = missing() ;
	 scaledValueOfFirstSize = 1 ;
	 scaleFactorOfFirstSize = 6 ;
	 typeOfSizeInterval = 5 ;
	 aerosolType = 62026 ;
	 scaledValueOfSecondSize = missing() ;
	 is_aerosol = 1 ;
	}
#Particulate matter d <= 2.5 um
'mass_concentration_of_pm2p5_ambient_aerosol_particles_in_air' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 0 ;
	 scaleFactorOfSecondSize = missing() ;
	 scaledValueOfFirstSize = 25 ;
	 scaleFactorOfFirstSize = 7 ;
	 typeOfSizeInterval = 5 ;
	 aerosolType = 62026 ;
	 scaledValueOfSecondSize = missing() ;
	 is_aerosol = 1 ;
	}
#Particulate matter d <= 10 um
'mass_concentration_of_pm10_ambient_aerosol_particles_in_air' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 0 ;
	 scaleFactorOfSecondSize = missing() ;
	 scaledValueOfFirstSize = 10 ;
	 scaleFactorOfFirstSize = 6 ;
	 typeOfSizeInterval = 5 ;
	 aerosolType = 62026 ;
	 scaledValueOfSecondSize = missing() ;
	 is_aerosol = 1 ;
	}
#Ammonia mass mixing ratio
'mass_fraction_of_ammonia_in_air' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 9 ;
	 is_chemical = 1 ;
	}
#Nitrogen monoxide mass mixing ratio
'mass_fraction_of_nitrogen_monoxide_in_air' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 11 ;
	 is_chemical = 1 ;
	}
#Forecast albedo
'surface_albedo' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 1 ;
	}
#Sea surface practical salinity
'sea_surface_salinity' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 3 ;
	}
#Depth of 20 C isotherm
'depth_of_isosurface_of_sea_water_potential_temperature' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 20 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 29315 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Ocean mixed layer depth defined by sigma theta 0.01 kg m-3
'ocean_mixed_layer_thickness_defined_by_sigma_theta' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 169 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 1 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Sea surface height
'sea_surface_height_above_geoid' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 1 ;
	}
#Heat flux correction
'heat_flux_correction' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Convective precipitation (water)
'lwe_thickness_of_convective_precipitation_amount' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 10 ;
	}
#Nitrogen dioxide mass mixing ratio
'mass_fraction_of_nitrogen_dioxide_in_air' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 5 ;
	 is_chemical = 1 ;
	}
#Sulphur dioxide mass mixing ratio
'mass_fraction_of_sulfur_dioxide_in_air' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 8 ;
	 is_chemical = 1 ;
	}
#Carbon monoxide mass mixing ratio
'mass_fraction_of_carbon_monoxide_in_air' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 4 ;
	 is_chemical = 1 ;
	}
#Ozone mass mixing ratio (full chemistry scheme)
'mass_fraction_of_ozone_in_air' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 0 ;
	 is_chemical = 1 ;
}
