# CARRA/CERRA local

codetable[2] suiteName "grib2/crra_suiteName.table" : dump;
alias crraSuiteID = suiteName;

ksec1expver[4] experimentVersionNumber = "0002" : dump;
alias marsExpver = experimentVersionNumber ;
