# Automatically generated by ./create_def.pl, do not edit
#Surface runoff
'sro' = {
	 localTablesVersion = 1 ;
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 202 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Sub-surface runoff
'ssro' = {
	 localTablesVersion = 1 ;
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 204 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Wind speed
'ws' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 100 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Wind speed
'ws' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 200 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#UV visible albedo for direct radiation (climatological)
'aluvp' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 193 ;
	 typeOfGeneratingProcess = 9 ;
	}
#UV visible albedo for diffuse radiation (climatological)
'aluvd' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 192 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Near IR albedo for direct radiation (climatological)
'alnip' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 193 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Near IR albedo for diffuse radiation (climatological)
'alnid' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 192 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Snow albedo
'asn' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 192 ;
	}
#Snow evaporation
'es' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 197 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Snowmelt
'smlt' = {
	 localTablesVersion = 1 ;
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 203 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#U component of wind
'u' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 100 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#U component of wind
'u' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 200 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#V component of wind
'v' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 100 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#V component of wind
'v' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 200 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Snow depth
'sd' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 254 ;
	}
#Large-scale precipitation
'lsp' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 196 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Convective precipitation
'cp' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 195 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Snowfall
'sf' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 198 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Logarithm of surface pressure
'lnsp' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 25 ;
	 typeOfFirstFixedSurface = 105 ;
	}
#Total cloud cover
'tcc' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 192 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Albedo (climatological)
'al' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 193 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Evaporation
'e' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 199 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Low cloud cover
'lcc' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 193 ;
	}
#Medium cloud cover
'mcc' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 194 ;
	}
#High cloud cover
'hcc' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 195 ;
	}
#Skin reservoir content
'src' = {
	 localTablesVersion = 1 ;
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 205 ;
	}
#Runoff
'ro' = {
	 localTablesVersion = 1 ;
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 201 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Total column ozone
'tco3' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 192 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total precipitation
'tp' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 193 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Convective snowfall
'csf' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 201 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Large-scale snowfall
'lsf' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 202 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Forecast albedo
'fal' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 193 ;
	}
#UV visible albedo for direct radiation, isotropic component (climatological)
'aluvpi' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 195 ;
	 typeOfGeneratingProcess = 9 ;
	}
#UV visible albedo for direct radiation, volumetric component (climatological)
'aluvpv' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 196 ;
	 typeOfGeneratingProcess = 9 ;
	}
#UV visible albedo for direct radiation, geometric component (climatological)
'aluvpg' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 194 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Near IR albedo for direct radiation, isotropic component (climatological)
'alnipi' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 195 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Near IR albedo for direct radiation, volumetric component (climatological)
'alnipv' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 196 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Near IR albedo for direct radiation, geometric component (climatological)
'alnipg' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 194 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Accumulated Carbon Dioxide Net Ecosystem Exchange
'aco2nee' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 59 ;
	 constituentType = 3 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Accumulated Carbon Dioxide Gross Primary Production
'aco2gpp' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 60 ;
	 constituentType = 3 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Accumulated Carbon Dioxide Ecosystem Respiration
'aco2rec' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 61 ;
	 constituentType = 3 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Carbon dioxide net ecosystem exchange flux
'fco2nee' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 59 ;
	 constituentType = 3 ;
	}
#Carbon dioxide gross primary production flux
'fco2gpp' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 60 ;
	 constituentType = 3 ;
	}
#Carbon dioxide ecosystem respiration flux
'fco2rec' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 61 ;
	 constituentType = 3 ;
	}
#Accumulated freezing rain
'fzra' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 194 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Potential evaporation
'pev' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 200 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated eastward ozone flux
'tvioze' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 78 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 constituentType = 0 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated northward ozone flux
'tviozn' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 79 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 constituentType = 0 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated divergence of ozone flux
'tviozd' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 80 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 constituentType = 0 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated net source of ozone
'tvions' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 81 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 constituentType = 0 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-mean carbon dioxide net ecosystem exchange flux
'avg_fco2nee' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 59 ;
	 constituentType = 3 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean carbon dioxide gross primary production flux
'avg_fco2gpp' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 60 ;
	 constituentType = 3 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean carbon dioxide ecosystem respiration flux
'avg_fco2rec' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 61 ;
	 constituentType = 3 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean U component of wind
'avg_u' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 200 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean U component of wind
'avg_u' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 100 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean V component of wind
'avg_v' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 200 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean V component of wind
'avg_v' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 100 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean logarithm of surface pressure
'avg_lnsp' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 25 ;
	 typeOfFirstFixedSurface = 105 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total cloud cover
'avg_tcc' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Covariance between 2-metre temperature and volumetric soil water layer 1
'covar_t2m_swvl1' = {
	 localTablesVersion = 1 ;
	 discipline = 254 ;
	 parameterCategory = 254 ;
	 parameterNumber = 192 ;
	 typeOfFirstFixedSurface = 254 ;
	}
#Covariance between 2-metre relative humidity and volumetric soil water layer 1
'covar_rh2m_swvl1' = {
	 localTablesVersion = 1 ;
	 discipline = 254 ;
	 parameterCategory = 254 ;
	 parameterNumber = 193 ;
	 typeOfFirstFixedSurface = 254 ;
	}
#Covariance between surface soil moisture and volumetric soil water layer 1
'covar_ssm_swvl1' = {
	 localTablesVersion = 1 ;
	 discipline = 254 ;
	 parameterCategory = 254 ;
	 parameterNumber = 194 ;
	 typeOfFirstFixedSurface = 254 ;
	}
#Covariance between 2-metre temperature and volumetric soil water layer 2
'covar_t2m_swvl2' = {
	 localTablesVersion = 1 ;
	 discipline = 254 ;
	 parameterCategory = 254 ;
	 parameterNumber = 195 ;
	 typeOfFirstFixedSurface = 254 ;
	}
#Covariance between 2-metre relative humidity and volumetric soil water layer 2
'covar_rh2m_swvl2' = {
	 localTablesVersion = 1 ;
	 discipline = 254 ;
	 parameterCategory = 254 ;
	 parameterNumber = 196 ;
	 typeOfFirstFixedSurface = 254 ;
	}
#Covariance between surface soil moisture and volumetric soil water layer 2
'covar_ssm_swvl2' = {
	 localTablesVersion = 1 ;
	 discipline = 254 ;
	 parameterCategory = 254 ;
	 parameterNumber = 197 ;
	 typeOfFirstFixedSurface = 254 ;
	}
#Covariance between 2-metre temperature and volumetric soil water layer 3
'covar_t2m_swvl3' = {
	 localTablesVersion = 1 ;
	 discipline = 254 ;
	 parameterCategory = 254 ;
	 parameterNumber = 198 ;
	 typeOfFirstFixedSurface = 254 ;
	}
#Covariance between 2-metre relative humidity and volumetric soil water layer 3
'covar_rh2m_swvl3' = {
	 localTablesVersion = 1 ;
	 discipline = 254 ;
	 parameterCategory = 254 ;
	 parameterNumber = 199 ;
	 typeOfFirstFixedSurface = 254 ;
	}
#Covariance between surface soil moisture and volumetric soil water layer 3
'covar_ssm_swvl3' = {
	 localTablesVersion = 1 ;
	 discipline = 254 ;
	 parameterCategory = 254 ;
	 parameterNumber = 200 ;
	 typeOfFirstFixedSurface = 254 ;
	}
#Covariance between 2-metre temperature and soil temperature layer 1
'covar_t2m_stl1' = {
	 localTablesVersion = 1 ;
	 discipline = 254 ;
	 parameterCategory = 254 ;
	 parameterNumber = 201 ;
	 typeOfFirstFixedSurface = 254 ;
	}
#Covariance between 2-metre relative humidity and soil temperature layer 1
'covar_rh2m_stl1' = {
	 localTablesVersion = 1 ;
	 discipline = 254 ;
	 parameterCategory = 254 ;
	 parameterNumber = 202 ;
	 typeOfFirstFixedSurface = 254 ;
	}
#Covariance between 2-metre temperature and soil temperature layer 2
'covar_t2m_stl2' = {
	 localTablesVersion = 1 ;
	 discipline = 254 ;
	 parameterCategory = 254 ;
	 parameterNumber = 203 ;
	 typeOfFirstFixedSurface = 254 ;
	}
#Covariance between 2-metre relative humidity and soil temperature layer 2
'covar_rh2m_stl2' = {
	 localTablesVersion = 1 ;
	 discipline = 254 ;
	 parameterCategory = 254 ;
	 parameterNumber = 204 ;
	 typeOfFirstFixedSurface = 254 ;
	}
#Covariance between 2-metre temperature and soil temperature layer 3
'covar_t2m_stl3' = {
	 localTablesVersion = 1 ;
	 discipline = 254 ;
	 parameterCategory = 254 ;
	 parameterNumber = 205 ;
	 typeOfFirstFixedSurface = 254 ;
	}
#Covariance between 2-metre relative humidity and soil temperature layer 3
'covar_rh2m_stl3' = {
	 localTablesVersion = 1 ;
	 discipline = 254 ;
	 parameterCategory = 254 ;
	 parameterNumber = 206 ;
	 typeOfFirstFixedSurface = 254 ;
	}
#Covariance between 2-metre temperature and temperature of snow layer 1
'covar_t2m_tsn1' = {
	 localTablesVersion = 1 ;
	 discipline = 254 ;
	 parameterCategory = 254 ;
	 parameterNumber = 207 ;
	 typeOfFirstFixedSurface = 254 ;
	}
#Covariance between 2-metre relative humidity and temperature of snow layer 1
'covar_rh2m_tsn1' = {
	 localTablesVersion = 1 ;
	 discipline = 254 ;
	 parameterCategory = 254 ;
	 parameterNumber = 208 ;
	 typeOfFirstFixedSurface = 254 ;
	}
#Covariance between 2-metre temperature and temperature of snow layer 2
'covar_t2m_tsn2' = {
	 localTablesVersion = 1 ;
	 discipline = 254 ;
	 parameterCategory = 254 ;
	 parameterNumber = 209 ;
	 typeOfFirstFixedSurface = 254 ;
	}
#Covariance between 2-metre relative humidity and temperature of snow layer 2
'covar_rh2m_tsn2' = {
	 localTablesVersion = 1 ;
	 discipline = 254 ;
	 parameterCategory = 254 ;
	 parameterNumber = 210 ;
	 typeOfFirstFixedSurface = 254 ;
	}
#Covariance between 2-metre temperature and temperature of snow layer 3
'covar_t2m_tsn3' = {
	 localTablesVersion = 1 ;
	 discipline = 254 ;
	 parameterCategory = 254 ;
	 parameterNumber = 211 ;
	 typeOfFirstFixedSurface = 254 ;
	}
#Covariance between 2-metre relative humidity and temperature of snow layer 3
'covar_rh2m_tsn3' = {
	 localTablesVersion = 1 ;
	 discipline = 254 ;
	 parameterCategory = 254 ;
	 parameterNumber = 212 ;
	 typeOfFirstFixedSurface = 254 ;
	}
#Snow thickness over sea ice
'sisnthick' = {
	 localTablesVersion = 1 ;
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 192 ;
	 typeOfFirstFixedSurface = 173 ;
	 typeOfSecondFixedSurface = 175 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Sea ice salinity
'icesalt' = {
	 localTablesVersion = 1 ;
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 193 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Time-mean snow thickness over sea ice
'avg_sisnthick' = {
	 localTablesVersion = 1 ;
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 192 ;
	 typeOfFirstFixedSurface = 173 ;
	 typeOfSecondFixedSurface = 175 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean Sea ice salinity
'avg_icesalt' = {
	 localTablesVersion = 1 ;
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 193 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
}
