# (C) Copyright 2005- ECMWF.
# Hooks post meta-data for DestinE (productionStatusOfProcessedData=12)

# conceptsDir2 --> datasetForLocal
concept gridSpecification(unknown, "gridSpecificationConcept.def", conceptsDir2, conceptsDir1): no_copy, read_only, dump;
concept destineOrigin(unknown, "destineOriginConcept.def", conceptsDir2, conceptsDir1): no_copy, dump;

# ECC-1794: DestinE data does not have the domain key
unalias mars.domain;

# ECC-1796: stepRange indexing for DestinE ExtremesDT and On-Demand ExtremesDT data
if ( defined(dataset) && dataset isnot "climate-dt" ) {
    alias mars.step=stepRange;
}
