# Automatically generated by ./create_def.pl, do not edit
#Instantaneous eastward turbulent surface stress
'229' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 38 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Instantaneous northward turbulent surface stress
'230' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 37 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Minimum dew point depression
'260006' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 14 ;
	}
#Maximum relative humidity
'260023' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 27 ;
	}
#Maximum absolute humidity
'260024' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 28 ;
	}
#Maximum wind speed
'260064' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 21 ;
	}
#Net long wave radiation flux (surface)
'260095' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 0 ;
	}
#Net long wave radiation flux (top of atmosphere)
'260096' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 1 ;
	}
#Maximum snow albedo
'260161' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 17 ;
	}
#Volumetric soil moisture content
'260185' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 9 ;
	}
#Upper layer soil temperature
'260201' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 1 ;
	}
#Upper layer soil moisture
'260202' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 2 ;
	}
#Lower layer soil moisture
'260203' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 3 ;
	}
#Bottom layer soil temperature
'260204' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 4 ;
	}
#Liquid volumetric soil moisture (non-frozen)
'260205' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 5 ;
	}
#Transpiration stress-onset (soil moisture)
'260207' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 7 ;
	}
#Direct evaporation cease (soil moisture)
'260208' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 8 ;
	}
#Soil porosity
'260209' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 9 ;
	}
#Evaporation in the last 6 hours
'260265' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 79 ;
	 typeOfFirstFixedSurface = 1 ;
	 indicatorOfUnitForTimeRange = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	 lengthOfTimeRange = 6 ;
	}
#Time-mean evapotranspiration rate in the last 24h
'260435' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 39 ;
	 indicatorOfUnitForTimeRange = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	 lengthOfTimeRange = 24 ;
	}
#Time-integrated potential evapotranspiration rate in the last 24h
'260437' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 40 ;
	 indicatorOfUnitForTimeRange = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	 lengthOfTimeRange = 24 ;
	}
#Time-mean potential evapotranspiration rate in the last 24h
'260438' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 40 ;
	 indicatorOfUnitForTimeRange = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	 lengthOfTimeRange = 24 ;
	}
#Time-mean volumetric soil moisture
'260440' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	 indicatorOfUnitForTimeRange = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	 lengthOfTimeRange = 24 ;
	}
#Time-integrated water runoff and drainage rate in the last 24h
'260444' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 42 ;
	 indicatorOfUnitForTimeRange = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	 lengthOfTimeRange = 24 ;
	}
#Time-mean water runoff and drainage rate in the last 24h
'260445' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 42 ;
	 indicatorOfUnitForTimeRange = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	 lengthOfTimeRange = 24 ;
	}
#Time-mean snow depth water equivalent
'260472' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 60 ;
	 indicatorOfUnitForTimeRange = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	 lengthOfTimeRange = 24 ;
	}
#Time-mean skin temperature
'260473' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 17 ;
	 indicatorOfUnitForTimeRange = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	 lengthOfTimeRange = 24 ;
	}
#Time-integrated snow melt rate in the last 24h
'260476' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 41 ;
	 indicatorOfUnitForTimeRange = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	 lengthOfTimeRange = 24 ;
	}
#Upward sea water velocity
'262507' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 27 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	}
#Time-mean upward sea water velocity
'263507' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 27 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Maximum temperature
'3015' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	}
#Minimum temperature
'3016' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 5 ;
	}
#Envelop-maximum individual wave height
'140218' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 24 ;
	}
#Soil moisture
'228039' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 22 ;
	}
#Soil temperature
'228139' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
}
