#Minimum dew point depression
#Minimum dew point depression
'mindpd' = {
 discipline = 0 ;
 parameterCategory = 0 ;
 parameterNumber = 14 ;
}
#Minimum dew point depression
'mindpd' = {
 discipline = 0 ;
 parameterCategory = 0 ;
 parameterNumber = 14 ;
}
#Maximum relative humidity
'maxrh' = {
 discipline = 0 ;
 parameterCategory = 1 ;
 parameterNumber = 27 ;
}
#Maximum absolute humidity
'maxah' = {
 discipline = 0 ;
 parameterCategory = 1 ;
 parameterNumber = 28 ;
}
#Maximum wind speed
'maxgust' = {
 discipline = 0 ;
 parameterCategory = 2 ;
 parameterNumber = 21 ;
}
#Net long wave radiation flux (surface)
'nlwrs' = {
 discipline = 0 ;
 parameterCategory = 5 ;
 parameterNumber = 0 ;
}
#Net long wave radiation flux (top of atmosphere)
'nlwrt' = {
 discipline = 0 ;
 parameterCategory = 5 ;
 parameterNumber = 1 ;
}
#Maximum snow albedo
'mxsalb' = {
 discipline = 0 ;
 parameterCategory = 19 ;
 parameterNumber = 17 ;
}
#Soil temperature
'sot' = {
 discipline = 2 ;
 parameterCategory = 3 ;
 parameterNumber = 18 ;
}
#Minimum dew point depression
'mindpd' = {
 discipline = 0 ;
 parameterCategory = 0 ;
 parameterNumber = 14 ;
}
#Maximum relative humidity
'maxrh' = {
 discipline = 0 ;
 parameterCategory = 1 ;
 parameterNumber = 27 ;
}
#Maximum absolute humidity
'maxah' = {
 discipline = 0 ;
 parameterCategory = 1 ;
 parameterNumber = 28 ;
}
#Maximum wind speed
'maxgust' = {
 discipline = 0 ;
 parameterCategory = 2 ;
 parameterNumber = 21 ;
}
#Net long wave radiation flux (surface)
'nlwrs' = {
 discipline = 0 ;
 parameterCategory = 5 ;
 parameterNumber = 0 ;
}
#Net long wave radiation flux (top of atmosphere)
'nlwrt' = {
 discipline = 0 ;
 parameterCategory = 5 ;
 parameterNumber = 1 ;
}
#Maximum snow albedo
'mxsalb' = {
 discipline = 0 ;
 parameterCategory = 19 ;
 parameterNumber = 17 ;
}
#Soil temperature
'sot' = {
 discipline = 2 ;
 parameterCategory = 3 ;
 parameterNumber = 18 ;
}
#Soil moisture
'som' = {
 discipline = 2 ;
 parameterCategory = 3 ;
 parameterNumber = 19 ;
}
#Minimum dew point depression
'mindpd' = {
 discipline = 0 ;
 parameterCategory = 0 ;
 parameterNumber = 14 ;
}
#Maximum relative humidity
'maxrh' = {
 discipline = 0 ;
 parameterCategory = 1 ;
 parameterNumber = 27 ;
}
#Maximum absolute humidity
'maxah' = {
 discipline = 0 ;
 parameterCategory = 1 ;
 parameterNumber = 28 ;
}
#Maximum wind speed
'maxgust' = {
 discipline = 0 ;
 parameterCategory = 2 ;
 parameterNumber = 21 ;
}
#Net long wave radiation flux (surface)
'nlwrs' = {
 discipline = 0 ;
 parameterCategory = 5 ;
 parameterNumber = 0 ;
}
#Net long wave radiation flux (top of atmosphere)
'nlwrt' = {
 discipline = 0 ;
 parameterCategory = 5 ;
 parameterNumber = 1 ;
}
#Maximum snow albedo
'mxsalb' = {
 discipline = 0 ;
 parameterCategory = 19 ;
 parameterNumber = 17 ;
}
#Soil temperature
'sot' = {
 discipline = 2 ;
 parameterCategory = 3 ;
 parameterNumber = 18 ;
}
#Soil moisture
'som' = {
 discipline = 2 ;
 parameterCategory = 3 ;
 parameterNumber = 19 ;
}
