# Brightness temperature for long window 4Dvar system

unsigned[4] channelNumber : dump ;
alias mars.channel = channelNumber;

unsigned[1] numberOfFrequencies : dump ;
alias totalNumberOfFrequencies =  numberOfFrequencies ;

# Hours
unsigned[2] offsetToEndOf4DvarWindow : dump;
unsigned[2] lengthOf4DvarWindow : dump;
alias anoffset=offsetToEndOf4DvarWindow;
