# (C) Copyright 2005- ECMWF.
#


unsigned[2] systemNumber : dump ;
unsigned[2] methodNumber : dump ;
alias system=systemNumber;
alias method=methodNumber;

alias local.systemNumber=systemNumber;
alias local.methodNumber=methodNumber;

