# Automatically generated by ./create_def.pl, do not edit
#Maximum temperature at 2 metres in the last 6 hours
'mx2t6' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 15 ;
	 scaleFactorOfFirstFixedSurface = 1 ;
	 indicatorOfUnitForTimeRange = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	 lengthOfTimeRange = 6 ;
	}
#Minimum temperature at 2 metres in the last 6 hours
'mn2t6' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 15 ;
	 scaleFactorOfFirstFixedSurface = 1 ;
	 indicatorOfUnitForTimeRange = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	 lengthOfTimeRange = 6 ;
	}
#2 metre temperature
't2m' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 15 ;
	 scaleFactorOfFirstFixedSurface = 1 ;
	}
#2 metre dewpoint temperature
'd2m' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 15 ;
	 scaleFactorOfFirstFixedSurface = 1 ;
}
