# Automatically generated by ./create_def.pl, do not edit
#Soil temperature level 1
'surface_temperature' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 139 ;
	}
#Soil wetness level 1
'lwe_thickness_of_soil_moisture_content' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 140 ;
	}
#Snow depth
'lwe_thickness_of_surface_snow_amount' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 254 ;
	}
#Large-scale precipitation
'lwe_thickness_of_stratiform_precipitation_amount' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 196 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Convective precipitation
'lwe_thickness_of_convective_precipitation_amount' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 195 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Snowfall
'lwe_thickness_of_snowfall_amount' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 198 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Tendency of surface pressure
'tendency_of_surface_air_pressure' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 158 ;
	}
#Total cloud cover
'cloud_area_fraction' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 192 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Albedo (climatological)
'surface_albedo' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 193 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Evaporation
'lwe_thickness_of_water_evaporation_amount' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 199 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Convective cloud cover
'convective_cloud_area_fraction' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 185 ;
	}
#Total column ozone
'atmosphere_mass_content_of_ozone' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 192 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Hydrogen peroxide
'mass_fraction_of_hydrogen_peroxide_in_air' = {
	 discipline = 192 ;
	 parameterCategory = 217 ;
	 parameterNumber = 3 ;
	}
#Methane (chemistry)
'mass_fraction_of_methane_in_air' = {
	 discipline = 192 ;
	 parameterCategory = 217 ;
	 parameterNumber = 4 ;
	}
#Nitric acid
'mass_fraction_of_nitric_acid_in_air' = {
	 discipline = 192 ;
	 parameterCategory = 217 ;
	 parameterNumber = 6 ;
	}
#Ethene
'mass_fraction_of_ethene_in_air' = {
	 discipline = 192 ;
	 parameterCategory = 217 ;
	 parameterNumber = 10 ;
	}
#Peroxyacetyl nitrate
'mass_fraction_of_peroxyacetyl_nitrate_in_air' = {
	 discipline = 192 ;
	 parameterCategory = 217 ;
	 parameterNumber = 13 ;
	}
#Isoprene
'mass_fraction_of_isoprene_in_air' = {
	 discipline = 192 ;
	 parameterCategory = 217 ;
	 parameterNumber = 16 ;
	}
#Dimethyl sulfide
'mass_fraction_of_dimethyl_sulfide_in_air' = {
	 discipline = 192 ;
	 parameterCategory = 217 ;
	 parameterNumber = 18 ;
	}
#Hydroxyl radical
'mass_fraction_of_hydroxyl_radical_in_air' = {
	 discipline = 192 ;
	 parameterCategory = 217 ;
	 parameterNumber = 30 ;
	}
#Nitrate radical
'mass_fraction_of_nitrate_radical_in_air' = {
	 discipline = 192 ;
	 parameterCategory = 217 ;
	 parameterNumber = 32 ;
	}
#Dinitrogen pentoxide
'mass_fraction_of_dinitrogen_pentoxide_in_air' = {
	 discipline = 192 ;
	 parameterCategory = 217 ;
	 parameterNumber = 33 ;
	}
#Methanol
'mass_fraction_of_methanol_in_air' = {
	 discipline = 192 ;
	 parameterCategory = 217 ;
	 parameterNumber = 42 ;
	}
#Formic acid
'mass_fraction_of_formic_acid_in_air' = {
	 discipline = 192 ;
	 parameterCategory = 217 ;
	 parameterNumber = 43 ;
	}
#Ethane
'mass_fraction_of_ethane_in_air' = {
	 discipline = 192 ;
	 parameterCategory = 217 ;
	 parameterNumber = 45 ;
	}
#Ethanol
'mass_fraction_of_ethanol_in_air' = {
	 discipline = 192 ;
	 parameterCategory = 217 ;
	 parameterNumber = 46 ;
	}
#Propane
'mass_fraction_of_propane_in_air' = {
	 discipline = 192 ;
	 parameterCategory = 217 ;
	 parameterNumber = 47 ;
	}
#Propene
'mass_fraction_of_propene_in_air' = {
	 discipline = 192 ;
	 parameterCategory = 217 ;
	 parameterNumber = 48 ;
	}
#Terpenes
'mass_fraction_of_terpenes_in_air' = {
	 discipline = 192 ;
	 parameterCategory = 217 ;
	 parameterNumber = 49 ;
	}
#Chlorine dioxide
'mass_fraction_of_chlorine_dioxide_in_air' = {
	 discipline = 192 ;
	 parameterCategory = 217 ;
	 parameterNumber = 63 ;
	}
#Chlorine nitrate
'mass_fraction_of_chlorine_nitrate_in_air' = {
	 discipline = 192 ;
	 parameterCategory = 217 ;
	 parameterNumber = 64 ;
	}
#Hypochlorous acid
'mass_fraction_of_hypochlorous_acid_in_air' = {
	 discipline = 192 ;
	 parameterCategory = 217 ;
	 parameterNumber = 65 ;
	}
#Hydrogen bromide
'mass_fraction_of_hydrogen_bromide_in_air' = {
	 discipline = 192 ;
	 parameterCategory = 217 ;
	 parameterNumber = 68 ;
	}
#Hypobromous acid
'mass_fraction_of_hypobromous_acid_in_air' = {
	 discipline = 192 ;
	 parameterCategory = 217 ;
	 parameterNumber = 70 ;
	}
#Methyl chloride
'mass_fraction_of_methyl_chloride_in_air' = {
	 discipline = 192 ;
	 parameterCategory = 217 ;
	 parameterNumber = 78 ;
	}
#Methyl bromide
'mass_fraction_of_methyl_bromide_in_air' = {
	 discipline = 192 ;
	 parameterCategory = 217 ;
	 parameterNumber = 80 ;
	}
#Sulfuric acid
'mass_fraction_of_sulfuric_acid_in_air' = {
	 discipline = 192 ;
	 parameterCategory = 217 ;
	 parameterNumber = 85 ;
	}
#Nitrous acid
'mass_fraction_of_nitrous_acid_in_air' = {
	 discipline = 192 ;
	 parameterCategory = 217 ;
	 parameterNumber = 86 ;
	}
#Acetic acid
'mass_fraction_of_acetic_acid_in_air' = {
	 discipline = 192 ;
	 parameterCategory = 217 ;
	 parameterNumber = 96 ;
	}
#Chlorine monoxide
'mass_fraction_of_chlorine_monoxide_in_air' = {
	 discipline = 192 ;
	 parameterCategory = 217 ;
	 parameterNumber = 174 ;
	}
#Bromine monoxide
'mass_fraction_of_bromine_monoxide_in_air' = {
	 discipline = 192 ;
	 parameterCategory = 217 ;
	 parameterNumber = 176 ;
	}
#Bromine nitrate
'mass_fraction_of_bromine_nitrate_in_air' = {
	 discipline = 192 ;
	 parameterCategory = 217 ;
	 parameterNumber = 194 ;
	}
#Hydrogen chloride
'mass_fraction_of_hydrogen_chloride_in_air' = {
	 discipline = 192 ;
	 parameterCategory = 217 ;
	 parameterNumber = 200 ;
	}
#Total column hydrogen peroxide
'atmosphere_mass_content_of_hydrogen_peroxide' = {
	 discipline = 192 ;
	 parameterCategory = 218 ;
	 parameterNumber = 3 ;
	}
#Total column methane
'atmosphere_mass_content_of_methane' = {
	 discipline = 192 ;
	 parameterCategory = 218 ;
	 parameterNumber = 4 ;
	}
#Total column nitric acid
'atmosphere_mass_content_of_nitric_acid' = {
	 discipline = 192 ;
	 parameterCategory = 218 ;
	 parameterNumber = 6 ;
	}
#Total column ethene
'atmosphere_mass_content_of_ethene' = {
	 discipline = 192 ;
	 parameterCategory = 218 ;
	 parameterNumber = 10 ;
	}
#Total column  peroxyacetyl nitrate
'atmosphere_mass_content_of_peroxyacetyl_nitrate' = {
	 discipline = 192 ;
	 parameterCategory = 218 ;
	 parameterNumber = 13 ;
	}
#Total column  isoprene
'atmosphere_mass_content_of_isoprene' = {
	 discipline = 192 ;
	 parameterCategory = 218 ;
	 parameterNumber = 16 ;
	}
#Total column dimethyl sulfide
'atmosphere_mass_content_of_dimethyl_sulfide' = {
	 discipline = 192 ;
	 parameterCategory = 218 ;
	 parameterNumber = 18 ;
	}
#Total column ammonia
'atmosphere_mass_content_of_ammonia' = {
	 discipline = 192 ;
	 parameterCategory = 218 ;
	 parameterNumber = 19 ;
	}
#Total column  sulfate
'atmosphere_mass_content_of_sulfate' = {
	 discipline = 192 ;
	 parameterCategory = 218 ;
	 parameterNumber = 20 ;
	}
#Total column nitrogen monoxide
'atmosphere_mass_content_of_nitrogen_monoxide' = {
	 discipline = 192 ;
	 parameterCategory = 218 ;
	 parameterNumber = 27 ;
	}
#Total column hydroxyl radical
'atmosphere_mass_content_of_hydroxyl_radical' = {
	 discipline = 192 ;
	 parameterCategory = 218 ;
	 parameterNumber = 30 ;
	}
#Total column nitrate radical
'atmosphere_mass_content_of_nitrate_radical' = {
	 discipline = 192 ;
	 parameterCategory = 218 ;
	 parameterNumber = 32 ;
	}
#Total column dinitrogen pentoxide
'atmosphere_mass_content_of_dinitrogen_pentoxide' = {
	 discipline = 192 ;
	 parameterCategory = 218 ;
	 parameterNumber = 33 ;
	}
#Total column methanol
'atmosphere_mass_content_of_methanol' = {
	 discipline = 192 ;
	 parameterCategory = 218 ;
	 parameterNumber = 42 ;
	}
#Total column formic acid
'atmosphere_mass_content_of_formic_acid' = {
	 discipline = 192 ;
	 parameterCategory = 218 ;
	 parameterNumber = 43 ;
	}
#Total column  ethane
'atmosphere_mass_content_of_ethane' = {
	 discipline = 192 ;
	 parameterCategory = 218 ;
	 parameterNumber = 45 ;
	}
#Total column ethanol
'atmosphere_mass_content_of_ethanol' = {
	 discipline = 192 ;
	 parameterCategory = 218 ;
	 parameterNumber = 46 ;
	}
#Total column propane
'atmosphere_mass_content_of_propane' = {
	 discipline = 192 ;
	 parameterCategory = 218 ;
	 parameterNumber = 47 ;
	}
#Total column propene
'atmosphere_mass_content_of_propene' = {
	 discipline = 192 ;
	 parameterCategory = 218 ;
	 parameterNumber = 48 ;
	}
#Total column terpenes
'atmosphere_mass_content_of_terpenes' = {
	 discipline = 192 ;
	 parameterCategory = 218 ;
	 parameterNumber = 49 ;
	}
#Total column of chlorine dioxide
'atmosphere_mass_content_of_chlorine_dioxide' = {
	 discipline = 192 ;
	 parameterCategory = 218 ;
	 parameterNumber = 63 ;
	}
#Total column of chlorine nitrate
'atmosphere_mass_content_of_chlorine_nitrate' = {
	 discipline = 192 ;
	 parameterCategory = 218 ;
	 parameterNumber = 64 ;
	}
#Total column of hypochlorous acid
'atmosphere_mass_content_of_hypochlorous_acid' = {
	 discipline = 192 ;
	 parameterCategory = 218 ;
	 parameterNumber = 65 ;
	}
#Total column of hydrogen bromide
'atmosphere_mass_content_of_hydrogen_bromide' = {
	 discipline = 192 ;
	 parameterCategory = 218 ;
	 parameterNumber = 68 ;
	}
#Total column of hypobromous acid
'atmosphere_mass_content_of_hypobromous_acid' = {
	 discipline = 192 ;
	 parameterCategory = 218 ;
	 parameterNumber = 70 ;
	}
#Total column of methyl chloride
'atmosphere_mass_content_of_methyl_chloride' = {
	 discipline = 192 ;
	 parameterCategory = 218 ;
	 parameterNumber = 78 ;
	}
#Total column of methyl bromide
'atmosphere_mass_content_of_methyl_bromide' = {
	 discipline = 192 ;
	 parameterCategory = 218 ;
	 parameterNumber = 80 ;
	}
#Total column of nitrous acid
'atmosphere_mass_content_of_nitrous_acid' = {
	 discipline = 192 ;
	 parameterCategory = 218 ;
	 parameterNumber = 86 ;
	}
#Total column of acetic acid
'atmosphere_mass_content_of_acetic_acid' = {
	 discipline = 192 ;
	 parameterCategory = 218 ;
	 parameterNumber = 96 ;
	}
#Total column of chlorine monoxide
'atmosphere_mass_content_of_chlorine_monoxide' = {
	 discipline = 192 ;
	 parameterCategory = 218 ;
	 parameterNumber = 174 ;
	}
#Total column of bromine monoxide
'atmosphere_mass_content_of_bromine_monoxide' = {
	 discipline = 192 ;
	 parameterCategory = 218 ;
	 parameterNumber = 176 ;
	}
#Total column of bromine nitrate
'atmosphere_mass_content_of_bromine_nitrate' = {
	 discipline = 192 ;
	 parameterCategory = 218 ;
	 parameterNumber = 194 ;
	}
#Total column of hydrogen chloride
'atmosphere_mass_content_of_hydrogen_chloride' = {
	 discipline = 192 ;
	 parameterCategory = 218 ;
	 parameterNumber = 200 ;
	}
#Ocean barotropic stream function
'ocean_barotropic_streamfunction' = {
	 discipline = 192 ;
	 parameterCategory = 151 ;
	 parameterNumber = 147 ;
	}
#Carbon dioxide mass mixing ratio
'mass_fraction_of_carbon_dioxide_in_air' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 61 ;
	}
#Methane
'mass_fraction_of_methane_in_air' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 62 ;
	}
#Nitrous oxide
'mass_fraction_of_nitrous_oxide_in_air' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 63 ;
	}
#Total column Nitrous oxide
'atmosphere_mass_content_of_nitrous_oxide' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 66 ;
	}
#Formaldehyde
'mass_fraction_of_formaldehyde_in_air' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 124 ;
	}
#Total column Nitrogen dioxide
'atmosphere_mass_content_of_nitrogen_dioxide' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 125 ;
	}
#Total column Sulphur dioxide
'atmosphere_mass_content_of_sulfur_dioxide' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 126 ;
	}
#Total column Carbon monoxide
'atmosphere_mass_content_of_carbon_monoxide' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 127 ;
	}
#Total column Formaldehyde
'atmosphere_mass_content_of_formaldehyde' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 128 ;
	}
#Radon
'mass_fraction_of_radon_in_air' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 181 ;
	}
#Total column Radon
'atmosphere_mass_content_of_radon' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 183 ;
	}
#GEMS Total column ozone
'atmosphere_mass_content_of_ozone' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 206 ;
}
