# assert(local=1)
meta verificationDate       g1verificationdate(dataDate, dataTime, endStep) : read_only;
meta monthlyVerificationDate g1monthlydate(verificationDate) : dump,no_copy;
alias mars.date            = monthlyVerificationDate;
alias mars.step            = endStep;

meta verificationYear          evaluate(verificationDate/10000);
meta monthlyVerificationYear   evaluate(monthlyVerificationDate/10000);
meta verificationMonth         evaluate( (verificationDate/100)%100 );
meta monthlyVerificationMonth  evaluate( (monthlyVerificationDate/100)%100 );

alias monthlyVerificationTime = zero;

# class 3 is "er" which is 15 year re-analysis (ERA15)
# Only ERA15 has time and step
if(class != 3) {
    unalias mars.time;
    unalias mars.step;
}
alias mars.number=perturbationNumber;
