/*
 * (C) Copyright 2005- ECMWF.
 *
 * This software is licensed under the terms of the Apache Licence Version 2.0
 * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
 *
 * In applying this licence, ECMWF does not waive the privileges and immunities granted to it by
 * virtue of its status as an intergovernmental organisation nor does it submit to any jurisdiction.
 */
#include "grib_api_internal.h"

const char* grib_get_git_sha1(void)
{
    return "5ab3e6cef47510b728bba62f05c35ad23c8d6d39";
}

const char* grib_get_git_branch(void)
{
    return "HEAD";
}

const char* codes_get_build_date(void)
{
    return "2025.02.12";
}
