# (C) Copyright 2005- ECMWF.

# Definition 38 - 4D variational increments for long window 4Dvar system (inspired by local def 20)

unsigned[1] iterationNumber  : dump;
alias number=iterationNumber;

unsigned[1] totalNumberOfIterations  : dump;
alias totalNumber=totalNumberOfIterations;

alias iteration = iterationNumber;

alias local.iterationNumber =iterationNumber;
alias local.totalNumberOfIterations=totalNumberOfIterations;

# Hours
unsigned[2] offsetToEndOf4DvarWindow : dump;
unsigned[2] lengthOf4DvarWindow : dump;

alias anoffset=offsetToEndOf4DvarWindow;

