#local section ECMWF

alias localDefinitionNumber=grib3LocalSectionNumber;
template  localSection  "grib3/local.[centreForLocal:l].[grib3LocalSectionNumber:l].def";

#####################
### MARS LABELING ###
#####################

template mars_labeling "grib3/mars_labeling.82.def";
template_nofail marsKeywords "mars/eswi/grib3.[stream:s].[type:s].def";

###################
### LS LABELING ###
###################

template ls_labeling "grib3/ls_labeling.82.def";


position offsetAfterLocalSection;


