# Automatically generated by ./create_def.pl, do not edit
#Surface runoff
'm' = {
	 localTablesVersion = 1 ;
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 202 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Sub-surface runoff
'm' = {
	 localTablesVersion = 1 ;
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 204 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#UV visible albedo for direct radiation (climatological)
'(0 - 1)' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 193 ;
	 typeOfGeneratingProcess = 9 ;
	}
#UV visible albedo for diffuse radiation (climatological)
'(0 - 1)' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 192 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Near IR albedo for direct radiation (climatological)
'(0 - 1)' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 193 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Near IR albedo for diffuse radiation (climatological)
'(0 - 1)' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 192 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Snow albedo
'(0 - 1)' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 192 ;
	}
#Snow evaporation
'm of water equivalent' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 197 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Snowmelt
'm of water equivalent' = {
	 localTablesVersion = 1 ;
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 203 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Specific rain water content
'kg kg**-1' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 85 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Specific snow water content
'kg kg**-1' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 86 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Eta-coordinate vertical velocity
's**-1' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 32 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Geopotential
'm**2 s**-2' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Temperature
'K' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Specific humidity
'kg kg**-1' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Vertical velocity
'Pa s**-1' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Vorticity (relative)
's**-1' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 12 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Snow depth
'm of water equivalent' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 254 ;
	}
#Large-scale precipitation
'm' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 196 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Convective precipitation
'm' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 195 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Snowfall
'm of water equivalent' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 198 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Logarithm of surface pressure
'Numeric' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 25 ;
	 typeOfFirstFixedSurface = 105 ;
	}
#Logarithm of surface pressure
'Numeric' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 25 ;
	 typeOfFirstFixedSurface = 105 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Divergence
's**-1' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 13 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Total cloud cover
'(0 - 1)' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 192 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Albedo (climatological)
'(0 - 1)' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 193 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Evaporation
'm of water equivalent' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 199 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Low cloud cover
'(0 - 1)' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 193 ;
	}
#Medium cloud cover
'(0 - 1)' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 194 ;
	}
#High cloud cover
'(0 - 1)' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 195 ;
	}
#Skin reservoir content
'm of water equivalent' = {
	 localTablesVersion = 1 ;
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 205 ;
	}
#Ozone mass mixing ratio
'kg kg**-1' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Runoff
'm' = {
	 localTablesVersion = 1 ;
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 201 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Total column ozone
'kg m**-2' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 192 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total precipitation
'm' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 193 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Convective snowfall
'm of water equivalent' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 201 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Large-scale snowfall
'm of water equivalent' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 202 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Forecast albedo
'(0 - 1)' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 193 ;
	}
#Specific cloud liquid water content
'kg kg**-1' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 83 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Specific cloud ice water content
'kg kg**-1' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 84 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Fraction of cloud cover
'(0 - 1)' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 32 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Temperature difference
'K' = {
	 discipline = 192 ;
	 parameterCategory = 200 ;
	 parameterNumber = 130 ;
	}
#Specific humidity difference
'kg kg**-1' = {
	 discipline = 192 ;
	 parameterCategory = 200 ;
	 parameterNumber = 133 ;
	}
#Vorticity (relative) difference
's**-1' = {
	 discipline = 192 ;
	 parameterCategory = 200 ;
	 parameterNumber = 138 ;
	}
#Logarithm of surface pressure difference
'kg m**-2' = {
	 discipline = 192 ;
	 parameterCategory = 200 ;
	 parameterNumber = 152 ;
	}
#Divergence difference
's**-1' = {
	 discipline = 192 ;
	 parameterCategory = 200 ;
	 parameterNumber = 155 ;
	}
#Ozone mass mixing ratio difference
'kg kg**-1' = {
	 discipline = 192 ;
	 parameterCategory = 200 ;
	 parameterNumber = 203 ;
	}
#Snow depth
'm' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 11 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#UV visible albedo for direct radiation, isotropic component (climatological)
'(0 - 1)' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 195 ;
	 typeOfGeneratingProcess = 9 ;
	}
#UV visible albedo for direct radiation, volumetric component (climatological)
'(0 - 1)' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 196 ;
	 typeOfGeneratingProcess = 9 ;
	}
#UV visible albedo for direct radiation, geometric component (climatological)
'(0 - 1)' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 194 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Near IR albedo for direct radiation, isotropic component (climatological)
'(0 - 1)' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 195 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Near IR albedo for direct radiation, volumetric component (climatological)
'(0 - 1)' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 196 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Near IR albedo for direct radiation, geometric component (climatological)
'(0 - 1)' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 194 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Random pattern 1 for sppt
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 1 ;
	}
#Random pattern 2 for sppt
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 2 ;
	}
#Random pattern 3 for sppt
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 3 ;
	}
#Random pattern 1 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 101 ;
	}
#Random pattern 2 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 102 ;
	}
#Random pattern 3 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 103 ;
	}
#Random pattern 4 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 104 ;
	}
#Random pattern 5 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 105 ;
	}
#Random pattern 6 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 106 ;
	}
#Random pattern 7 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 107 ;
	}
#Random pattern 8 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 108 ;
	}
#Random pattern 9 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 109 ;
	}
#Random pattern 10 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 110 ;
	}
#Random pattern 11 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 111 ;
	}
#Random pattern 12 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 112 ;
	}
#Random pattern 13 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 113 ;
	}
#Random pattern 14 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 114 ;
	}
#Random pattern 15 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 115 ;
	}
#Random pattern 16 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 116 ;
	}
#Random pattern 17 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 117 ;
	}
#Random pattern 18 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 118 ;
	}
#Random pattern 19 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 119 ;
	}
#Random pattern 20 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 120 ;
	}
#Random pattern 21 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 121 ;
	}
#Random pattern 22 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 122 ;
	}
#Random pattern 23 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 123 ;
	}
#Random pattern 24 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 124 ;
	}
#Random pattern 25 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 125 ;
	}
#Random pattern 26 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 126 ;
	}
#Random pattern 27 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 127 ;
	}
#Random pattern 28 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 128 ;
	}
#Random pattern 29 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 129 ;
	}
#Random pattern 30 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 130 ;
	}
#Random pattern 31 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 131 ;
	}
#Random pattern 32 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 132 ;
	}
#Random pattern 33 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 133 ;
	}
#Random pattern 34 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 134 ;
	}
#Random pattern 35 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 135 ;
	}
#Random pattern 36 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 136 ;
	}
#Random pattern 37 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 137 ;
	}
#Random pattern 38 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 138 ;
	}
#Random pattern 39 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 139 ;
	}
#Random pattern 40 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 140 ;
	}
#Random pattern 41 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 141 ;
	}
#Random pattern 42 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 142 ;
	}
#Random pattern 43 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 143 ;
	}
#Random pattern 44 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 144 ;
	}
#Random pattern 45 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 145 ;
	}
#Random pattern 46 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 146 ;
	}
#Random pattern 47 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 147 ;
	}
#Random pattern 48 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 148 ;
	}
#Random pattern 49 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 149 ;
	}
#Random pattern 50 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 150 ;
	}
#Random pattern 51 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 151 ;
	}
#Random pattern 52 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 152 ;
	}
#Random pattern 53 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 153 ;
	}
#Random pattern 54 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 154 ;
	}
#Random pattern 55 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 155 ;
	}
#Random pattern 56 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 156 ;
	}
#Random pattern 57 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 157 ;
	}
#Random pattern 58 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 158 ;
	}
#Random pattern 59 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 159 ;
	}
#Random pattern 60 for SPP scheme
'dimensionless' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 160 ;
	}
#Accumulated Carbon Dioxide Net Ecosystem Exchange
'kg m**-2' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 59 ;
	 constituentType = 3 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Accumulated Carbon Dioxide Gross Primary Production
'kg m**-2' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 60 ;
	 constituentType = 3 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Accumulated Carbon Dioxide Ecosystem Respiration
'kg m**-2' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 61 ;
	 constituentType = 3 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Carbon dioxide net ecosystem exchange flux
'kg m**-2 s**-1' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 59 ;
	 constituentType = 3 ;
	}
#Carbon dioxide gross primary production flux
'kg m**-2 s**-1' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 60 ;
	 constituentType = 3 ;
	}
#Carbon dioxide ecosystem respiration flux
'kg m**-2 s**-1' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 61 ;
	 constituentType = 3 ;
	}
#Evaporation from the top of canopy
'm of water equivalent' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 100 ;
	}
#Evaporation from bare soil
'm of water equivalent' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 101 ;
	}
#Evaporation from open water surfaces excluding oceans
'm of water equivalent' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 102 ;
	}
#Evaporation from vegetation transpiration
'm of water equivalent' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 103 ;
	}
#Accumulated freezing rain
'm' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 194 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Potential evaporation
'm' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 200 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated eastward ozone flux
'kg m**-1' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 78 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 constituentType = 0 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated northward ozone flux
'kg m**-1' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 79 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 constituentType = 0 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated divergence of ozone flux
'kg m**-2' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 80 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 constituentType = 0 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated net source of ozone
'kg m**-2' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 81 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 constituentType = 0 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-mean carbon dioxide net ecosystem exchange flux
'kg m**-2 s**-1' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 59 ;
	 constituentType = 3 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean carbon dioxide gross primary production flux
'kg m**-2 s**-1' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 60 ;
	 constituentType = 3 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean carbon dioxide ecosystem respiration flux
'kg m**-2 s**-1' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 61 ;
	 constituentType = 3 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total cloud cover
'%' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Precipitation type
'(Code table 4.201)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 19 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Snow cover
'%' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 42 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#K index
'K' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Total totals index
'K' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Snow thickness over sea ice
'm' = {
	 localTablesVersion = 1 ;
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 192 ;
	 typeOfFirstFixedSurface = 173 ;
	 typeOfSecondFixedSurface = 175 ;
	}
#Sea ice salinity
'g kg**-1' = {
	 localTablesVersion = 1 ;
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 193 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	}
#Time-mean snow thickness over sea ice
'm' = {
	 localTablesVersion = 1 ;
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 192 ;
	 typeOfFirstFixedSurface = 173 ;
	 typeOfSecondFixedSurface = 175 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean Sea ice salinity
'g kg**-1' = {
	 localTablesVersion = 1 ;
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 193 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Sea water potential temperature
'deg C' = {
	 discipline = 192 ;
	 parameterCategory = 151 ;
	 parameterNumber = 129 ;
	}
#Sea water practical salinity
'psu' = {
	 discipline = 192 ;
	 parameterCategory = 151 ;
	 parameterNumber = 130 ;
	}
#Upward sea water velocity
'm s**-1' = {
	 discipline = 192 ;
	 parameterCategory = 151 ;
	 parameterNumber = 133 ;
	}
#Sea water sigma theta
'kg m**-3' = {
	 discipline = 192 ;
	 parameterCategory = 151 ;
	 parameterNumber = 138 ;
	}
#Surface downward eastward stress
'N m**-2' = {
	 discipline = 192 ;
	 parameterCategory = 151 ;
	 parameterNumber = 153 ;
	}
#Surface downward northward stress
'N m**-2' = {
	 discipline = 192 ;
	 parameterCategory = 151 ;
	 parameterNumber = 154 ;
	}
#Surface geopotential
'm**2 s**-2' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 51 ;
	}
#Total column vertically-integrated temperature
'K kg m**-2' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 54 ;
	}
#Total column vertically-integrated cloud liquid water
'kg m**-2' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 56 ;
	}
#Total column vertically-integrated cloud frozen water
'kg m**-2' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 57 ;
	}
#Total column vertically-integrated ozone
'kg m**-2' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 58 ;
	}
#Total column vertically-integrated energy conversion
'W m**-2' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 64 ;
	}
#Total column vertically-integrated eastward mass flux
'kg m**-1 s**-1' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 65 ;
	}
#Total column vertically-integrated northward mass flux
'kg m**-1 s**-1' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 66 ;
	}
#Total column vertically-integrated eastward kinetic energy flux
'W m**-1' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 67 ;
	}
#Total column vertically-integrated northward kinetic energy flux
'W m**-1' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 68 ;
	}
#Total column vertically-integrated eastward geopotential flux
'W m**-1' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 73 ;
	}
#Total column vertically-integrated northward geopotential flux
'W m**-1' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 74 ;
	}
#Total column vertically-integrated eastward total energy flux
'W m**-1' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 75 ;
	}
#Total column vertically-integrated northward total energy flux
'W m**-1' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 76 ;
	}
#Total column vertically-integrated eastward ozone flux
'kg m**-1 s**-1' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 77 ;
	}
#Total column vertically-integrated northward ozone flux
'kg m**-1 s**-1' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 78 ;
	}
#Total column vertically-integrated divergence of mass flux
'kg m**-2 s**-1' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 81 ;
	}
#Total column vertically-integrated divergence of kinetic energy flux
'W m**-2' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 82 ;
	}
#Total column vertically-integrated divergence of thermal energy flux
'W m**-2' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 83 ;
	}
#Total column vertically-integrated divergence of geopotential flux
'W m**-2' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 85 ;
	}
#Total column vertically-integrated divergence of total energy flux
'W m**-2' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 86 ;
	}
#Total column vertically-integrated divergence of ozone flux
'kg m**-2 s**-1' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 87 ;
	}
#Variance of geopotential
'm**4 s**-4' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 206 ;
	}
#Covariance of geopotential/temperature
'm**2 K s**-2' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 207 ;
	}
#Variance of temperature
'K**2' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 208 ;
	}
#Covariance of geopotential/specific humidity
'm**2 s**-2' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 209 ;
	}
#Covariance of temperature/specific humidity
'K' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 210 ;
	}
#Variance of specific humidity
'~' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 211 ;
	}
#Covariance of u component/geopotential
'm**3 s**-3' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 212 ;
	}
#Covariance of u component/temperature
'm s**-1 K' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 213 ;
	}
#Covariance of u component/specific humidity
'm s**-1' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 214 ;
	}
#Variance of u component
'm**2 s**-2' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 215 ;
}
