# Automatically generated by ./create_def.pl, do not edit
#Instantaneous eastward turbulent surface stress
'Instantaneous eastward turbulent surface stress' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 38 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Instantaneous northward turbulent surface stress
'Instantaneous northward turbulent surface stress' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 37 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Minimum dew point depression
'Minimum dew point depression' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 14 ;
	}
#Maximum relative humidity
'Maximum relative humidity' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 27 ;
	}
#Maximum absolute humidity
'Maximum absolute humidity' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 28 ;
	}
#Maximum wind speed
'Maximum wind speed' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 21 ;
	}
#Net long wave radiation flux (surface)
'Net long wave radiation flux (surface)' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 0 ;
	}
#Net long wave radiation flux (top of atmosphere)
'Net long wave radiation flux (top of atmosphere)' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 1 ;
	}
#Maximum snow albedo
'Maximum snow albedo' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 17 ;
	}
#Volumetric soil moisture content
'Volumetric soil moisture content' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 9 ;
	}
#Upper layer soil temperature
'Upper layer soil temperature' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 1 ;
	}
#Upper layer soil moisture
'Upper layer soil moisture' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 2 ;
	}
#Lower layer soil moisture
'Lower layer soil moisture' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 3 ;
	}
#Bottom layer soil temperature
'Bottom layer soil temperature' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 4 ;
	}
#Liquid volumetric soil moisture (non-frozen)
'Liquid volumetric soil moisture (non-frozen)' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 5 ;
	}
#Transpiration stress-onset (soil moisture)
'Transpiration stress-onset (soil moisture)' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 7 ;
	}
#Direct evaporation cease (soil moisture)
'Direct evaporation cease (soil moisture)' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 8 ;
	}
#Soil porosity
'Soil porosity' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 9 ;
	}
#Evaporation in the last 6 hours
'Evaporation in the last 6 hours' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 79 ;
	 typeOfFirstFixedSurface = 1 ;
	 indicatorOfUnitForTimeRange = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	 lengthOfTimeRange = 6 ;
	}
#Time-mean evapotranspiration rate in the last 24h
'Time-mean evapotranspiration rate in the last 24h' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 39 ;
	 indicatorOfUnitForTimeRange = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	 lengthOfTimeRange = 24 ;
	}
#Time-integrated potential evapotranspiration rate in the last 24h
'Time-integrated potential evapotranspiration rate in the last 24h' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 40 ;
	 indicatorOfUnitForTimeRange = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	 lengthOfTimeRange = 24 ;
	}
#Time-mean potential evapotranspiration rate in the last 24h
'Time-mean potential evapotranspiration rate in the last 24h' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 40 ;
	 indicatorOfUnitForTimeRange = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	 lengthOfTimeRange = 24 ;
	}
#Time-mean volumetric soil moisture
'Time-mean volumetric soil moisture' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	 indicatorOfUnitForTimeRange = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	 lengthOfTimeRange = 24 ;
	}
#Time-integrated water runoff and drainage rate in the last 24h
'Time-integrated water runoff and drainage rate in the last 24h' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 42 ;
	 indicatorOfUnitForTimeRange = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	 lengthOfTimeRange = 24 ;
	}
#Time-mean water runoff and drainage rate in the last 24h
'Time-mean water runoff and drainage rate in the last 24h' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 42 ;
	 indicatorOfUnitForTimeRange = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	 lengthOfTimeRange = 24 ;
	}
#Time-mean snow depth water equivalent
'Time-mean snow depth water equivalent' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 60 ;
	 indicatorOfUnitForTimeRange = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	 lengthOfTimeRange = 24 ;
	}
#Time-mean skin temperature
'Time-mean skin temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 17 ;
	 indicatorOfUnitForTimeRange = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	 lengthOfTimeRange = 24 ;
	}
#Time-integrated snow melt rate in the last 24h
'Time-integrated snow melt rate in the last 24h' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 41 ;
	 indicatorOfUnitForTimeRange = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	 lengthOfTimeRange = 24 ;
	}
#Upward sea water velocity
'Upward sea water velocity' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 27 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	}
#Time-mean upward sea water velocity
'Time-mean upward sea water velocity' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 27 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Maximum temperature
'Maximum temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	}
#Minimum temperature
'Minimum temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 5 ;
	}
#Envelop-maximum individual wave height
'Envelop-maximum individual wave height' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 24 ;
	}
#Soil moisture
'Soil moisture' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 22 ;
	}
#Soil temperature
'Soil temperature' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
}
