# Automatically generated by ./create_def.pl, do not edit
#Geopotential
'geopotential' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Temperature
'air_temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Specific humidity
'specific_humidity' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Vertical velocity
'lagrangian_tendency_of_air_pressure' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Vorticity (relative)
'atmosphere_relative_vorticity' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 12 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Snow depth
'lwe_thickness_of_surface_snow_amount' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 254 ;
	}
#Large-scale precipitation
'lwe_thickness_of_stratiform_precipitation_amount' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 196 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Convective precipitation
'lwe_thickness_of_convective_precipitation_amount' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 195 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Snowfall
'lwe_thickness_of_snowfall_amount' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 198 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Divergence
'divergence_of_wind' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 13 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Total cloud cover
'cloud_area_fraction' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 192 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Albedo (climatological)
'surface_albedo' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 193 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Evaporation
'lwe_thickness_of_water_evaporation_amount' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 199 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Ozone mass mixing ratio
'mass_fraction_of_ozone_in_air' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Total column ozone
'atmosphere_mass_content_of_ozone' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 192 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Snow depth
'lwe_thickness_of_surface_snow_amount' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 11 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Sea water potential temperature
'sea_water_potential_temperature' = {
	 discipline = 192 ;
	 parameterCategory = 151 ;
	 parameterNumber = 129 ;
	}
#Sea water practical salinity
'sea_water_practical_salinity' = {
	 discipline = 192 ;
	 parameterCategory = 151 ;
	 parameterNumber = 130 ;
	}
#Upward sea water velocity
'upward_sea_water_velocity' = {
	 discipline = 192 ;
	 parameterCategory = 151 ;
	 parameterNumber = 133 ;
	}
#Sea water sigma theta
'sea_water_sigma_theta' = {
	 discipline = 192 ;
	 parameterCategory = 151 ;
	 parameterNumber = 138 ;
	}
#Surface downward eastward stress
'surface_downward_eastward_stress' = {
	 discipline = 192 ;
	 parameterCategory = 151 ;
	 parameterNumber = 153 ;
	}
#Surface downward northward stress
'surface_downward_northward_stress' = {
	 discipline = 192 ;
	 parameterCategory = 151 ;
	 parameterNumber = 154 ;
}
