# (C) Copyright 2005- ECMWF.

# SECTION 3, Bit-map section
position offsetSection3;
transient section3Length=1;
meta section3Pointer section_pointer(offsetSection3,section3Length,3);

transient numberOfUnusedBitsAtEndOfSection3 = 0 : read_only;

transient tableReference = 0;

#position offsetBeforeBitmap;
meta bitmap gds_not_present_bitmap(
    missingValue,numberOfValues,
    numberOfPoints,
    latitudeOfFirstGridPoint,
    Ni,numberOfUnusedBitsAtEndOfSection3) : read_only;

#position offsetAfterBitmap;
#padtoeven padding_sec3_1(offsetSection3,section3Length);
#section_padding section3Padding;
