alias presentWeather1PresentTrend2=zero;
alias presentWeather2PresentTrend2=zero;
alias presentWeather3PresentTrend2=zero;
if (g is "NSW") {
		rename(g,nswTrend2);
		group g : dump; non_alpha na;

} else {

		if (is_in_list(g,"metar/present_weather.list")) {
				rename(g,presentWeather1Trend2);
				group g : dump; non_alpha na;
				alias presentWeather1PresentTrend2=one;
				if (is_in_list(g,"metar/present_weather.list")) {
						rename(g,presentWeather2Trend2);
						group g : dump; non_alpha na;
						alias presentWeather2PresentTrend2=one;
				}
				if (is_in_list(g,"metar/present_weather.list")) {
						rename(g,presentWeather3Trend2);
						group g : dump; non_alpha na;
						alias presentWeather3PresentTrend2=one;
				}
		}
		if (substr(g,0,1) is "-" || substr(g,0,1) is "+" || substr(g,0,2) is "FZ" || g is "//" ) {
				rename(g,wrongPresentWeatherTrend2);
				group g : dump; non_alpha na;
		}
		if (! presentWeather1PresentTrend2 && is_in_list(g,"metar/present_weather.list")) {
				rename(g,presentWeather1Trend2);
				group g : dump; non_alpha na;
				alias presentWeather1PresentTrend2=one;
		}
		if (!presentWeather2PresentTrend2 && is_in_list(g,"metar/present_weather.list")) {
						rename(g,presentWeather2Trend2);
						group g : dump; non_alpha na;
						alias presentWeather2PresentTrend2=one;
		}
		if (!presentWeather3PresentTrend2 && is_in_list(g,"metar/present_weather.list")) {
						rename(g,presentWeather3TrendTrend21);
						group g : dump; non_alpha na;
						alias presentWeather3PresentTrend2=one;
		}
}

