#########################
#
# author: Sebastien Villaume
# created: 13 May 2013
#
#########################
"all"={matchLandType=0;}
"water"={matchLandType=1;}
"rural"={matchLandType=2;}
"urban"={matchLandType=3;}
"lowveg"={matchLandType=4;}
"forest"={matchLandType=5;}
"noveg"={matchLandType=6;}
"pasture"={matchLandType=21;}
"arable"={matchLandType=22;}
"beechoak"={matchLandType=23;}
"deciduous"={matchLandType=24;}
"spruce"={matchLandType=25;}
"pine"={matchLandType=26;}
"wetland"={matchLandType=27;}
"mountain"={matchLandType=28;}
"birch"={matchLandType=29;}
"ice"={matchLandType=51;}
"snow"={matchLandType=52;}
"hslowv"={matchLandType=71;}
"hsfor"={matchLandType=72;}
"politi"={matchLandType=73;}
"mask"={matchLandType=74;}
"regional"={matchLandType=81;}
"long-range"={matchLandType=82;}
"local"={matchLandType=83;}
"zone"={matchLandType=90;}
"top"={matchLandType=100;}
"effdose"={matchLandType=150;}
"skin"={matchLandType=151;}
"thyroid"={matchLandType=152;} 
"lung"={matchLandType=153;}
"missing"={matchLandType=255;}
