# Automatically generated by ./create_def.pl, do not edit
#Surface runoff
'8' = {
	 localTablesVersion = 1 ;
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 202 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Sub-surface runoff
'9' = {
	 localTablesVersion = 1 ;
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 204 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#UV visible albedo for direct radiation (climatological)
'15' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 193 ;
	 typeOfGeneratingProcess = 9 ;
	}
#UV visible albedo for diffuse radiation (climatological)
'16' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 192 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Near IR albedo for direct radiation (climatological)
'17' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 193 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Near IR albedo for diffuse radiation (climatological)
'18' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 192 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Snow albedo
'32' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 192 ;
	}
#Snow evaporation
'44' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 197 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Snowmelt
'45' = {
	 localTablesVersion = 1 ;
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 203 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Specific rain water content
'75' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 85 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Specific snow water content
'76' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 86 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Eta-coordinate vertical velocity
'77' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 32 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Geopotential
'129' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Temperature
'130' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Specific humidity
'133' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Vertical velocity
'135' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Vorticity (relative)
'138' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 12 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Snow depth
'141' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 254 ;
	}
#Large-scale precipitation
'142' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 196 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Convective precipitation
'143' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 195 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Snowfall
'144' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 198 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Logarithm of surface pressure
'152' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 25 ;
	 typeOfFirstFixedSurface = 105 ;
	}
#Logarithm of surface pressure
'152' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 25 ;
	 typeOfFirstFixedSurface = 105 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Divergence
'155' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 13 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Total cloud cover
'164' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 192 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Albedo (climatological)
'174' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 193 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Evaporation
'182' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 199 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Low cloud cover
'186' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 193 ;
	}
#Medium cloud cover
'187' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 194 ;
	}
#High cloud cover
'188' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 195 ;
	}
#Skin reservoir content
'198' = {
	 localTablesVersion = 1 ;
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 205 ;
	}
#Ozone mass mixing ratio
'203' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Runoff
'205' = {
	 localTablesVersion = 1 ;
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 201 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Total column ozone
'206' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 192 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total precipitation
'228' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 193 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Convective snowfall
'239' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 201 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Large-scale snowfall
'240' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 202 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Forecast albedo
'243' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 193 ;
	}
#Specific cloud liquid water content
'246' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 83 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Specific cloud ice water content
'247' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 84 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Fraction of cloud cover
'248' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 32 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Temperature difference
'200130' = {
	 discipline = 192 ;
	 parameterCategory = 200 ;
	 parameterNumber = 130 ;
	}
#Specific humidity difference
'200133' = {
	 discipline = 192 ;
	 parameterCategory = 200 ;
	 parameterNumber = 133 ;
	}
#Vorticity (relative) difference
'200138' = {
	 discipline = 192 ;
	 parameterCategory = 200 ;
	 parameterNumber = 138 ;
	}
#Logarithm of surface pressure difference
'200152' = {
	 discipline = 192 ;
	 parameterCategory = 200 ;
	 parameterNumber = 152 ;
	}
#Divergence difference
'200155' = {
	 discipline = 192 ;
	 parameterCategory = 200 ;
	 parameterNumber = 155 ;
	}
#Ozone mass mixing ratio difference
'200203' = {
	 discipline = 192 ;
	 parameterCategory = 200 ;
	 parameterNumber = 203 ;
	}
#Snow depth
'3066' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 11 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#UV visible albedo for direct radiation, isotropic component (climatological)
'210186' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 195 ;
	 typeOfGeneratingProcess = 9 ;
	}
#UV visible albedo for direct radiation, volumetric component (climatological)
'210187' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 196 ;
	 typeOfGeneratingProcess = 9 ;
	}
#UV visible albedo for direct radiation, geometric component (climatological)
'210188' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 194 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Near IR albedo for direct radiation, isotropic component (climatological)
'210189' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 195 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Near IR albedo for direct radiation, volumetric component (climatological)
'210190' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 196 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Near IR albedo for direct radiation, geometric component (climatological)
'210191' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 194 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Random pattern 1 for sppt
'213001' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 1 ;
	}
#Random pattern 2 for sppt
'213002' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 2 ;
	}
#Random pattern 3 for sppt
'213003' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 3 ;
	}
#Random pattern 1 for SPP scheme
'213101' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 101 ;
	}
#Random pattern 2 for SPP scheme
'213102' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 102 ;
	}
#Random pattern 3 for SPP scheme
'213103' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 103 ;
	}
#Random pattern 4 for SPP scheme
'213104' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 104 ;
	}
#Random pattern 5 for SPP scheme
'213105' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 105 ;
	}
#Random pattern 6 for SPP scheme
'213106' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 106 ;
	}
#Random pattern 7 for SPP scheme
'213107' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 107 ;
	}
#Random pattern 8 for SPP scheme
'213108' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 108 ;
	}
#Random pattern 9 for SPP scheme
'213109' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 109 ;
	}
#Random pattern 10 for SPP scheme
'213110' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 110 ;
	}
#Random pattern 11 for SPP scheme
'213111' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 111 ;
	}
#Random pattern 12 for SPP scheme
'213112' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 112 ;
	}
#Random pattern 13 for SPP scheme
'213113' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 113 ;
	}
#Random pattern 14 for SPP scheme
'213114' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 114 ;
	}
#Random pattern 15 for SPP scheme
'213115' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 115 ;
	}
#Random pattern 16 for SPP scheme
'213116' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 116 ;
	}
#Random pattern 17 for SPP scheme
'213117' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 117 ;
	}
#Random pattern 18 for SPP scheme
'213118' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 118 ;
	}
#Random pattern 19 for SPP scheme
'213119' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 119 ;
	}
#Random pattern 20 for SPP scheme
'213120' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 120 ;
	}
#Random pattern 21 for SPP scheme
'213121' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 121 ;
	}
#Random pattern 22 for SPP scheme
'213122' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 122 ;
	}
#Random pattern 23 for SPP scheme
'213123' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 123 ;
	}
#Random pattern 24 for SPP scheme
'213124' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 124 ;
	}
#Random pattern 25 for SPP scheme
'213125' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 125 ;
	}
#Random pattern 26 for SPP scheme
'213126' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 126 ;
	}
#Random pattern 27 for SPP scheme
'213127' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 127 ;
	}
#Random pattern 28 for SPP scheme
'213128' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 128 ;
	}
#Random pattern 29 for SPP scheme
'213129' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 129 ;
	}
#Random pattern 30 for SPP scheme
'213130' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 130 ;
	}
#Random pattern 31 for SPP scheme
'213131' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 131 ;
	}
#Random pattern 32 for SPP scheme
'213132' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 132 ;
	}
#Random pattern 33 for SPP scheme
'213133' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 133 ;
	}
#Random pattern 34 for SPP scheme
'213134' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 134 ;
	}
#Random pattern 35 for SPP scheme
'213135' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 135 ;
	}
#Random pattern 36 for SPP scheme
'213136' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 136 ;
	}
#Random pattern 37 for SPP scheme
'213137' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 137 ;
	}
#Random pattern 38 for SPP scheme
'213138' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 138 ;
	}
#Random pattern 39 for SPP scheme
'213139' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 139 ;
	}
#Random pattern 40 for SPP scheme
'213140' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 140 ;
	}
#Random pattern 41 for SPP scheme
'213141' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 141 ;
	}
#Random pattern 42 for SPP scheme
'213142' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 142 ;
	}
#Random pattern 43 for SPP scheme
'213143' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 143 ;
	}
#Random pattern 44 for SPP scheme
'213144' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 144 ;
	}
#Random pattern 45 for SPP scheme
'213145' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 145 ;
	}
#Random pattern 46 for SPP scheme
'213146' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 146 ;
	}
#Random pattern 47 for SPP scheme
'213147' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 147 ;
	}
#Random pattern 48 for SPP scheme
'213148' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 148 ;
	}
#Random pattern 49 for SPP scheme
'213149' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 149 ;
	}
#Random pattern 50 for SPP scheme
'213150' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 150 ;
	}
#Random pattern 51 for SPP scheme
'213151' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 151 ;
	}
#Random pattern 52 for SPP scheme
'213152' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 152 ;
	}
#Random pattern 53 for SPP scheme
'213153' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 153 ;
	}
#Random pattern 54 for SPP scheme
'213154' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 154 ;
	}
#Random pattern 55 for SPP scheme
'213155' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 155 ;
	}
#Random pattern 56 for SPP scheme
'213156' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 156 ;
	}
#Random pattern 57 for SPP scheme
'213157' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 157 ;
	}
#Random pattern 58 for SPP scheme
'213158' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 158 ;
	}
#Random pattern 59 for SPP scheme
'213159' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 159 ;
	}
#Random pattern 60 for SPP scheme
'213160' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 160 ;
	}
#Accumulated Carbon Dioxide Net Ecosystem Exchange
'228080' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 59 ;
	 constituentType = 3 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Accumulated Carbon Dioxide Gross Primary Production
'228081' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 60 ;
	 constituentType = 3 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Accumulated Carbon Dioxide Ecosystem Respiration
'228082' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 61 ;
	 constituentType = 3 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Carbon dioxide net ecosystem exchange flux
'228083' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 59 ;
	 constituentType = 3 ;
	}
#Carbon dioxide gross primary production flux
'228084' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 60 ;
	 constituentType = 3 ;
	}
#Carbon dioxide ecosystem respiration flux
'228085' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 61 ;
	 constituentType = 3 ;
	}
#Evaporation from the top of canopy
'228100' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 100 ;
	}
#Evaporation from bare soil
'228101' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 101 ;
	}
#Evaporation from open water surfaces excluding oceans
'228102' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 102 ;
	}
#Evaporation from vegetation transpiration
'228103' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 103 ;
	}
#Accumulated freezing rain
'228216' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 194 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Potential evaporation
'228251' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 200 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated eastward ozone flux
'233032' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 78 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 constituentType = 0 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated northward ozone flux
'233033' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 79 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 constituentType = 0 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated divergence of ozone flux
'233034' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 80 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 constituentType = 0 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated net source of ozone
'233035' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 81 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 constituentType = 0 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-mean carbon dioxide net ecosystem exchange flux
'235062' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 59 ;
	 constituentType = 3 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean carbon dioxide gross primary production flux
'235063' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 60 ;
	 constituentType = 3 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean carbon dioxide ecosystem respiration flux
'235064' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 61 ;
	 constituentType = 3 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total cloud cover
'235288' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Precipitation type
'260015' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 19 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Snow cover
'260038' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 42 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#K index
'260121' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Total totals index
'260123' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Snow thickness over sea ice
'262002' = {
	 localTablesVersion = 1 ;
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 192 ;
	 typeOfFirstFixedSurface = 173 ;
	 typeOfSecondFixedSurface = 175 ;
	}
#Sea ice salinity
'262023' = {
	 localTablesVersion = 1 ;
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 193 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	}
#Time-mean snow thickness over sea ice
'263002' = {
	 localTablesVersion = 1 ;
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 192 ;
	 typeOfFirstFixedSurface = 173 ;
	 typeOfSecondFixedSurface = 175 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean Sea ice salinity
'263023' = {
	 localTablesVersion = 1 ;
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 193 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Sea water potential temperature
'151129' = {
	 discipline = 192 ;
	 parameterCategory = 151 ;
	 parameterNumber = 129 ;
	}
#Sea water practical salinity
'151130' = {
	 discipline = 192 ;
	 parameterCategory = 151 ;
	 parameterNumber = 130 ;
	}
#Upward sea water velocity
'151133' = {
	 discipline = 192 ;
	 parameterCategory = 151 ;
	 parameterNumber = 133 ;
	}
#Sea water sigma theta
'151138' = {
	 discipline = 192 ;
	 parameterCategory = 151 ;
	 parameterNumber = 138 ;
	}
#Surface downward eastward stress
'151153' = {
	 discipline = 192 ;
	 parameterCategory = 151 ;
	 parameterNumber = 153 ;
	}
#Surface downward northward stress
'151154' = {
	 discipline = 192 ;
	 parameterCategory = 151 ;
	 parameterNumber = 154 ;
	}
#Surface geopotential
'162051' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 51 ;
	}
#Total column vertically-integrated temperature
'162054' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 54 ;
	}
#Total column vertically-integrated cloud liquid water
'162056' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 56 ;
	}
#Total column vertically-integrated cloud frozen water
'162057' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 57 ;
	}
#Total column vertically-integrated ozone
'162058' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 58 ;
	}
#Total column vertically-integrated energy conversion
'162064' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 64 ;
	}
#Total column vertically-integrated eastward mass flux
'162065' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 65 ;
	}
#Total column vertically-integrated northward mass flux
'162066' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 66 ;
	}
#Total column vertically-integrated eastward kinetic energy flux
'162067' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 67 ;
	}
#Total column vertically-integrated northward kinetic energy flux
'162068' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 68 ;
	}
#Total column vertically-integrated eastward geopotential flux
'162073' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 73 ;
	}
#Total column vertically-integrated northward geopotential flux
'162074' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 74 ;
	}
#Total column vertically-integrated eastward total energy flux
'162075' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 75 ;
	}
#Total column vertically-integrated northward total energy flux
'162076' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 76 ;
	}
#Total column vertically-integrated eastward ozone flux
'162077' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 77 ;
	}
#Total column vertically-integrated northward ozone flux
'162078' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 78 ;
	}
#Total column vertically-integrated divergence of mass flux
'162081' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 81 ;
	}
#Total column vertically-integrated divergence of kinetic energy flux
'162082' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 82 ;
	}
#Total column vertically-integrated divergence of thermal energy flux
'162083' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 83 ;
	}
#Total column vertically-integrated divergence of geopotential flux
'162085' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 85 ;
	}
#Total column vertically-integrated divergence of total energy flux
'162086' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 86 ;
	}
#Total column vertically-integrated divergence of ozone flux
'162087' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 87 ;
	}
#Variance of geopotential
'162206' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 206 ;
	}
#Covariance of geopotential/temperature
'162207' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 207 ;
	}
#Variance of temperature
'162208' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 208 ;
	}
#Covariance of geopotential/specific humidity
'162209' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 209 ;
	}
#Covariance of temperature/specific humidity
'162210' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 210 ;
	}
#Variance of specific humidity
'162211' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 211 ;
	}
#Covariance of u component/geopotential
'162212' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 212 ;
	}
#Covariance of u component/temperature
'162213' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 213 ;
	}
#Covariance of u component/specific humidity
'162214' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 214 ;
	}
#Variance of u component
'162215' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 215 ;
}
