# Automatically generated by ./create_def.pl, do not edit
#Maximum temperature at 2 metres in the last 6 hours
'mx2t6' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 15 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}
#Maximum temperature at 2 metres in the last 6 hours
'mx2t6' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 15 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}
#Maximum temperature at 2 metres in the last 6 hours
'mx2t6' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 15 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}
#Minimum temperature at 2 metres in the last 6 hours
'mn2t6' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 16 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}
#Minimum temperature at 2 metres in the last 6 hours
'mn2t6' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 16 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}
#Minimum temperature at 2 metres in the last 6 hours
'mn2t6' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 16 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}
#10 metre U wind component
'u10' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 33 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	}
#10 metre U wind component
'u10' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 33 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	}
#10 metre U wind component
'u10' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 33 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	}
#10 metre V wind component
'v10' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 34 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	}
#10 metre V wind component
'v10' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 34 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	}
#10 metre V wind component
'v10' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 34 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	}
#2 metre temperature
't2m' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 11 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}
#2 metre temperature
't2m' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 11 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}
#2 metre temperature
't2m' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 11 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}
#2 metre dewpoint temperature
'd2m' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 17 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}
#2 metre dewpoint temperature
'd2m' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 17 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}
#2 metre dewpoint temperature
'd2m' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 17 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
}
