# (C) Copyright 2005- ECMWF.

# TEMPLATE 4.3, Derived forecasts based on a cluster of ensemble members over a rectangular area at a horizontal level or in a horizontal layer at a point in time

include "grib2/templates/template.4.parameter.def"
include "grib2/templates/template.4.generating_process.def"
include "grib2/templates/template.4.forecast_time.def"
include "grib2/templates/template.4.point_in_time.def"
include "grib2/templates/template.4.horizontal.def"
include "grib2/templates/template.4.derived.def"
include "grib2/templates/template.4.rectangular_cluster.def"
include "grib2/templates/template.4.eps_cluster.def"
