/* This file is automatically generated by ./make_class.pl, do not edit */
{ "abstract_long_vector", &grib_accessor_abstract_long_vector, },
{ "abstract_vector", &grib_accessor_abstract_vector, },
{ "ascii", &grib_accessor_ascii, },
{ "bit", &grib_accessor_bit, },
{ "bitmap", &grib_accessor_bitmap, },
{ "bits", &grib_accessor_bits, },
{ "bits_per_value", &grib_accessor_bits_per_value, },
{ "blob", &grib_accessor_blob, },
{ "budgdate", &grib_accessor_budgdate, },
{ "bufr_data_array", &grib_accessor_bufr_data_array, },
{ "bufr_data_element", &grib_accessor_bufr_data_element, },
{ "bufr_elements_table", &grib_accessor_bufr_elements_table, },
{ "bufr_extract_area_subsets", &grib_accessor_bufr_extract_area_subsets, },
{ "bufr_extract_datetime_subsets", &grib_accessor_bufr_extract_datetime_subsets, },
{ "bufr_extract_subsets", &grib_accessor_bufr_extract_subsets, },
{ "bufr_group", &grib_accessor_bufr_group, },
{ "bufr_simple_thinning", &grib_accessor_bufr_simple_thinning, },
{ "bufr_string_values", &grib_accessor_bufr_string_values, },
{ "bufrdc_expanded_descriptors", &grib_accessor_bufrdc_expanded_descriptors, },
{ "bytes", &grib_accessor_bytes, },
{ "change_alternative_row_scanning", &grib_accessor_change_alternative_row_scanning, },
{ "change_scanning_direction", &grib_accessor_change_scanning_direction, },
{ "check_internal_version", &grib_accessor_check_internal_version, },
{ "closest_date", &grib_accessor_closest_date, },
{ "codeflag", &grib_accessor_codeflag, },
{ "codetable", &grib_accessor_codetable, },
{ "codetable_title", &grib_accessor_codetable_title, },
{ "codetable_units", &grib_accessor_codetable_units, },
{ "concept", &grib_accessor_concept, },
{ "constant", &grib_accessor_constant, },
{ "count_file", &grib_accessor_count_file, },
{ "count_missing", &grib_accessor_count_missing, },
{ "count_total", &grib_accessor_count_total, },
{ "data_apply_bitmap", &grib_accessor_data_apply_bitmap, },
{ "data_apply_boustrophedonic", &grib_accessor_data_apply_boustrophedonic, },
{ "data_apply_boustrophedonic_bitmap", &grib_accessor_data_apply_boustrophedonic_bitmap, },
{ "data_ccsds_packing", &grib_accessor_data_ccsds_packing, },
{ "data_complex_packing", &grib_accessor_data_complex_packing, },
{ "data_dummy_field", &grib_accessor_data_dummy_field, },
{ "data_g1complex_packing", &grib_accessor_data_g1complex_packing, },
{ "data_g1second_order_constant_width_packing", &grib_accessor_data_g1second_order_constant_width_packing, },
{ "data_g1second_order_general_extended_packing", &grib_accessor_data_g1second_order_general_extended_packing, },
{ "data_g1second_order_general_packing", &grib_accessor_data_g1second_order_general_packing, },
{ "data_g1second_order_row_by_row_packing", &grib_accessor_data_g1second_order_row_by_row_packing, },
{ "data_g1secondary_bitmap", &grib_accessor_data_g1secondary_bitmap, },
{ "data_g1shsimple_packing", &grib_accessor_data_g1shsimple_packing, },
{ "data_g1simple_packing", &grib_accessor_data_g1simple_packing, },
{ "data_g22order_packing", &grib_accessor_data_g22order_packing, },
{ "data_g2bifourier_packing", &grib_accessor_data_g2bifourier_packing, },
{ "data_g2complex_packing", &grib_accessor_data_g2complex_packing, },
{ "data_g2secondary_bitmap", &grib_accessor_data_g2secondary_bitmap, },
{ "data_g2shsimple_packing", &grib_accessor_data_g2shsimple_packing, },
{ "data_g2simple_packing", &grib_accessor_data_g2simple_packing, },
{ "data_g2simple_packing_with_preprocessing", &grib_accessor_data_g2simple_packing_with_preprocessing, },
{ "data_jpeg2000_packing", &grib_accessor_data_jpeg2000_packing, },
{ "data_png_packing", &grib_accessor_data_png_packing, },
{ "data_raw_packing", &grib_accessor_data_raw_packing, },
{ "data_run_length_packing", &grib_accessor_data_run_length_packing, },
{ "data_secondary_bitmap", &grib_accessor_data_secondary_bitmap, },
{ "data_sh_packed", &grib_accessor_data_sh_packed, },
{ "data_sh_unpacked", &grib_accessor_data_sh_unpacked, },
{ "data_shsimple_packing", &grib_accessor_data_shsimple_packing, },
{ "data_simple_packing", &grib_accessor_data_simple_packing, },
{ "decimal_precision", &grib_accessor_decimal_precision, },
{ "dictionary", &grib_accessor_dictionary, },
{ "dirty", &grib_accessor_dirty, },
{ "divdouble", &grib_accessor_divdouble, },
{ "double", &grib_accessor_double, },
{ "element", &grib_accessor_element, },
{ "evaluate", &grib_accessor_evaluate, },
{ "expanded_descriptors", &grib_accessor_expanded_descriptors, },
{ "from_scale_factor_scaled_value", &grib_accessor_from_scale_factor_scaled_value, },
{ "g1_half_byte_codeflag", &grib_accessor_g1_half_byte_codeflag, },
{ "g1_message_length", &grib_accessor_g1_message_length, },
{ "g1_section4_length", &grib_accessor_g1_section4_length, },
{ "g1bitmap", &grib_accessor_g1bitmap, },
{ "g1date", &grib_accessor_g1date, },
{ "g1day_of_the_year_date", &grib_accessor_g1day_of_the_year_date, },
{ "g1end_of_interval_monthly", &grib_accessor_g1end_of_interval_monthly, },
{ "g1fcperiod", &grib_accessor_g1fcperiod, },
{ "g1forecastmonth", &grib_accessor_g1forecastmonth, },
{ "g1monthlydate", &grib_accessor_g1monthlydate, },
{ "g1number_of_coded_values_sh_complex", &grib_accessor_g1number_of_coded_values_sh_complex, },
{ "g1number_of_coded_values_sh_simple", &grib_accessor_g1number_of_coded_values_sh_simple, },
{ "g1step_range", &grib_accessor_g1step_range, },
{ "g1verificationdate", &grib_accessor_g1verificationdate, },
{ "g2_aerosol", &grib_accessor_g2_aerosol, },
{ "g2_chemical", &grib_accessor_g2_chemical, },
{ "g2_concept_dir", &grib_accessor_g2_concept_dir, },
{ "g2_eps", &grib_accessor_g2_eps, },
{ "g2_mars_labeling", &grib_accessor_g2_mars_labeling, },
{ "g2_param_concept_filename", &grib_accessor_g2_param_concept_filename, },
{ "g2bitmap", &grib_accessor_g2bitmap, },
{ "g2bitmap_present", &grib_accessor_g2bitmap_present, },
{ "g2date", &grib_accessor_g2date, },
{ "g2end_step", &grib_accessor_g2end_step, },
{ "g2grid", &grib_accessor_g2grid, },
{ "g2latlon", &grib_accessor_g2latlon, },
{ "g2level", &grib_accessor_g2level, },
{ "g2lon", &grib_accessor_g2lon, },
{ "g2step_range", &grib_accessor_g2step_range, },
{ "gaussian_grid_name", &grib_accessor_gaussian_grid_name, },
{ "gds_is_present", &grib_accessor_gds_is_present, },
{ "gen", &grib_accessor_gen, },
{ "getenv", &grib_accessor_getenv, },
{ "global_gaussian", &grib_accessor_global_gaussian, },
{ "grid_spec", &grib_accessor_grid_spec, },
{ "group", &grib_accessor_group, },
{ "gts_header", &grib_accessor_gts_header, },
{ "hash_array", &grib_accessor_hash_array, },
{ "headers_only", &grib_accessor_headers_only, },
{ "ibmfloat", &grib_accessor_ibmfloat, },
{ "ieeefloat", &grib_accessor_ieeefloat, },
{ "ifs_param", &grib_accessor_ifs_param, },
{ "iterator", &grib_accessor_iterator, },
{ "julian_date", &grib_accessor_julian_date, },
{ "julian_day", &grib_accessor_julian_day, },
{ "ksec1expver", &grib_accessor_ksec1expver, },
{ "label", &grib_accessor_label, },
{ "latitudes", &grib_accessor_latitudes, },
{ "latlon_increment", &grib_accessor_latlon_increment, },
{ "latlonvalues", &grib_accessor_latlonvalues, },
{ "library_version", &grib_accessor_library_version, },
{ "local_definition", &grib_accessor_local_definition, },
{ "long", &grib_accessor_long, },
{ "long_vector", &grib_accessor_long_vector, },
{ "longitudes", &grib_accessor_longitudes, },
{ "lookup", &grib_accessor_lookup, },
{ "mars_param", &grib_accessor_mars_param, },
{ "mars_step", &grib_accessor_mars_step, },
{ "md5", &grib_accessor_md5, },
{ "message", &grib_accessor_message, },
{ "message_copy", &grib_accessor_message_copy, },
{ "message_is_valid", &grib_accessor_message_is_valid, },
{ "mtg2_switch_default", &grib_accessor_mtg2_switch_default, },
{ "multdouble", &grib_accessor_multdouble, },
{ "nearest", &grib_accessor_nearest, },
{ "non_alpha", &grib_accessor_non_alpha, },
{ "number_of_coded_values", &grib_accessor_number_of_coded_values, },
{ "number_of_points", &grib_accessor_number_of_points, },
{ "number_of_points_gaussian", &grib_accessor_number_of_points_gaussian, },
{ "number_of_values", &grib_accessor_number_of_values, },
{ "number_of_values_data_raw_packing", &grib_accessor_number_of_values_data_raw_packing, },
{ "octahedral_gaussian", &grib_accessor_octahedral_gaussian, },
{ "octet_number", &grib_accessor_octet_number, },
{ "offset_file", &grib_accessor_offset_file, },
{ "offset_values", &grib_accessor_offset_values, },
{ "optimal_step_units", &grib_accessor_optimal_step_units, },
{ "pack_bufr_values", &grib_accessor_pack_bufr_values, },
{ "packing_type", &grib_accessor_packing_type, },
{ "pad", &grib_accessor_pad, },
{ "padding", &grib_accessor_padding, },
{ "padto", &grib_accessor_padto, },
{ "padtoeven", &grib_accessor_padtoeven, },
{ "padtomultiple", &grib_accessor_padtomultiple, },
{ "position", &grib_accessor_position, },
{ "proj_string", &grib_accessor_proj_string, },
{ "raw", &grib_accessor_raw, },
{ "rdbtime_guess_date", &grib_accessor_rdbtime_guess_date, },
{ "reference_value_error", &grib_accessor_reference_value_error, },
{ "round", &grib_accessor_round, },
{ "scale", &grib_accessor_scale, },
{ "scale_values", &grib_accessor_scale_values, },
{ "second_order_bits_per_value", &grib_accessor_second_order_bits_per_value, },
{ "section", &grib_accessor_section, },
{ "section_length", &grib_accessor_section_length, },
{ "section_padding", &grib_accessor_section_padding, },
{ "section_pointer", &grib_accessor_section_pointer, },
{ "select_step_template", &grib_accessor_select_step_template, },
{ "sexagesimal2decimal", &grib_accessor_sexagesimal2decimal, },
{ "signed", &grib_accessor_signed, },
{ "signed_bits", &grib_accessor_signed_bits, },
{ "simple_packing_error", &grib_accessor_simple_packing_error, },
{ "size", &grib_accessor_size, },
{ "smart_table", &grib_accessor_smart_table, },
{ "smart_table_column", &grib_accessor_smart_table_column, },
{ "spd", &grib_accessor_spd, },
{ "spectral_truncation", &grib_accessor_spectral_truncation, },
{ "sprintf", &grib_accessor_sprintf, },
{ "statistics", &grib_accessor_statistics, },
{ "statistics_spectral", &grib_accessor_statistics_spectral, },
{ "step_human_readable", &grib_accessor_step_human_readable, },
{ "step_in_units", &grib_accessor_step_in_units, },
{ "sum", &grib_accessor_sum, },
{ "suppressed", &grib_accessor_suppressed, },
{ "time", &grib_accessor_time, },
{ "to_double", &grib_accessor_to_double, },
{ "to_integer", &grib_accessor_to_integer, },
{ "to_string", &grib_accessor_to_string, },
{ "transient", &grib_accessor_transient, },
{ "transient_darray", &grib_accessor_transient_darray, },
{ "trim", &grib_accessor_trim, },
{ "uint16", &grib_accessor_uint16, },
{ "uint32", &grib_accessor_uint32, },
{ "uint32_little_endian", &grib_accessor_uint32_little_endian, },
{ "uint64", &grib_accessor_uint64, },
{ "uint64_little_endian", &grib_accessor_uint64_little_endian, },
{ "uint8", &grib_accessor_uint8, },
{ "unexpanded_descriptors", &grib_accessor_unexpanded_descriptors, },
{ "unpack_bufr_values", &grib_accessor_unpack_bufr_values, },
{ "unsigned", &grib_accessor_unsigned, },
{ "unsigned_bits", &grib_accessor_unsigned_bits, },
{ "validity_date", &grib_accessor_validity_date, },
{ "validity_time", &grib_accessor_validity_time, },
{ "values", &grib_accessor_values, },
{ "variable", &grib_accessor_variable, },
{ "vector", &grib_accessor_vector, },
{ "when", &grib_accessor_when, },
