# (C) Copyright 2005- ECMWF.

# Section 0 - Indicator Section

position     offsetSection0;
constant     section0Length = 16;
ascii[4]     identifier = "GRIB"     : read_only;
unsigned[2]  reserved  = missing()   : can_be_missing,hidden,read_only,edition_specific;

codetable[1] tablesVersion 'grib3/tables/0.0.table' = 1 : edition_specific;
alias gribMasterTablesVersionNumber=tablesVersion;

unsigned[1]  editionNumber = 3 : edition_specific,dump;
alias ls.edition = editionNumber;

section_length[8]  totalLength;
position startOfHeaders; # See later for endOfHeadersMarker

meta section0Pointer section_pointer(offsetSection0,section0Length,0);
