# Automatically generated by get_definitionsALL.sql from database PRJ_TDCFDOKU.GRIB_PARAMETER@OFC1MIR.DWD.DE, do not edit! 2024-09-17 11:09
#paramId: 500000
#Pressure (S) (not reduced)
'PS' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500001
#Pressure
'P' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	}

#paramId: 500002
#Pressure Reduced to MSL
'PMSL' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 1 ;
	}

#paramId: 500003
#Pressure Tendency (S)
'DPSDT' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500004
#Geopotential (S)
'FIS' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500005
#Geopotential (full lev)
'FIF' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 4 ;
	 typeOfSecondFixedSurface = 105 ;
	 typeOfFirstFixedSurface = 105 ;
	}

#paramId: 500006
#Geopotential
'FI' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 4 ;
	}

#paramId: 500007
#Geometric Height of the earths surface above sea level
'HSURF' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	 typeOfSecondFixedSurface = 101 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500008
#Geometric Height of the layer limits above sea level(NN)
'HHL' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	 typeOfSecondFixedSurface = 101 ;
	}

#paramId: 500009
#Total Column Integrated Ozone
'TO3' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 2 ;
	}

#paramId: 500010
#Temperature (G)
'T_G' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500011
#2m Temperature
'T_2M' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 500012
#2m Temperature (AV)
'T_2M_AV' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 500013
#Climat. temperature, 2m Temperature
'T_2M_CL' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 typeOfGeneratingProcess = 9 ;
	}

#paramId: 500014
#Temperature
'T' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	}

#paramId: 500015
#Max 2m Temperature (i)
'TMAX_2M' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 500016
#Min 2m Temperature (i)
'TMIN_2M' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 500017
#2m Dew Point Temperature
'TD_2M' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 500018
#2m Dew Point Temperature (AV)
'TD_2M_AV' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 500019
#Radar spectra (1)
'DBZ_MAX' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 6 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500020
#Wave spectra (1)
'WVSP1' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	}

#paramId: 500021
#Wave spectra (2)
'WVSP2' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	}

#paramId: 500022
#Wave spectra (3)
'WVSP3' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	}

#paramId: 500023
#Wind Direction (DD_10M)
'DD_10M' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	}

#paramId: 500024
#Wind Direction (DD)
'DD' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	}

#paramId: 500025
#Wind speed (SP_10M)
'SP_10M' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	}

#paramId: 500026
#Wind speed (SP)
'SP' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	}

#paramId: 500027
#U-Component of Wind
'U_10M' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	}

#paramId: 500028
#U-Component of Wind
'U' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	}

#paramId: 500029
#V-Component of Wind
'V_10M' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	}

#paramId: 500030
#V-Component of Wind
'V' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	}

#paramId: 500031
#Vertical Velocity (Pressure) ( omega=dp/dt )
'OMEGA' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	}

#paramId: 500032
#Vertical Velocity (Geometric) (w)
'W' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 9 ;
	}

#paramId: 500034
#Specific Humidity (2m)
'QV_2M' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 500035
#Specific Humidity
'QV' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	}

#paramId: 500036
#2m Relative Humidity
'RELHUM_2M' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 500037
#Relative Humidity
'RELHUM' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	}

#paramId: 500038
#Total column integrated water vapour
'TQV' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 64 ;
	}

#paramId: 500039
#Evaporation (s)
'AEVAP_S' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 79 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500040
#Total Column-Integrated Cloud Ice
'TQI' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 70 ;
	}

#paramId: 500041
#Total Precipitation (Accumulation)
'TOT_PREC' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 500042
#Large-Scale Precipitation (Accumulation)
'PREC_GSP' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 54 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 500043
#Convective Precipitation (Accumulation)
'PREC_CON' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 37 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 500044
#Snow depth water equivalent
'W_SNOW' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 60 ;
	}

#paramId: 500045
#Snow Depth
'H_SNOW' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 11 ;
	}

#paramId: 500046
#Total Cloud Cover
'CLCT' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 1 ;
	}

#paramId: 500047
#Convective Cloud Cover
'CLC_CON' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 2 ;
	}

#paramId: 500048
#Cloud Cover (800 hPa - Soil)
'CLCL' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 22 ;
	 typeOfSecondFixedSurface = 1 ;
	 typeOfFirstFixedSurface = 100 ;
	 scaleFactorOfFirstFixedSurface = -2 ;
	 scaledValueOfFirstFixedSurface = 800 ;
	}

#paramId: 500049
#Cloud Cover (400 - 800 hPa)
'CLCM' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 22 ;
	 typeOfSecondFixedSurface = 100 ;
	 scaleFactorOfSecondFixedSurface = -2 ;
	 scaledValueOfSecondFixedSurface = 800 ;
	 typeOfFirstFixedSurface = 100 ;
	 scaleFactorOfFirstFixedSurface = -2 ;
	 scaledValueOfFirstFixedSurface = 400 ;
	}

#paramId: 500050
#Cloud Cover (0 - 400 hPa)
'CLCH' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 22 ;
	 typeOfSecondFixedSurface = 100 ;
	 scaleFactorOfSecondFixedSurface = -2 ;
	 scaledValueOfSecondFixedSurface = 400 ;
	 typeOfFirstFixedSurface = 100 ;
	 scaleFactorOfFirstFixedSurface = -2 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	}

#paramId: 500051
#Total Column-Integrated Cloud Water
'TQC' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 69 ;
	}

#paramId: 500052
#Convective Snowfall water equivalent (s)
'SNOW_CON' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 55 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 500053
#Large-Scale snowfall - water equivalent (Accumulation)
'SNOW_GSP' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 56 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 500054
#Land Cover (1=land, 0=sea)
'FR_LAND' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	}

#paramId: 500055
#Surface Roughness length Surface Roughness
'Z0' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	}

#paramId: 500056
#Albedo (in short-wave)
'ALB_RAD' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 1 ;
	}

#paramId: 500057
#Albedo (in short-wave, average)
'ALBEDO_B' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}

#paramId: 500058
#Soil Temperature  ( 36 cm depth, vv=0h)
'T_CL' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfFirstFixedSurface = 36 ;
	}

#paramId: 500059
#Soil Temperature (41 cm depth)
'T_CL_LM' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfFirstFixedSurface = 41 ;
	}

#paramId: 500060
#Soil Temperature
'T_M' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfFirstFixedSurface = 9 ;
	}

#paramId: 500061
#Soil Temperature
'T_S' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500062
#Column-integrated Soil Moisture
'W_CL' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 20 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaleFactorOfSecondFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = 190 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfFirstFixedSurface = 100 ;
	}

#paramId: 500063
#Column-integrated Soil Moisture (1) 0 -10 cm
'W_G1' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 20 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaleFactorOfSecondFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = 10 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	}

#paramId: 500064
#Column-integrated Soil Moisture (2) 10-100cm
'W_G2' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 20 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaleFactorOfSecondFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = 100 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	}

#paramId: 500065
#Plant cover
'PLCOV' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	}

#paramId: 500066
#Water Runoff
'RUNOFF_G' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	}

#paramId: 500068
#Water Runoff (s)
'RUNOFF_S' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	}

#paramId: 500069
#Sea Ice Cover ( 0= free, 1=cover)
'FR_ICE' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	}

#paramId: 500070
#Sea Ice Thickness
'H_ICE' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	}

#paramId: 500071
#Significant height of combined wind waves and swell
'SWH' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	}

#paramId: 500072
#Direction of wind waves
'MDWW' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	}

#paramId: 500073
#Significant height of wind waves
'SHWW' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 5 ;
	}

#paramId: 500074
#Mean period of wind waves
'MPWW' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	}

#paramId: 500075
#Direction of swell waves
'MDTS' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 7 ;
	}

#paramId: 500076
#Significant height of swell waves
'SHTS' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 8 ;
	}

#paramId: 500077
#Mean period of swell waves
'MPTS' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 9 ;
	}

#paramId: 500078
#Net short wave radiation flux (at the surface)
'ASOB_S' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500079
#Net short wave radiation flux (at the surface)
'SOBS_RAD' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500080
#Net long wave radiation flux (m) (at the surface)
'ATHB_S' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500081
#Net long wave radiation flux
'THBS_RAD' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500082
#Net short wave radiation flux (on the model top)
'ASOB_T' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 8 ;
	}

#paramId: 500083
#Net short wave radiation flux
'SOBT_RAD' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 8 ;
	}

#paramId: 500084
#Net long wave radiation flux (m) (on the model top)
'ATHB_T' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 8 ;
	}

#paramId: 500085
#Net long wave radiation flux
'THBT_RAD' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 8 ;
	}

#paramId: 500086
#Latent Heat Net Flux (m)
'ALHFL_S' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500087
#Sensible Heat Net Flux (m)
'ASHFL_S' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 11 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500088
#Momentum Flux, U-Component (m)
'AUMFL_S' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 17 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500089
#Momentum Flux, V-Component (m)
'AVMFL_S' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 18 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500090
#Photosynthetically active radiation (m) (at the surface)
'APAB_S' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500091
#Photosynthetically active radiation
'PABS_RAD' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500098
#Cloud cover
'CLC' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 22 ;
	}

#paramId: 500099
#Non-Convective Cloud Cover, grid scale
'CLC_SGS' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 14 ;
	}

#paramId: 500100
#Cloud Mixing Ratio
'QC' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 22 ;
	}

#paramId: 500101
#Cloud Ice Mixing Ratio
'QI' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 82 ;
	}

#paramId: 500102
#Rain mixing ratio
'QR' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 24 ;
	}

#paramId: 500103
#Snow mixing ratio
'QS' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 25 ;
	}

#paramId: 500104
#Total column integrated rain
'TQR' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 45 ;
	}

#paramId: 500105
#Total column integrated snow
'TQS' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 46 ;
	}

#paramId: 500106
#Grauple
'QG' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 32 ;
	}

#paramId: 500107
#Total column integrated grauple
'TQG' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 74 ;
	}

#paramId: 500108
#Total Column integrated water (all components incl. precipitation)
'TWATER' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 78 ;
	}

#paramId: 500118
#Height of Convective Cloud Base above msl
'HBAS_CON' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 26 ;
	 typeOfSecondFixedSurface = 101 ;
	 typeOfFirstFixedSurface = 2 ;
	}

#paramId: 500119
#Height of Convective Cloud Top above msl
'HTOP_CON' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 27 ;
	 typeOfSecondFixedSurface = 101 ;
	 typeOfFirstFixedSurface = 3 ;
	}

#paramId: 500127
#Height of 0 degree Celsius isotherm above msl
'HZEROCL' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	 typeOfSecondFixedSurface = 101 ;
	 typeOfFirstFixedSurface = 4 ;
	}

#paramId: 500132
#Large scale rain rate
'PRR_GSP' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 77 ;
	}

#paramId: 500133
#Large scale snowfall rate water equivalent
'PRS_GSP' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 56 ;
	}

#paramId: 500134
#Large scale rain (Accumulation)
'RAIN_GSP' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 500135
#Convective rain rate
'PRR_CON' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 76 ;
	}

#paramId: 500136
#Convective snowfall rate water equivalent
'PRS_CON' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 55 ;
	}

#paramId: 500137
#Convective rain
'RAIN_CON' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 76 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 500138
#rain amount, grid-scale plus convective
'TOT_RAIN' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 65 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 500139
#snow amount, grid-scale plus convective
'TOT_SNOW' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 66 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 500145
#Graupel (snow pellets) precipitation rate
'PRG_GSP' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 75 ;
	}

#paramId: 500146
#Graupel (snow pellets) precipitation (Accumulation)
'GRAU_GSP' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 75 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 500147
#Snow density
'RHO_SNOW' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 61 ;
	}

#paramId: 500155
#Convective turbulent kinetic enery
'TKE_CON' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 24 ;
	}

#paramId: 500158
#Turbulent Kinetic Energy
'TKE' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 11 ;
	}

#paramId: 500159
#Turbulent diffusioncoefficient for momentum
'TKVM' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 31 ;
	}

#paramId: 500160
#Turbulent diffusion coefficient for heat (and moisture)
'TKVH' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 20 ;
	}

#paramId: 500161
#Turbulent transfer coefficient for impulse
'TCM' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 29 ;
	}

#paramId: 500162
#Turbulent transfer coefficient for heat (and Moisture)
'TCH' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 19 ;
	}

#paramId: 500163
#mixed layer depth
'MH' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 3 ;
	}

#paramId: 500164
#maximum Wind 10m
'VMAX_10M' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	}

#paramId: 500166
#Soil Temperature (multilayer model)
'T_SO' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 106 ;
	}

#paramId: 500167
#Column-integrated Soil Moisture (multilayers)
'W_SO' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 20 ;
	 typeOfSecondFixedSurface = 106 ;
	 typeOfFirstFixedSurface = 106 ;
	}

#paramId: 500168
#soil ice content (multilayers)
'W_SO_ICE' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 22 ;
	 typeOfSecondFixedSurface = 106 ;
	 typeOfFirstFixedSurface = 106 ;
	}

#paramId: 500169
#Plant Canopy Surface Water
'W_I' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 13 ;
	}

#paramId: 500170
#Snow temperature (top of snow)
'T_SNOW' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 18 ;
	}

#paramId: 500171
#Minimal Stomatal Resistance
'RSMIN' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 16 ;
	}

#paramId: 500172
#Sea Ice Temperature
'T_ICE' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	}

#paramId: 500173
#Base reflectivity
'DBZ_850' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500174
#Base reflectivity
'DBZ' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 1 ;
	}

#paramId: 500175
#Base reflectivity (cmax)
'DBZ_CMAX' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500183
#Convective Available Potential Energy
'CAPE_CON' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	}

#paramId: 500185
#Direction of combined wind waves and swell
'MWD' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 14 ;
	}

#paramId: 500187
#Peak period of total swell
'PPTS' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 36 ;
	}

#paramId: 500189
#Peak period of wind waves
'PPWW' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 35 ;
	}

#paramId: 500190
#Peak wave period
'PP1D' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 34 ;
	}

#paramId: 500191
#Mean period of combined wind waves and swell
'TM10' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 15 ;
	}

#paramId: 500192
#Inverse mean wave frequency
'TM01' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	}

#paramId: 500193
#Mean zero-crossing wave period
'TM02' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 28 ;
	}

#paramId: 500194
#Wave directional width
'SPRD' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 31 ;
	}

#paramId: 500200
#Standard deviation of sub-grid scale orography
'SSO_STDH' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 20 ;
	}

#paramId: 500201
#Anisotropy of sub-gridscale orography
'SSO_GAMMA' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 24 ;
	}

#paramId: 500202
#Angle of sub-gridscale orography
'SSO_THETA' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 21 ;
	}

#paramId: 500203
#Slope of sub-gridscale orography
'SSO_SIGMA' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 22 ;
	}

#paramId: 500206
#Leaf area index
'LAI' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 28 ;
	}

#paramId: 500207
#root depth of vegetation
'ROOTDP' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 32 ;
	}

#paramId: 500210
#Plant covering degree in the vegetation phase
'PLCOV_MX' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 2 ;
	}

#paramId: 500211
#Plant covering degree in the quiescent phas
'PLCOV_MN' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 3 ;
	}

#paramId: 500212
#Max Leaf area index
'LAI_MX' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 28 ;
	 typeOfStatisticalProcessing = 2 ;
	}

#paramId: 500213
#Min Leaf area index
'LAI_MN' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 28 ;
	 typeOfStatisticalProcessing = 3 ;
	}

#paramId: 500214
#Orographie + Land-Meer-Verteilung
'ORO_MOD' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 7 ;
	}

#paramId: 500217
#evergreen forest
'FOR_E' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 29 ;
	}

#paramId: 500218
#deciduous forest
'FOR_D' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 30 ;
	}

#paramId: 500219
#normalized differential vegetation index
'NDVI' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 31 ;
	 typeOfStatisticalProcessing = 0 ;
	}

#paramId: 500220
#normalized differential vegetation index (NDVI)
'NDVI_MAX' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 31 ;
	 typeOfStatisticalProcessing = 2 ;
	}

#paramId: 500223
#Total sulfate aerosol
'AER_SO4' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 constituentType = 62006 ;
	}

#paramId: 500224
#Total sulfate aerosol (12M)
'AER_SO412' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 62006 ;
	}

#paramId: 500225
#Total soil dust aerosol (climatology)
'AER_DUST' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 constituentType = 62001 ;
	}

#paramId: 500226
#Total soil dust aerosol (climatology,12M)
'AER_DUST12' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 62001 ;
	}

#paramId: 500227
#Organic aerosol
'AER_ORG' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 constituentType = 62010 ;
	}

#paramId: 500228
#Organic aerosol (12M)
'AER_ORG12' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 62010 ;
	}

#paramId: 500229
#Black carbon aerosol
'AER_BC' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 constituentType = 62009 ;
	}

#paramId: 500230
#Black carbon aerosol (12M)
'AER_BC12' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 62009 ;
	}

#paramId: 500231
#Sea salt aerosol
'AER_SS' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 constituentType = 62008 ;
	}

#paramId: 500232
#Sea salt aerosol (12M)
'AER_SS12' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 62008 ;
	}

#paramId: 500236
#geographical latitude
'RLAT' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 1 ;
	}

#paramId: 500237
#geographical longitude
'RLON' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 2 ;
	}

#paramId: 500238
#Friction velocity
'USTAR' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 30 ;
	}

#paramId: 500242
#Ozone Mixing Ratio
'O3' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 1 ;
	}

#paramId: 500243
#Air concentration of Ruthenium 103
'Ru-103' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 constituentType = 30102 ;
	}

#paramId: 500244
#Ru103 - dry deposition
'Ru-103d' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 12 ;
	 constituentType = 30102 ;
	}

#paramId: 500245
#Ru103 - wet deposition
'Ru-103w' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 11 ;
	 constituentType = 30102 ;
	}

#paramId: 500246
#Air concentration of Strontium 90
'Sr-90' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 constituentType = 30067 ;
	}

#paramId: 500247
#Sr90 - dry deposition
'Sr-90d' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 12 ;
	 constituentType = 30067 ;
	}

#paramId: 500248
#Sr90 - wet deposition
'Sr-90w' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 11 ;
	 constituentType = 30067 ;
	}

#paramId: 500249
#Air concentration of Iodine 131 aerosol
'I-131a' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 constituentType = 30141 ;
	}

#paramId: 500250
#I131a - dry deposition
'I-131ad' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 12 ;
	 constituentType = 30141 ;
	}

#paramId: 500251
#I131a - wet deposition
'I-131aw' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 11 ;
	 constituentType = 30141 ;
	}

#paramId: 500252
#Air concentration of Caesium 137
'Cs-137' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 constituentType = 30172 ;
	}

#paramId: 500253
#Cs137 - dry deposition
'Cs-137d' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 12 ;
	 constituentType = 30172 ;
	}

#paramId: 500255
#Air concentration of Tellurium 132
'Te-132' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 constituentType = 30129 ;
	}

#paramId: 500256
#Te132 - dry deposition
'Te-132d' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 12 ;
	 constituentType = 30129 ;
	}

#paramId: 500257
#Te132 - wet deposition
'Te-132w' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 11 ;
	 constituentType = 30129 ;
	}

#paramId: 500258
#Air concentration of Zirconium 95
'Zr-95' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 constituentType = 30079 ;
	}

#paramId: 500259
#Zr95 - dry deposition
'Zr-95d' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 12 ;
	 constituentType = 30079 ;
	}

#paramId: 500260
#Zr95 - wet deposition
'Zr-95w' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 11 ;
	 constituentType = 30079 ;
	}

#paramId: 500261
#Air concentration of Krypton 85
'Kr-85' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 constituentType = 30059 ;
	}

#paramId: 500262
#Kr85 - dry deposition
'Kr-85d' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 12 ;
	 constituentType = 30059 ;
	}

#paramId: 500263
#Kr85 - wet deposition
'Kr-85w' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 11 ;
	 constituentType = 30059 ;
	}

#paramId: 500264
#TRACER - concentration
'Tr-2' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 constituentType = 30000 ;
	}

#paramId: 500265
#TRACER - dry deposition
'Tr-2d' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 12 ;
	 constituentType = 30000 ;
	}

#paramId: 500266
#TRACER - wet deposition
'Tr-2w' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 11 ;
	 constituentType = 30000 ;
	}

#paramId: 500267
#Air concentration of Xenon 133
'Xe-133' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 constituentType = 30161 ;
	}

#paramId: 500268
#Xe133 - dry deposition
'Xe-133d' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 12 ;
	 constituentType = 30161 ;
	}

#paramId: 500269
#Xe133 - wet deposition
'Xe-133w' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 11 ;
	 constituentType = 30161 ;
	}

#paramId: 500270
#Air concentration of Iodine 131 elementary gaseous
'I-131g' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 constituentType = 30138 ;
	}

#paramId: 500271
#I131g - dry deposition
'I-131gd' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 12 ;
	 constituentType = 30138 ;
	}

#paramId: 500272
#I131g - wet deposition
'I-131gw' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 11 ;
	 constituentType = 30138 ;
	}

#paramId: 500273
#Air concentration of Iodine 131 organic bounded
'I-131o' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 constituentType = 30139 ;
	}

#paramId: 500274
#I131o - dry deposition
'I-131od' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 12 ;
	 constituentType = 30139 ;
	}

#paramId: 500275
#I131o - wet deposition
'I-131ow' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 11 ;
	 constituentType = 30139 ;
	}

#paramId: 500276
#Air concentration of Barium 140
'Ba-140' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 constituentType = 30175 ;
	}

#paramId: 500277
#Ba140 - dry deposition
'Ba-140d' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 12 ;
	 constituentType = 30175 ;
	}

#paramId: 500278
#Ba140 - wet deposition
'Ba-140w' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 11 ;
	 constituentType = 30175 ;
	}

#paramId: 500284
#Gravity wave dissipation (vertical integral)
'VDIS_SSO' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 23 ;
	}

#paramId: 500285
#UV Index, clouded sky, maximum
'UVI_MAX_CL' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 51 ;
	 typeOfStatisticalProcessing = 2 ;
	}

#paramId: 500286
#Vertical speed shear
'W_SHAER' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 25 ;
	}

#paramId: 500287
#storm relative helicity
'SRH' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 8 ;
	}

#paramId: 500290
#Hoehe der Konvektionsuntergrenze ueber Grund
'CCL_GND' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 26 ;
	 typeOfSecondFixedSurface = 1 ;
	 typeOfFirstFixedSurface = 2 ;
	}

#paramId: 500292
#weather interpretation (WMO)
'WW' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 25 ;
	}

#paramId: 500301
#Druck einer isentropen Flaeche
'PTHETA' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 107 ;
	}

#paramId: 500302
#KO index
'KO' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 3 ;
	}

#paramId: 500303
#Aequivalentpotentielle Temperatur
'THETAE' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	}

#paramId: 500304
#Ceiling
'CEILING' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 13 ;
	}

#paramId: 500305
#Icing Grade (1=LGT,2=MOD,3=SEV)
'ICE_GRD' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 7 ;
	}

#paramId: 500308
#Monthly Mean of RMS of difference FG-AN of pressure reduced to MSL
'EFA-PS' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 201 ;
	}

#paramId: 500309
#Monthly Mean of RMS of difference IA-AN of pressure reduced to MSL
'EIA-PS' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 200 ;
	}

#paramId: 500310
#Monthly Mean of RMS of difference FG-AN of u-component of wind
'EFA-U' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 201 ;
	}

#paramId: 500311
#Monthly Mean of RMS of difference IA-AN of u-component of wind
'EIA-U' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 200 ;
	}

#paramId: 500312
#Monthly Mean of RMS of difference FG-AN of v-component of wind
'EFA-V' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 201 ;
	}

#paramId: 500313
#Monthly Mean of RMS of difference IA-AN of v-component of wind
'EIA-V' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 200 ;
	}

#paramId: 500314
#Monthly Mean of RMS of difference FG-AN of geopotential
'EFA-FI' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 201 ;
	}

#paramId: 500315
#Monthly Mean of RMS of difference IA-AN of geopotential
'EIA-FI' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 200 ;
	}

#paramId: 500316
#Monthly Mean of RMS of difference FG-AN of relative humidity
'EFA-RH' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 201 ;
	}

#paramId: 500317
#Monthly Mean of RMS of difference IA-AN of relative humidity
'EIA-RH' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 200 ;
	}

#paramId: 500318
#Monthly Mean of RMS of difference FG-AN of temperature
'EFA-T' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 201 ;
	}

#paramId: 500319
#Monthly Mean of RMS of difference IA-AN of temperature
'EIA-T' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 200 ;
	}

#paramId: 500320
#Monthly Mean of RMS of difference FG-AN of vert.velocity (pressure)
'EFA-OM' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 201 ;
	}

#paramId: 500321
#Monthly Mean of RMS of difference IA-AN of vert.velocity (pressure)
'EIA-OM' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 200 ;
	}

#paramId: 500324
#Synth. Sat. brightness temperature cloudy
'SYNME5_BT_CL' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 52 ;
	 instrumentType = 205 ;
	}

#paramId: 500325
#Synth. Sat. brightness temperature clear sky
'SYNME5_BT_CS' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 52 ;
	 instrumentType = 205 ;
	}

#paramId: 500326
#Synth. Sat. radiance cloudy
'SYNME5_RAD_CL' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 16 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 52 ;
	 instrumentType = 205 ;
	}

#paramId: 500327
#Synth. Sat. radiance clear sky
'SYNME5_RAD_CS' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 52 ;
	 instrumentType = 205 ;
	}

#paramId: 500328
#Synth. Sat. brightness temperature cloudy
'SYNME6_BT_CL' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 53 ;
	 instrumentType = 205 ;
	}

#paramId: 500329
#Synth. Sat. brightness temperature clear sky
'SYNME6_BT_CS' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 53 ;
	 instrumentType = 205 ;
	}

#paramId: 500330
#Synth. Sat. radiance cloudy
'SYNME6_RAD_CL' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 16 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 53 ;
	 instrumentType = 205 ;
	}

#paramId: 500331
#Synth. Sat. radiance clear sky
'SYNME6_RAD_CS' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 53 ;
	 instrumentType = 205 ;
	}

#paramId: 500332
#Synth. Sat. brightness temperature cloudy
'SYNME7_BT_CL_IR11.5' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 54 ;
	 instrumentType = 205 ;
	 scaledValueOfCentralWaveNumber = 86956 ;
	}

#paramId: 500333
#Synth. Sat. brightness temperature cloudy
'SYNME7_BT_CL_WV6.4' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 54 ;
	 instrumentType = 205 ;
	 scaledValueOfCentralWaveNumber = 156250 ;
	}

#paramId: 500334
#Synth. Sat. brightness temperature clear sky
'SYNME7_BT_CS_IR11.5' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 54 ;
	 instrumentType = 205 ;
	 scaledValueOfCentralWaveNumber = 86956 ;
	}

#paramId: 500335
#Synth. Sat. brightness temperature clear sky
'SYNME7_BT_CS_WV6.4' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 54 ;
	 instrumentType = 205 ;
	 scaledValueOfCentralWaveNumber = 156250 ;
	}

#paramId: 500336
#Synth. Sat. radiance cloudy
'SYNME7_RAD_CL_IR11.5' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 16 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 54 ;
	 instrumentType = 205 ;
	 scaledValueOfCentralWaveNumber = 86956 ;
	}

#paramId: 500337
#Synth. Sat. radiance cloudy
'SYNME7_RAD_CL_WV6.4' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 16 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 54 ;
	 instrumentType = 205 ;
	 scaledValueOfCentralWaveNumber = 156250 ;
	}

#paramId: 500338
#Synth. Sat. radiance clear sky
'SYNME7_RAD_CS_IR11.5' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 54 ;
	 instrumentType = 205 ;
	 scaledValueOfCentralWaveNumber = 86956 ;
	}

#paramId: 500339
#Synth. Sat. radiance clear sky
'SYNME7_RAD_CS_WV6.4' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 54 ;
	 instrumentType = 205 ;
	 scaledValueOfCentralWaveNumber = 156250 ;
	}

#paramId: 500340
#Synth. Sat. brightness temperature cloudy
'SYNMSG_BT_CL_IR10.8' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 92592 ;
	}

#paramId: 500341
#Synth. Sat. brightness temperature cloudy
'SYNMSG_BT_CL_IR12.1' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 82644 ;
	}

#paramId: 500342
#Synth. Sat. brightness temperature cloudy
'SYNMSG_BT_CL_IR13.4' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 74626 ;
	}

#paramId: 500343
#Synth. Sat. brightness temperature cloudy
'SYNMSG_BT_CL_IR3.9' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 256410 ;
	}

#paramId: 500344
#Synth. Sat. brightness temperature cloudy
'SYNMSG_BT_CL_IR8.7' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 114942 ;
	}

#paramId: 500345
#Synth. Sat. brightness temperature cloudy
'SYNMSG_BT_CL_IR9.7' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 103092 ;
	}

#paramId: 500346
#Synth. Sat. brightness temperature cloudy
'SYNMSG_BT_CL_WV6.2' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 161290 ;
	}

#paramId: 500347
#Synth. Sat. brightness temperature cloudy
'SYNMSG_BT_CL_WV7.3' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 136986 ;
	}

#paramId: 500348
#Synth. Sat. brightness temperature clear sky
'SYNMSG_BT_CS_IR8.7' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 114942 ;
	}

#paramId: 500349
#Synth. Sat. brightness temperature clear sky
'SYNMSG_BT_CS_IR10.8' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 92592 ;
	}

#paramId: 500350
#Synth. Sat. brightness temperature clear sky
'SYNMSG_BT_CS_IR12.1' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 82644 ;
	}

#paramId: 500351
#Synth. Sat. brightness temperature clear sky
'SYNMSG_BT_CS_IR13.4' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 74626 ;
	}

#paramId: 500352
#Synth. Sat. brightness temperature clear sky
'SYNMSG_BT_CS_IR3.9' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 256410 ;
	}

#paramId: 500353
#Synth. Sat. brightness temperature clear sky
'SYNMSG_BT_CS_IR9.7' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 103092 ;
	}

#paramId: 500354
#Synth. Sat. brightness temperature clear sky
'SYNMSG_BT_CS_WV6.2' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 161290 ;
	}

#paramId: 500355
#Synth. Sat. brightness temperature clear sky
'SYNMSG_BT_CS_WV7.3' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 136986 ;
	}

#paramId: 500356
#Synth. Sat. radiance cloudy
'SYNMSG_RAD_CL_IR10.8' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 16 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 92592 ;
	}

#paramId: 500357
#Synth. Sat. radiance cloudy
'SYNMSG_RAD_CL_IR12.1' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 16 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 82644 ;
	}

#paramId: 500358
#Synth. Sat. radiance cloudy
'SYNMSG_RAD_CL_IR13.4' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 16 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 74626 ;
	}

#paramId: 500359
#Synth. Sat. radiance cloudy
'SYNMSG_RAD_CL_IR3.9' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 16 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 256410 ;
	}

#paramId: 500360
#Synth. Sat. radiance cloudy
'SYNMSG_RAD_CL_IR8.7' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 16 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 114942 ;
	}

#paramId: 500361
#Synth. Sat. radiance cloudy
'SYNMSG_RAD_CL_IR9.7' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 16 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 103092 ;
	}

#paramId: 500362
#Synth. Sat. radiance cloudy
'SYNMSG_RAD_CL_WV6.2' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 16 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 161290 ;
	}

#paramId: 500363
#Synth. Sat. radiance cloudy
'SYNMSG_RAD_CL_WV7.3' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 16 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 136986 ;
	}

#paramId: 500364
#Synth. Sat. radiance clear sky
'SYNMSG_RAD_CS_IR10.8' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 92592 ;
	}

#paramId: 500365
#Synth. Sat. radiance clear sky
'SYNMSG_RAD_CS_IR12.1' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 82644 ;
	}

#paramId: 500366
#Synth. Sat. radiance clear sky
'SYNMSG_RAD_CS_IR13.4' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 74626 ;
	}

#paramId: 500367
#Synth. Sat. radiance clear sky
'SYNMSG_RAD_CS_IR3.9' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 256410 ;
	}

#paramId: 500368
#Synth. Sat. radiance clear sky
'SYNMSG_RAD_CS_IR8.7' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 114942 ;
	}

#paramId: 500369
#Synth. Sat. radiance clear sky
'SYNMSG_RAD_CS_IR9.7' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 103092 ;
	}

#paramId: 500370
#Synth. Sat. radiance clear sky
'SYNMSG_RAD_CS_WV6.2' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 161290 ;
	}

#paramId: 500371
#Synth. Sat. radiance clear sky
'SYNMSG_RAD_CS_WV7.3' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 136986 ;
	}

#paramId: 500372
#smoothed forecast, temperature
'T_2M_S' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 typeOfGeneratingProcess = 197 ;
	}

#paramId: 500373
#smoothed forecast, maximum temp.
'TMAX_2M_S' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 typeOfGeneratingProcess = 197 ;
	}

#paramId: 500374
#smoothed forecast, minimum temp.
'TMIN_2M_S' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 typeOfGeneratingProcess = 197 ;
	}

#paramId: 500375
#smoothed forecast, dew point temp.
'TD_2M_S' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 typeOfGeneratingProcess = 197 ;
	}

#paramId: 500376
#smoothed forecast, u comp. of wind
'U_10M_S' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 typeOfGeneratingProcess = 197 ;
	}

#paramId: 500377
#smoothed forecast, v comp. of wind
'V_10M_S' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 typeOfGeneratingProcess = 197 ;
	}

#paramId: 500378
#smoothed forecast, total precipitation (Accumulation)
'TOT_PREC_S' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfGeneratingProcess = 197 ;
	}

#paramId: 500379
#smoothed forecast, total cloud cover
'CLCT_S' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 1 ;
	 typeOfGeneratingProcess = 197 ;
	}

#paramId: 500380
#smoothed forecast, cloud cover low
'CLCL_S' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 22 ;
	 typeOfSecondFixedSurface = 1 ;
	 typeOfFirstFixedSurface = 100 ;
	 scaleFactorOfFirstFixedSurface = -2 ;
	 scaledValueOfFirstFixedSurface = 800 ;
	 typeOfGeneratingProcess = 197 ;
	}

#paramId: 500381
#smoothed forecast, cloud cover medium
'CLCM_S' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 22 ;
	 typeOfSecondFixedSurface = 100 ;
	 scaleFactorOfSecondFixedSurface = -2 ;
	 scaledValueOfSecondFixedSurface = 800 ;
	 typeOfFirstFixedSurface = 100 ;
	 scaleFactorOfFirstFixedSurface = -2 ;
	 scaledValueOfFirstFixedSurface = 400 ;
	 typeOfGeneratingProcess = 197 ;
	}

#paramId: 500382
#smoothed forecast, cloud cover high
'CLCH_S' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 22 ;
	 typeOfSecondFixedSurface = 100 ;
	 scaleFactorOfSecondFixedSurface = -2 ;
	 scaledValueOfSecondFixedSurface = 400 ;
	 typeOfFirstFixedSurface = 100 ;
	 scaleFactorOfFirstFixedSurface = -2 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 typeOfGeneratingProcess = 197 ;
	}

#paramId: 500383
#smoothed forecast, large-scale snowfall
'SNOW_GSP_S' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 56 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfGeneratingProcess = 197 ;
	}

#paramId: 500384
#smoothed forecast, soil temperature
'T_S_S' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 typeOfGeneratingProcess = 197 ;
	}

#paramId: 500385
#smoothed forecast, wind speed (gust)
'VMAX_10M_S' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 typeOfGeneratingProcess = 197 ;
	}

#paramId: 500386
#calibrated forecast, total precipitation  (Accumulation)
'TOT_PREC_C' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfGeneratingProcess = 198 ;
	}

#paramId: 500387
#calibrated forecast, large-scale snowfall
'SNOW_GSP_C' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 56 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfGeneratingProcess = 198 ;
	}

#paramId: 500388
#calibrated forecast, wind speed (gust)
'VMAX_10M_C' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 typeOfGeneratingProcess = 198 ;
	}

#paramId: 500389
#Obser. Sat. Meteosat sec. generation Albedo (scaled)
'OBSMSG_ALB_HRV' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 typeOfGeneratingProcess = 8 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 2000000 ;
	}

#paramId: 500390
#Obser. Sat. Meteosat sec. generation Albedo (scaled)
'OBSMSG_ALB_NIR1.6' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 typeOfGeneratingProcess = 8 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 625000 ;
	}

#paramId: 500391
#Obser. Sat. Meteosat sec. generation Albedo (scaled)
'OBSMSG_ALB_VIS0.6' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 typeOfGeneratingProcess = 8 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 1666666 ;
	}

#paramId: 500392
#Obser. Sat. Meteosat sec. generation Albedo (scaled)
'OBSMSG_ALB_VIS0.8' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 typeOfGeneratingProcess = 8 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 1250000 ;
	}

#paramId: 500393
#Obser. Sat. Meteosat sec. generation brightness temperature
'OBSMSG_BT_IR10.8' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	 typeOfGeneratingProcess = 8 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 92592 ;
	}

#paramId: 500394
#Obser. Sat. Meteosat sec. generation brightness temperature
'OBSMSG_BT_IR12.0' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	 typeOfGeneratingProcess = 8 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 83333 ;
	}

#paramId: 500395
#Obser. Sat. Meteosat sec. generation brightness temperature
'OBSMSG_BT_IR13.4' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	 typeOfGeneratingProcess = 8 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 74626 ;
	}

#paramId: 500396
#Obser. Sat. Meteosat sec. generation brightness temperature
'OBSMSG_BT_IR3.9' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	 typeOfGeneratingProcess = 8 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 256410 ;
	}

#paramId: 500397
#Obser. Sat. Meteosat sec. generation brightness temperature
'OBSMSG_BT_IR8.7' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	 typeOfGeneratingProcess = 8 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 114942 ;
	}

#paramId: 500398
#Obser. Sat. Meteosat sec. generation brightness temperature
'OBSMSG_BT_IR9.7' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	 typeOfGeneratingProcess = 8 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 103092 ;
	}

#paramId: 500399
#Obser. Sat. Meteosat sec. generation brightness temperature
'OBSMSG_BT_WV6.2' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	 typeOfGeneratingProcess = 8 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 161290 ;
	}

#paramId: 500400
#Obser. Sat. Meteosat sec. generation brightness temperature
'OBSMSG_BT_WV7.3' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	 typeOfGeneratingProcess = 8 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 136986 ;
	}

#paramId: 500401
#Total Precipitation Difference
'TOT_PREC_D' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfStatisticalProcessing = 4 ;
	}

#paramId: 500419
#Net short wave radiation flux
'ASOB_T' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfGeneratingProcess = 1 ;
	}

#paramId: 500420
#Net long wave radiation flux
'ATHB_T' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfGeneratingProcess = 1 ;
	}

#paramId: 500421
#Net short wave radiation flux (at the surface)
'ASOB_S' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfGeneratingProcess = 1 ;
	}

#paramId: 500422
#Net long wave radiation flux
'ATHB_S' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfGeneratingProcess = 1 ;
	}

#paramId: 500468
#UV Index, clear sky, maximum
'UVI_MAX_CS' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 50 ;
	 typeOfStatisticalProcessing = 2 ;
	}

#paramId: 500469
#Total ozone
'TOT_O3' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 500474
#wind chill factor
'WCF' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 13 ;
	}

#paramId: 500475
#Water temperature
'T_SEA' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	}

#paramId: 500477
#Absolute Vorticity
'ABSV' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 10 ;
	}

#paramId: 500482
#Upward diffusive short wave radiation flux at surface ( mean over forecast time)
'ASWDIFU_S' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500490
#Water Fraction
'FR_LAKE' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	}

#paramId: 500491
#Lake depth
'DEPTH_LK' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfSecondFixedSurface = 162 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500492
#Wind fetch
'FETCH_LK' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 33 ;
	}

#paramId: 500493
#Attenuation coefficient of water with respect to solar radiation
'GAMSO_LK' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 11 ;
	 typeOfSecondFixedSurface = 162 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500494
#Depth of thermally active layer of bottom sediment
'DP_BS_LK' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	 typeOfSecondFixedSurface = 164 ;
	 typeOfFirstFixedSurface = 162 ;
	}

#paramId: 500495
#Temperature at the lower boundary of the thermally active layer of bottom sediment
'T_BS_LK' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 164 ;
	}

#paramId: 500496
#Mean temperature of the water column
'T_MNW_LK' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfSecondFixedSurface = 162 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500497
#Mixed-layer temperature
'T_WML_LK' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfSecondFixedSurface = 166 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500498
#Bottom temperature (temperature at the water-bottom sediment interface)
'T_BOT_LK' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 162 ;
	}

#paramId: 500499
#Mixed-layer depth
'H_ML_LK' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfSecondFixedSurface = 166 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500500
#Shape factor with respect to the temperature profile in the thermocline
'C_T_LK' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 10 ;
	 typeOfSecondFixedSurface = 162 ;
	 typeOfFirstFixedSurface = 166 ;
	}

#paramId: 500501
#Temperature at the lower boundary of the upper layer of bottom sediment (penetrated by thermal wave)
'T_B1_LK' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 165 ;
	}

#paramId: 500502
#Sediment thickness of the upper layer of bottom sediments
'H_B1_LK' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	 typeOfSecondFixedSurface = 165 ;
	 typeOfFirstFixedSurface = 162 ;
	}

#paramId: 500539
#cloud top height
'CL_TOP_HEIGHT' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 2 ;
	}

#paramId: 500543
#vertical vorticity
'VORTIC_W' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 12 ;
	}

#paramId: 500544
#Potential vorticity
'POT_VORTIC' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 14 ;
	}

#paramId: 500545
#Density
'DEN' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 10 ;
	}

#paramId: 500546
#Altimeter Settings
'ALTS' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 11 ;
	}

#paramId: 500547
#Convective Precipitation (difference)
'PREC_CON_D' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 37 ;
	 typeOfStatisticalProcessing = 4 ;
	}

#paramId: 500548
#Soil moisture
'SM' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 19 ;
	}

#paramId: 500549
#Soil moisture
'SM' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 22 ;
	}

#paramId: 500568
#Geopotential height
'GH' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 5 ;
	}

#paramId: 500569
#Relative Divergenz
'RDIV' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 13 ;
	}

#paramId: 500574
#Logarithm of Pressure
'LNPS' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 25 ;
	}

#paramId: 500579
#Soil Temperature (layer)
'T_S_L' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 typeOfSecondFixedSurface = 106 ;
	 typeOfFirstFixedSurface = 106 ;
	}

#paramId: 500580
#Soil Moisture Content (0-7 cm)
'W_G3' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 20 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaleFactorOfSecondFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = 7 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	}

#paramId: 500581
#Soil Moisture Content (7-50 cm)
'W_G4' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 20 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaleFactorOfSecondFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = 50 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfFirstFixedSurface = 7 ;
	}

#paramId: 500584
#Sunshine duration
'DURSUN' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 33 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 500588
#Snow melt
'SNOW_MELT' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 16 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 500590
#ICAO Standard Atmosphere reference height
'ICAHT' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 3 ;
	}

#paramId: 500593
#Global radiation flux
'GRAD' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 3 ;
	}

#paramId: 500594
#exner pressure
'EXNER' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 26 ;
	}

#paramId: 500595
#normal wind component
'VN' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 34 ;
	}

#paramId: 500596
#tangential wind component
'VT' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 35 ;
	}

#paramId: 500597
#virtual potential temperature
'THETA_V' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 15 ;
	}

#paramId: 500598
#Current Direction
'CURD' = {
	 discipline = 10 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	}

#paramId: 500599
#Current Speed
'CURS' = {
	 discipline = 10 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	}

#paramId: 500642
#Lapse rate
'LAPSE_RATE' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 8 ;
	}

#paramId: 500905
#Specific Humidity (S)
'QV_S' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 502307
#Albedo - diffusive solar - time average (0.3 - 5.0 m-6)
'ALB_DIF12' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 18 ;
	 typeOfStatisticalProcessing = 0 ;
	}

#paramId: 502308
#Albedo - diffusive solar (0.3 - 5.0 m-6)
'ALB_DIF' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 18 ;
	}

#paramId: 502309
#center latitude
'CLAT' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 1 ;
	 numberOfGridInReference = 1 ;
	}

#paramId: 502310
#center longitude
'CLON' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 2 ;
	 numberOfGridInReference = 1 ;
	}

#paramId: 502311
#edge midpoint latitude
'ELAT' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 1 ;
	 numberOfGridInReference = 3 ;
	}

#paramId: 502312
#edge midpoint longitude
'ELON' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 2 ;
	 numberOfGridInReference = 3 ;
	}

#paramId: 502313
#vertex latitude
'VLAT' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 1 ;
	 numberOfGridInReference = 2 ;
	}

#paramId: 502314
#vertex longitude
'VLON' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 2 ;
	 numberOfGridInReference = 2 ;
	}

#paramId: 502315
#Number of cloud droplets per unit mass of air
'NCCLOUD' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 28 ;
	}

#paramId: 502316
#Number of cloud ice particles per unit mass of air
'NCICE' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 29 ;
	}

#paramId: 502317
#Latent Heat Net Flux - instant - at surface
'LHFL_S' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 502318
#Sensible Heat Net Flux - instant - at surface
'SHFL_S' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 502319
#Latent Heat Net Flux - accumulated _ surface
'ACCLHFL_S' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 502320
#Sensible Heat Net Flux - accumulated _ surface
'ACCSHFL_S' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 11 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 502321
#Net short wave radiation flux - accumulated _ surface
'ACCSOB_S' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 502322
#Net long wave radiation flux - accumulated _  surface
'ACCTHB_S' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 502323
#Net long wave radiation flux  - accumulated _ model top
'ACCTHB_T' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 8 ;
	}

#paramId: 502327
#Net short wave radiation flux - accumulated _ model top
'ACCSOB_T' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 8 ;
	}

#paramId: 502328
#Snow temperature  - multi level
'T_SNOW_M' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 114 ;
	}

#paramId: 502329
#Snow depth  - multi level
'H_SNOW_M' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 114 ;
	}

#paramId: 502330
#Snow density in  - multi level
'RHO_SNOW_M' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 61 ;
	 typeOfFirstFixedSurface = 114 ;
	}

#paramId: 502331
#Water equivalent  of accumulated snoe depth in - multi level
'W_SNOW_M' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 60 ;
	 typeOfFirstFixedSurface = 114 ;
	}

#paramId: 502333
#salinity
'SALT_LK' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 12 ;
	}

#paramId: 502334
#Stream function
'STRF' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 4 ;
	}

#paramId: 502335
#Velocity potential
'VPOT' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 5 ;
	}

#paramId: 502336
#Skin temperature
'SKT' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 502340
#Snow cover
'SNOWC' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 42 ;
	}

#paramId: 502341
#Cloud Cover (0 - 400 hPa)
'CLCH' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 22 ;
	 typeOfSecondFixedSurface = 100 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 40000 ;
	 typeOfFirstFixedSurface = 100 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	}

#paramId: 502342
#Cloud Cover (400 - 800 hPa)
'CLCM' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 22 ;
	 typeOfSecondFixedSurface = 100 ;
	 scaledValueOfSecondFixedSurface = 80000 ;
	 typeOfFirstFixedSurface = 100 ;
	 scaledValueOfFirstFixedSurface = 40000 ;
	}

#paramId: 502343
#Cloud Cover (800 hPa - Soil)
'CLCL' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 22 ;
	 typeOfSecondFixedSurface = 1 ;
	 typeOfFirstFixedSurface = 100 ;
	 scaledValueOfFirstFixedSurface = 80000 ;
	}

#paramId: 502348
#Water Runoff (s)
'RUNOFF_S' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	}

#paramId: 502349
#Water Runoff
'RUNOFF_G' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaleFactorOfFirstFixedSurface = 1 ;
	 scaledValueOfFirstFixedSurface = 1 ;
	}

#paramId: 502397
#Virtual Temperature
'VTMP' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	}

#paramId: 502424
#Vertical u-component shear
'VUCSH' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 15 ;
	}

#paramId: 502425
#Vertical v-component shear
'VVCSH' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 16 ;
	}

#paramId: 502693
#Potential temperature
'PT' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	}

#paramId: 502700
#Boundary layer dissipation
'BLD' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 20 ;
	}

#paramId: 502701
#Sunshine duration
'SUND' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 24 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 502702
#Brightness temperature
'BTMP' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 4 ;
	}

#paramId: 502703
#Heat index
'HEATX' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 12 ;
	}

#paramId: 502705
#Total column water
'TCW' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 51 ;
	}

#paramId: 502706
#Large scale precipitation (non-convective)
'NCPCP' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 9 ;
	}

#paramId: 502707
#Snowfall rate water equivalent
'SRWEQ' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 12 ;
	}

#paramId: 502708
#Convective snow
'SNOC' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	}

#paramId: 502709
#Large scale snow
'SNOL' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	}

#paramId: 502710
#Snow age
'SNOAG' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	}

#paramId: 502711
#Absolute humidity
'ABSH' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 18 ;
	}

#paramId: 502712
#Precipitation type
'PTYPE' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 19 ;
	}

#paramId: 502713
#Integrated liquid water
'ILIQW' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 20 ;
	}

#paramId: 502714
#Condensate
'TCOND' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 21 ;
	}

#paramId: 502715
#Ice water mixing ratio
'ICMR' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 23 ;
	}

#paramId: 502717
#Maximum relative humidity
'MAXRH' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 27 ;
	}

#paramId: 502718
#Maximum absolute humidity
'MAXAH' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 28 ;
	}

#paramId: 502719
#Total snowfall
'ASNOW' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 29 ;
	}

#paramId: 502720
#Precipitable water category
'PWCAT' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 30 ;
	}

#paramId: 502721
#Hail
'HAIL' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 31 ;
	}

#paramId: 502722
#Categorical rain
'CRAIN' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 33 ;
	}

#paramId: 502723
#Categorical freezing rain
'CFRZR' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 34 ;
	}

#paramId: 502724
#Categorical ice pellets
'CICEP' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 35 ;
	}

#paramId: 502725
#Categorical snow
'CSNOW' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 36 ;
	}

#paramId: 502727
#Percent frozen precipitation
'CPOFP' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 39 ;
	}

#paramId: 502728
#Potential evaporation
'PEVAP' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 40 ;
	}

#paramId: 502729
#Potential evaporation rate
'PEVPR' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 41 ;
	}

#paramId: 502730
#Rain fraction of total cloud water
'FRAIN' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 43 ;
	}

#paramId: 502731
#Rime factor
'RIME' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 44 ;
	}

#paramId: 502732
#Large scale water precipitation (non-convective)
'LSWP' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 47 ;
	}

#paramId: 502733
#Convective water precipitation
'CWP' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 48 ;
	}

#paramId: 502734
#Total water precipitation
'TWATP' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 49 ;
	}

#paramId: 502735
#Total snow precipitation
'TSNOWP' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 50 ;
	}

#paramId: 502737
#Snow Fall water equivalent
'SF' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 53 ;
	}

#paramId: 502738
#Convective snowfall rate
'CSRATE' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 58 ;
	}

#paramId: 502739
#Large scale snowfall rate
'LSSRATE' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 59 ;
	}

#paramId: 502740
#Water equivalent of accumulated snow depth
'SDWE' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 13 ;
	}

#paramId: 502741
#Freezing rain precipitation rate
'FPRATE' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 67 ;
	}

#paramId: 502742
#Ice pellets precipitation rate
'IPRATE' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 68 ;
	}

#paramId: 502743
#Maximum wind speed
'MAXGUST' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 21 ;
	}

#paramId: 502744
#u-component of wind (gust)
'UGUST' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 23 ;
	}

#paramId: 502745
#v-component of wind (gust)
'VGUST' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 24 ;
	}

#paramId: 502746
#Horizontal momentum flux
'MFLX' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 26 ;
	}

#paramId: 502747
#U-component storm motion
'USTM' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 27 ;
	}

#paramId: 502748
#V-component storm motion
'VSTM' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 28 ;
	}

#paramId: 502749
#Thickness
'THICK' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 12 ;
	}

#paramId: 502751
#Minimum dew point depression
'MINDPD' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 14 ;
	}

#paramId: 502752
#Pressure altitude
'PRESALT' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 13 ;
	}

#paramId: 502753
#Density altitude
'DENALT' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 14 ;
	}

#paramId: 502754
#5-wave geopotential height
'5WAVH' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 15 ;
	}

#paramId: 502755
#Zonal flux of gravity wave stress
'U-GWD' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 16 ;
	}

#paramId: 502756
#Meridional flux of gravity wave stress
'V-GWD' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 17 ;
	}

#paramId: 502757
#Planetary boundary layer height
'HPBL' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	}

#paramId: 502758
#5-wave geopotential height anomaly
'5WAVA' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 19 ;
	}

#paramId: 502759
#Net short-wave radiation flux (top of atmosphere)
'NSWRT' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 1 ;
	}

#paramId: 502760
#Downward short-wave radiation flux
'DSWRF' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	}

#paramId: 502761
#Net short-wave radiation flux, clear sky
'NSWRFCS' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 11 ;
	}

#paramId: 502762
#Downward UV radiation
'DWUVR' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 12 ;
	}

#paramId: 502763
#Net long wave radiation flux (surface)
'NLWRS' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 0 ;
	}

#paramId: 502764
#Net long wave radiation flux (top of atmosphere)
'NLWRT' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 1 ;
	}

#paramId: 502765
#Downward long-wave radiation flux
'DLWRF' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 3 ;
	}

#paramId: 502766
#Upward long-wave radiation flux
'ULWRF' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 4 ;
	}

#paramId: 502767
#Net long-wave radiation flux, clear sky
'NLWRCS' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 6 ;
	}

#paramId: 502768
#Cloud Ice
'CICE' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 0 ;
	}

#paramId: 502769
#Cloud water
'CWAT' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 6 ;
	}

#paramId: 502770
#Cloud amount
'CDCA' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 7 ;
	}

#paramId: 502771
#Cloud type
'CDCT' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 8 ;
	}

#paramId: 502772
#Thunderstorm maximum tops
'TMAXT' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 9 ;
	}

#paramId: 502773
#Thunderstorm coverage
'THUNC' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 10 ;
	}

#paramId: 502774
#Cloud base
'CDCB' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 11 ;
	}

#paramId: 502775
#Cloud top
'CDCT' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 12 ;
	}

#paramId: 502776
#Cloud work function
'CWORK' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 15 ;
	}

#paramId: 502777
#Convective cloud efficiency
'CUEFI' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 16 ;
	}

#paramId: 502778
#Total condensate
'TCOND1' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 17 ;
	}

#paramId: 502779
#Total column-integrated cloud water
'TCOLW' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 18 ;
	}

#paramId: 502780
#Total column-integrated cloud ice
'TCOLI' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 19 ;
	}

#paramId: 502781
#Total column-integrated condensate
'TCOLC' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 20 ;
	}

#paramId: 502782
#Ice fraction of total condensate
'FICE' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 21 ;
	}

#paramId: 502783
#Cloud ice mixing ratio
'CDCIMR' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 23 ;
	}

#paramId: 502785
#K index
'KX' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 2 ;
	}

#paramId: 502786
#Total totals index
'TOTALX' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 4 ;
	}

#paramId: 502787
#Sweat index
'SX' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 5 ;
	}

#paramId: 502788
#Energy helicity index
'EHLX' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 9 ;
	}

#paramId: 502789
#Surface lifted index
'LFTX' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 10 ;
	}

#paramId: 502790
#Best (4-layer) lifted index
'4LFTX' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 11 ;
	}

#paramId: 502791
#Aerosol type
'AEROT' = {
	 discipline = 0 ;
	 parameterCategory = 13 ;
	 parameterNumber = 0 ;
	}

#paramId: 502792
#Base spectrum width
'BSWID' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 0 ;
	}

#paramId: 502793
#Base radial velocity
'BRVEL' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 2 ;
	}

#paramId: 502794
#Vertically-integrated liquid
'VERIL' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 3 ;
	}

#paramId: 502795
#Layer-maximum base reflectivity
'LMAXBR' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 4 ;
	}

#paramId: 502796
#Precipitation
'PREC' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 502797
#Air concentration of Caesium 137
'ACCES' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 0 ;
	}

#paramId: 502798
#Air concentration of Iodine 131
'ACIOD' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 1 ;
	}

#paramId: 502799
#Air concentration of radioactive pollutant
'ACRADP' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 2 ;
	}

#paramId: 502800
#Ground deposition of Caesium 137
'GDCES' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 3 ;
	}

#paramId: 502801
#Ground deposition of Iodine 131
'GDIOD' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 4 ;
	}

#paramId: 502802
#Ground deposition of radioactive pollutant
'GDRADP' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 5 ;
	}

#paramId: 502843
#Time-integrated air concentration of caesium pollutant
'TIACCP' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 6 ;
	}

#paramId: 502844
#Time-integrated air concentration of iodine pollutant
'TIACIP' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 7 ;
	}

#paramId: 502845
#Time-integrated air concentration of radioactive pollutant
'TIACRP' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 8 ;
	}

#paramId: 502846
#Volcanic ash
'VOLASH' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 4 ;
	}

#paramId: 502847
#Icing top
'ICIT' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 5 ;
	}

#paramId: 502848
#Icing base
'ICIB' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 6 ;
	}

#paramId: 502849
#Turbulence top
'TURBT' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 8 ;
	}

#paramId: 502850
#Turbulence base
'TURBB' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 9 ;
	}

#paramId: 502851
#Turbulence
'TURB' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 10 ;
	}

#paramId: 502852
#Planetary boundary layer regime
'PBLREG' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 12 ;
	}

#paramId: 502853
#Contrail intensity
'CONTI' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 13 ;
	}

#paramId: 502854
#Contrail engine type
'CONTET' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 14 ;
	}

#paramId: 502855
#Contrail top
'CONTT' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 15 ;
	}

#paramId: 502856
#Contrail base
'CONTB' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 16 ;
	}

#paramId: 502857
#Maximum snow albedo
'MXALB' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 17 ;
	}

#paramId: 502858
#Icing
'ICI' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 20 ;
	}

#paramId: 502859
#Horizontal extent of cumulonimbus (CB)
'CBHEXT' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 25 ;
	}

#paramId: 502860
#In-cloud turbulence
'ICT' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 21 ;
	}

#paramId: 502861
#Clear air turbulence (CAT)
'CAT' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 22 ;
	}

#paramId: 502862
#Supercooled large droplet probability (see Note 4)
'SLDP' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 23 ;
	}

#paramId: 502864
#Seconds prior to initial reference time (defined in Section 1)
'TSEC' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 0 ;
	}

#paramId: 502865
#Flash flood guidance (Encoded as an accumulation over a floating subinterval of time between the ref
'FFLDG' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	}

#paramId: 502866
#Flash flood runoff (Encoded as an accumulation over a floating subinterval of time)
'FFLDRO' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	}

#paramId: 502867
#Remotely sensed snow cover
'RSSC' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	}

#paramId: 502868
#Elevation of snow covered terrain
'ESCT' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	}

#paramId: 502869
#Snow water equivalent percent of normal
'SWEPON' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	}

#paramId: 502870
#Baseflow-groundwater runoff
'BGRUN' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 5 ;
	}

#paramId: 502871
#Storm surface runoff
'SSRUN' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	}

#paramId: 502872
#Conditional percent precipitation amount fractile for an overall period (Encoded as an accumulation)
'CPPOP' = {
	 discipline = 1 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	}

#paramId: 502873
#Percent precipitation in a sub-period of an overall period (Encoded as per cent accumulation over th
'PPOSP' = {
	 discipline = 1 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	}

#paramId: 502874
#Probability of 0.01 inch of precipitation (POP)
'POP' = {
	 discipline = 1 ;
	 parameterCategory = 1 ;
	 parameterNumber = 2 ;
	}

#paramId: 502875
#Evapotranspiration
'EVAPT' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	}

#paramId: 502876
#Land use
'LANDU' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 8 ;
	}

#paramId: 502877
#Volumetric soil moisture content
'SOILW' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 9 ;
	}

#paramId: 502878
#Ground heat flux
'GFLUX' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 10 ;
	}

#paramId: 502879
#Moisture availability
'MSTAV' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 11 ;
	}

#paramId: 502880
#Exchange coefficient
'SFEXC' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 12 ;
	}

#paramId: 502881
#Blackadar mixing length scale
'BMIXL' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 14 ;
	}

#paramId: 502882
#Canopy conductance
'CCOND' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 15 ;
	}

#paramId: 502883
#Solar parameter in canopy conductance
'RCS' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 18 ;
	}

#paramId: 502885
#Soil moisture parameter in canopy conductance
'RCSOL' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 20 ;
	}

#paramId: 502886
#Humidity parameter in canopy conductance
'RCQ' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 21 ;
	}

#paramId: 502887
#Column-integrated soil water
'CISOILW' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 23 ;
	}

#paramId: 502888
#Heat flux
'HFLUX' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 24 ;
	}

#paramId: 502889
#Volumetric soil moisture
'VSW' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	}

#paramId: 502890
#Volumetric wilting point
'VWILTM' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 27 ;
	}

#paramId: 502891
#Upper layer soil temperature
'UPLST' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 1 ;
	}

#paramId: 502892
#Upper layer soil moisture
'UPLSM' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 2 ;
	}

#paramId: 502893
#Lower layer soil moisture
'LOWLSM' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 3 ;
	}

#paramId: 502894
#Bottom layer soil temperature
'BOTLST' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 4 ;
	}

#paramId: 502895
#Liquid volumetric soil moisture (non-frozen)
'SOIL1' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 5 ;
	}

#paramId: 502896
#Number of soil layers in root zone
'RLYRS' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	}

#paramId: 502897
#Transpiration stress-onset (soil moisture)
'SMREF' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 7 ;
	}

#paramId: 502898
#Direct evaporation cease (soil moisture)
'SMDRY' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 8 ;
	}

#paramId: 502899
#Soil porosity
'POROS' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 9 ;
	}

#paramId: 502900
#Liquid volumetric soil moisture (non-frozen)
'LIQVSM' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 10 ;
	}

#paramId: 502919
#Volumetric transpiration stress-onset (soil moisture)
'VOLTSO' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 11 ;
	}

#paramId: 502920
#Transpiration stress-onset (soil moisture)
'TRANSO' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 12 ;
	}

#paramId: 502921
#Volumetric direct evaporation cease (soil moisture)
'VOLDEC' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 13 ;
	}

#paramId: 502922
#Direct evaporation cease (soil moisture)
'DIREC' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 14 ;
	}

#paramId: 502923
#Soil porosity
'SOILP' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 15 ;
	}

#paramId: 502924
#Volumetric saturation of soil moisture
'VSOSM' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 16 ;
	}

#paramId: 502926
#Estimated precipitation
'ESTP' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	}

#paramId: 502927
#Instantaneous rain rate
'IRRATE' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	}

#paramId: 502928
#Cloud top height quality indicator
'CTOPHQI' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 3 ;
	}

#paramId: 502929
#Estimated u component of wind
'ESTU' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 4 ;
	}

#paramId: 502930
#Estimated v component of wind
'ESTV' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 5 ;
	}

#paramId: 502931
#Number of pixels used
'NPIXU' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 6 ;
	}

#paramId: 502932
#Solar zenith angle
'SOLZA' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 7 ;
	}

#paramId: 502933
#Reflectance in 0.6 micron channel
'RFL06' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 9 ;
	}

#paramId: 502934
#Reflectance in 0.8 micron channel
'RFL08' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 10 ;
	}

#paramId: 502935
#Reflectance in 1.6 micron channel
'RFL16' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 11 ;
	}

#paramId: 502936
#Reflectance in 3.9 micron channel
'RFL39' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 12 ;
	}

#paramId: 502937
#Atmospheric divergence
'ATMDIV' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 13 ;
	}

#paramId: 502938
#Primary wave direction
'DIRPW' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 10 ;
	}

#paramId: 502939
#Primary wave mean period
'PERPW' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 11 ;
	}

#paramId: 502940
#Secondary wave mean period
'PERSW' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 13 ;
	}

#paramId: 502941
#Deviation of sea level from mea
'DSLM' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 1 ;
	}

#paramId: 502942
#Seconds prior to initial reference time (defined in Section 1)
'TSEC' = {
	 discipline = 10 ;
	 parameterCategory = 191 ;
	 parameterNumber = 0 ;
	}

#paramId: 502943
#Standard deviation of height
'HSTDV' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 7 ;
	}

#paramId: 502944
#Maximum temperature
'TMAX' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	}

#paramId: 502945
#Minimum temperature
'TMIN' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 5 ;
	}

#paramId: 502946
#Visibility
'VIS' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 0 ;
	}

#paramId: 502947
#Radar spectra (2)
'RDSP2' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 7 ;
	}

#paramId: 502948
#Radar spectra (3)
'RDSP3' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 8 ;
	}

#paramId: 502949
#Parcel lifted index (to 500 hPa)
'PLI' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 0 ;
	}

#paramId: 502950
#Temperature anomaly
'TA' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 9 ;
	}

#paramId: 502951
#Pressure anomaly
'PRESA' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 8 ;
	}

#paramId: 502952
#Geopotential height anomaly
'GPA' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 9 ;
	}

#paramId: 502953
#Montgomery stream Function
'MNTSF' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 6 ;
	}

#paramId: 502954
#Sigma coordinate vertical velocity
'SGCVV' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 7 ;
	}

#paramId: 502955
#Absolute divergence
'ABSD' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 11 ;
	}

#paramId: 502958
#U-component of current
'UCURR' = {
	 discipline = 10 ;
	 parameterCategory = 1 ;
	 parameterNumber = 2 ;
	}

#paramId: 502959
#V-component of current
'VCURR' = {
	 discipline = 10 ;
	 parameterCategory = 1 ;
	 parameterNumber = 3 ;
	}

#paramId: 502960
#Precipitable water
'PWAT' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 3 ;
	}

#paramId: 502961
#Saturation deficit
'SATD' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 5 ;
	}

#paramId: 502962
#Precipitation rate
'PRATE' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 7 ;
	}

#paramId: 502963
#Thunderstorm probability
'TSTM' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 2 ;
	}

#paramId: 502964
#Convective precipitation (water)
'ACPCP' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 10 ;
	}

#paramId: 502965
#Transient thermocline depth
'TTHDP' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 2 ;
	}

#paramId: 502966
#Main thermocline depth
'MTHD' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 0 ;
	}

#paramId: 502967
#Main thermocline anomaly
'MTHA' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 1 ;
	}

#paramId: 502968
#Best lifted index (to 500 hPa)
'BLI' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 1 ;
	}

#paramId: 502969
#Soil moisture content
'SSW' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	}

#paramId: 503011
#Salinity
'S' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 3 ;
	}

#paramId: 503012
#Direction of ice drift
'DICED' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	}

#paramId: 503013
#Speed of ice drift
'SICED' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	}

#paramId: 503014
#U-component of ice drift
'UICE' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 4 ;
	}

#paramId: 503015
#V-component of ice drift
'VICE' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 5 ;
	}

#paramId: 503016
#Ice growth rate
'ICEG' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 6 ;
	}

#paramId: 503017
#Ice divergence
'ICED' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 7 ;
	}

#paramId: 503019
#Secondary wave direction
'DIRSW' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 12 ;
	}

#paramId: 503020
#Net short-wave radiation flux (surface)
'NSWRS' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 0 ;
	}

#paramId: 503021
#Radiance (with respect to wave number)
'LWRAD' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 5 ;
	}

#paramId: 503022
#Radiance (with respect to wave length)
'SWRAD' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 6 ;
	}

#paramId: 503023
#Convective inhibition
'CIN' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 7 ;
	}

#paramId: 503024
#Wind mixing energy
'WMIXE' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 19 ;
	}

#paramId: 503025
#Soil Temperature
'ST' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	}

#paramId: 503028
#Wilting point
'WILT' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 26 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 2 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	}

#paramId: 503038
#Snow phase change heat flux
'SNOHF' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 16 ;
	}

#paramId: 503039
#Vapor pressure
'VAPP' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 4 ;
	}

#paramId: 503047
#Land use class fraction
'FR_LUC' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 36 ;
	}

#paramId: 503048
#Saturation of soil moisture
'SATOSM' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 17 ;
	}

#paramId: 503062
#Upward diffusive short wave radiation flux at surface ( mean over forecast time)
'SWDIFUS_RAD' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503063
#Momentum Flux, U-Component (m)
'UMFL_S' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503064
#Momentum Flux, V-Component (m)
'VMFL_S' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503075
#Geometric height of the earths surface above mean sea level at vertex point (ICON)
'HSURF_V' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	 numberOfGridInReference = 2 ;
	 typeOfSecondFixedSurface = 101 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503076
#Gravity wave dissipation
'AVDIS_SSO' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 23 ;
	 typeOfStatisticalProcessing = 0 ;
	}

#paramId: 503080
#Land use class
'LUC' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 35 ;
	}

#paramId: 503081
#Water depth
'DPTH' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	}

#paramId: 503082
#Friction velocity
'USTR' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 17 ;
	}

#paramId: 503083
#Coefficient of drag with waves
'DRAG' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 16 ;
	}

#paramId: 503084
#Normalized wave stress
'STRS' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 19 ;
	}

#paramId: 503085
#Inverse mean frequency of wind waves
'TM1W' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 26 ;
	}

#paramId: 503086
#Mean zero-crossing period of wind waves
'TM2W' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 29 ;
	}

#paramId: 503087
#Directional width of wind waves
'SPRW' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 32 ;
	}

#paramId: 503088
#Inverse mean frequency of total swell
'TM1S' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 27 ;
	}

#paramId: 503089
#Inverse mean zero crossing period of total swell
'TM2S' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 30 ;
	}

#paramId: 503090
#Directional width of total swell
'SPRS' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 33 ;
	}

#paramId: 503091
#Goda peakedness parameter
'GODA' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 45 ;
	}

#paramId: 503092
#Spectral kurtosis
'SKUR' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 43 ;
	}

#paramId: 503093
#Benjamin-Feir index
'BEFI' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 44 ;
	}

#paramId: 503094
#Maximum individual wave height
'MXWH' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 24 ;
	}

#paramId: 503095
#Maximum wave period
'MXWP' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 23 ;
	}

#paramId: 503097
#Meansquare slope
'SQSL' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 20 ;
	}

#paramId: 503106
#Hail  mixing ratio
'QH' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 71 ;
	}

#paramId: 503107
#Hail
'TQH' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 72 ;
	}

#paramId: 503108
#Hail  precipitation rate
'PRH_GSP' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 73 ;
	}

#paramId: 503109
#Reflectivity of cloud droplets
'DBZ_CLOUD' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 9 ;
	}

#paramId: 503110
#Reflectivity of  cloud ice
'DBZ_ICE' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 10 ;
	}

#paramId: 503111
#Reflectivity of snow
'DBZ_SNOW' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 11 ;
	}

#paramId: 503112
#Reflectivity of rain
'DBZ_RAIN' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 12 ;
	}

#paramId: 503113
#Reflectivity of graupel
'DBZ_GRAUPEL' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 13 ;
	}

#paramId: 503114
#Reflectivity of hail
'DBZ_HAIL' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 14 ;
	}

#paramId: 503130
#Hail  precipitation rate, accumulation
'HAIL_GSP' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 73 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 503132
#Number density of cloud droplets
'NDCLOUD' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 30 ;
	}

#paramId: 503133
#Number density of cloud ice particles
'NDICE' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 31 ;
	}

#paramId: 503134
#Downward long-wave radiation flux
'THDS_RAD' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503135
#Downward long-wave radiation flux avg
'ATHD_S' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503136
#Downward long-wave radiation flux accum
'ACCTHD_S' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503145
#2m absolute humidity
'ABSH_2M' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 503154
#Bulk Richardson number
'BRN' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 16 ;
	}

#paramId: 503155
#Cape of mixed (mean) layer parcel, ascent up to 3 km
'CAPE_3KM' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfSecondFixedSurface = 192 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 3000 ;
	}

#paramId: 503166
#Geostrophic wind direction
'DD_G' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 43 ;
	}

#paramId: 503169
#Dewpoint depression
'D_TD' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 7 ;
	}

#paramId: 503170
#2m dewpoint depression
'D_TD_2M' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 503173
#Geostrophic wind speed
'SP_G' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 44 ;
	}

#paramId: 503174
#Downward short wave radiation flux at surface (time average)
'ASOD_S' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503186
#Height of lifting condensation level of mixed (mean) layer parcel
'LCL_ML' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	 typeOfSecondFixedSurface = 192 ;
	 typeOfFirstFixedSurface = 5 ;
	}

#paramId: 503192
#Humidity mixing ratio
'MIXRAT' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 2 ;
	}

#paramId: 503193
#2m Humidity mixing ratio
'MIXRAT_2M' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 503195
#relative humidity over ice
'RH_ICE' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 94 ;
	}

#paramId: 503196
#Gradient Richardson number
'RI' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 17 ;
	}

#paramId: 503197
#Showalter index
'SI' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 13 ;
	}

#paramId: 503204
#Surface lifted index
'SLI' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 10 ;
	}

#paramId: 503210
#2m potential temperature
'PT_2M' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 503211
#Dew point temperature
'TD' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	}

#paramId: 503212
#2m equivalentTemperature
'THETAE_2M' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 503213
#2m virtual potential temperature
'THETA_V_2M' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 15 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 503214
#Temperature at cloud top
'TTOP_CON' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 3 ;
	}

#paramId: 503215
#Wet bulb temperature
'TW' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 27 ;
	}

#paramId: 503216
#2m wet bulb temperature
'TW_2M' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 27 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 503219
#Universal thermal climate index with direct incident short wave radiation
'UTCI_SUN' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 21 ;
	}

#paramId: 503220
#u-component of geostrophic wind
'U_G' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 41 ;
	}

#paramId: 503221
#v-component of geostrophic wind
'V_G' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 42 ;
	}

#paramId: 503229
#Prognostic mass mixing ratio of volcanic ash particles for bin number 1
'ASH1' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62025 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 1 ;
	}

#paramId: 503230
#Prognostic mass mixing ratio of volcanic ash particles for bin number 2
'ASH2' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62025 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 1 ;
	}

#paramId: 503231
#Prognostic mass mixing ratio of volcanic ash particles for bin number 3
'ASH3' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62025 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 1 ;
	}

#paramId: 503232
#Prognostic mass mixing ratio of volcanic ash particles for bin number 4
'ASH4' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62025 ;
	 modeNumber = 4 ;
	 typeOfDistributionFunction = 1 ;
	}

#paramId: 503233
#Prognostic mass mixing ratio of volcanic ash particles for bin number 5
'ASH5' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62025 ;
	 modeNumber = 5 ;
	 typeOfDistributionFunction = 1 ;
	}

#paramId: 503234
#Prognostic mass mixing ratio of volcanic ash particles for bin number 6
'ASH6' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62025 ;
	 modeNumber = 6 ;
	 typeOfDistributionFunction = 1 ;
	}

#paramId: 503235
#Modal prognostic mass mixing ratio of volcanic ash particles (fine mode)
'ASHA' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62025 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503236
#Modal prognostic mass mixing ratio of volcanic ash particles (medium mode)
'ASHB' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62025 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503237
#Modal prognostic mass mixing ratio of volcanic ash particles (coarse mode)
'ASHC' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62025 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503238
#Modal prognostic specific number concentration of volcanic ash particles (fine mode)
'ASHA0' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 60 ;
	 constituentType = 62025 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503239
#Modal prognostic specific number concentration of volcanic ash particles (medium mode)
'ASHB0' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 60 ;
	 constituentType = 62025 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503240
#Modal prognostic specific number concentration of volcanic ash particles (coarse mode)
'ASHC0' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 60 ;
	 constituentType = 62025 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503241
#Modal prognostic mass mixing ratio of mineral dust particles (fine mode)
'DUSTA' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62001 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503242
#Modal prognostic mass mixing ratio of mineral dust particles (medium mode)
'DUSTB' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62001 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503243
#Modal prognostic mass mixing ratio of mineral dust particles (coarse mode)
'DUSTC' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62001 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503244
#Modal prognostic specific number concentration  of mineral dust particles (fine mode)
'DUSTA0' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 60 ;
	 constituentType = 62001 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503245
#Modal prognostic specific number concentration  of mineral dust particles (medium mode)
'DUSTB0' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 60 ;
	 constituentType = 62001 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503246
#Modal prognostic specific number concentration  of mineral dust particles (coarsemode)
'DUSTC0' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 60 ;
	 constituentType = 62001 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503247
#Modal prognostic mass mixing ratio of sea salt particles (fine mode)
'SEASA' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62008 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503248
#Modal prognostic mass mixing ratio of sea salt particles (medium mode)
'SEASB' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62008 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503249
#Modal prognostic mass mixing ratio of sea salt particles (coarse mode)
'SEASC' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62008 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503250
#Modal prognostic specific number concentration of sea salt particles (fine mode)
'SEASA0' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 60 ;
	 constituentType = 62008 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503251
#Modal prognostic specific number concentration of sea salt particles (medium mode)
'SEASB0' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 60 ;
	 constituentType = 62008 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503252
#Modal prognostic specific number concentration of sea salt particles (coarse mode)
'SEASC0' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 60 ;
	 constituentType = 62008 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503253
#Cs137 - wet deposition
'Cs-137w' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 11 ;
	 constituentType = 30172 ;
	}

#paramId: 503254
#Prognostic specific activity concentration of Iodine 131 aerosol
'I_131a' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 14 ;
	 constituentType = 30141 ;
	}

#paramId: 503255
#Te132 - total (wet + dry) deposition
'Te-132t' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 13 ;
	 constituentType = 30129 ;
	}

#paramId: 503256
#Prognostic specific activity concentration of Zirconium 95
'Zr_95' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 14 ;
	 constituentType = 30079 ;
	}

#paramId: 503257
#Prognostic specific activity concentration of Xenon 133
'Xe_133' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 14 ;
	 constituentType = 30161 ;
	}

#paramId: 503258
#Prognostic specific activity concentration of Iodine 131 elementary gaseous
'I_131g' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 14 ;
	 constituentType = 30138 ;
	}

#paramId: 503259
#Prognostic specific activity concentration of Iodine 131 organic bounded
'I_131o' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 14 ;
	 constituentType = 30139 ;
	}

#paramId: 503260
#Prognostic specific activity concentration of Barium 140
'Ba_140' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 14 ;
	 constituentType = 30175 ;
	}

#paramId: 503261
#Prognostic specific activity concentration of Ruthenium 103
'Ru_103' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 14 ;
	 constituentType = 30102 ;
	}

#paramId: 503262
#Diagnostic total mass concentration of volcanic ash
'ASH_TOTAL_MC' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 0 ;
	 constituentType = 62025 ;
	}

#paramId: 503263
#Diagnostic maximum total mass concentration of volcanic ash in layer SFC-FL200
'ASH_MAX_TOTAL_MC_SFC_200' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 61 ;
	 typeOfSecondFixedSurface = 100 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 101325 ;
	 typeOfFirstFixedSurface = 100 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 46500 ;
	 constituentType = 62025 ;
	}

#paramId: 503265
#Diagnostic total column of mass concentration of volcanic ash
'ASH_TOTAL_MC_VI' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 10 ;
	 constituentType = 62025 ;
	}

#paramId: 503266
#Diagnostic height of model layer with maximal total mass concentration of volcanic ash
'ASH_HML_MAX' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 62 ;
	 constituentType = 62025 ;
	}

#paramId: 503267
#Diagnostic volcanic ash optical depth
'AOD_ASH' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 aerosolType = 62025 ;
	}

#paramId: 503268
#Diagnostic mineral dust optical depth
'AOD_DUST' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 aerosolType = 62001 ;
	}

#paramId: 503269
#Diagnostic sea salt optical depth
'AOD_SEAS' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 aerosolType = 62008 ;
	}

#paramId: 503270
#Diagnostic vmaximum activity concentration of radionuclides in a layer
'RADIONUC_MAX_AC_LAYER' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 15 ;
	}

#paramId: 503273
#Diagnostic maximum total mass concentration of volcanic ash in layer FL200-FL350
'ASH_MAX_TOTAL_MC_200_350' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 61 ;
	 typeOfSecondFixedSurface = 100 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 46500 ;
	 typeOfFirstFixedSurface = 100 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 24000 ;
	 constituentType = 62025 ;
	}

#paramId: 503274
#Diagnostic maximum total mass concentration of volcanic ash in layer SFC-FL100
'ASH_MAX_TOTAL_MC_SFC_100' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 61 ;
	 typeOfSecondFixedSurface = 100 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 101325 ;
	 typeOfFirstFixedSurface = 100 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 70000 ;
	 constituentType = 62025 ;
	}

#paramId: 503275
#Diagnostic maximum total mass concentration of volcanic ash in layer FL350-FL550
'ASH_MAX_TOTAL_MC_350_550' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 61 ;
	 typeOfSecondFixedSurface = 100 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 24000 ;
	 typeOfFirstFixedSurface = 100 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 9100 ;
	 constituentType = 62025 ;
	}

#paramId: 503276
#Diagnostic maximum total mass concentration of volcanic ash in layer FL100-FL245
'ASH_MAX_TOTAL_MC_100_245' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 61 ;
	 typeOfSecondFixedSurface = 100 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 70000 ;
	 typeOfFirstFixedSurface = 100 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 38500 ;
	 constituentType = 62025 ;
	}

#paramId: 503277
#Diagnostic maximum total mass concentration of volcanic ash in layer FL245-FL390
'ASH_MAX_TOTAL_MC_245_390' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 61 ;
	 typeOfSecondFixedSurface = 100 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 38500 ;
	 typeOfFirstFixedSurface = 100 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 20000 ;
	 constituentType = 62025 ;
	}

#paramId: 503278
#Diagnostic maximum total mass concentration of volcanic ash in layer FL390-FL530
'ASH_MAX_TOTAL_MC_390_530' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 61 ;
	 typeOfSecondFixedSurface = 100 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 20000 ;
	 typeOfFirstFixedSurface = 100 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10000 ;
	 constituentType = 62025 ;
	}

#paramId: 503279
#Diagnostic maximum total mass concentration of volcanic ash in a layer
'ASH_MAX_TOTAL_MC_LAYER' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 61 ;
	 constituentType = 62025 ;
	}

#paramId: 503280
#Aerosol optical depth
'AEROSOL_OPTICAL_DEPTH' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	}

#paramId: 503293
#Large Scale Rain Difference
'RAIN_GSP_D' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 4 ;
	}

#paramId: 503294
#Large Scale Snowfall water Equivalent Difference
'SNOW_GSP_D' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 56 ;
	 typeOfStatisticalProcessing = 4 ;
	}

#paramId: 503295
#Convective Rain Difference
'RAIN_CON_D' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 76 ;
	 typeOfStatisticalProcessing = 4 ;
	}

#paramId: 503296
#Convective Snowfall Water Equivalent Difference
'SNOW_CON_D' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 55 ;
	 typeOfStatisticalProcessing = 4 ;
	}

#paramId: 503303
#Total precipitation rate
'TOT_PR' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	}

#paramId: 503304
#Horizontal moisture convergence
'MCONV' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 26 ;
	}

#paramId: 503305
#TOA downward solar radiation
'SODT_RAD' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 8 ;
	}

#paramId: 503306
#Surface upward thermal radiation
'THUS_RAD' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503307
#Surface upward thermal radiation
'ATHU_S' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503308
#Specific mass of liquid water coating on hail
'QH_LIQ' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 110 ;
	}

#paramId: 503309
#Specific mass of liquid water coating on graupel
'QG_LIQ' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 113 ;
	}

#paramId: 503310
#Specific mass of liquid water coating on snow
'QS_LIQ' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 116 ;
	}

#paramId: 503311
#Specific number concentration of rain
'NCRAIN' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 100 ;
	}

#paramId: 503312
#Number density of rain
'NDRAIN' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 104 ;
	}

#paramId: 503313
#Specific number concentration of snow
'NCSNOW' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 101 ;
	}

#paramId: 503314
#Specific number concentration of graupel
'NCGRAUPEL' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 102 ;
	}

#paramId: 503315
#Specific number concentration of hail
'NCHAIL' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 103 ;
	}

#paramId: 503316
#Number density of snow
'NDSNOW' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 105 ;
	}

#paramId: 503317
#Number density of graupel
'NDGRAUPEL' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 106 ;
	}

#paramId: 503318
#Number density of hail
'NDHAIL' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 107 ;
	}

#paramId: 503319
#Mass density of rain
'DENR' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 96 ;
	}

#paramId: 503320
#Mass density of snow
'DENS' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 97 ;
	}

#paramId: 503321
#Mass density of graupel
'DENG' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 98 ;
	}

#paramId: 503322
#Mass density of cloud droplets
'DENC' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 38 ;
	}

#paramId: 503323
#Mass density of cloud ice
'DENI' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 39 ;
	}

#paramId: 503324
#Mass density of hail
'DENH' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 99 ;
	}

#paramId: 503326
#Diagnostic total column of activity concentration of radionuclides
'RADIONUC_AC_VI' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 10 ;
	}

#paramId: 503327
#Base for given threshold of mass density for volcanic ash cloud
'HBAS_ASH_CLD' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 21 ;
	 constituentType = 62025 ;
	}

#paramId: 503328
#Base for given threshold of mass density for mineral dust cloud
'HBAS_DUST_CLD' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 21 ;
	 constituentType = 62001 ;
	}

#paramId: 503330
#Top for given threshold of mass density for volcanic ash cloud
'HTOP_ASH_CLD' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 22 ;
	 constituentType = 62025 ;
	}

#paramId: 503331
#Top for given threshold of mass density for mineral dust cloud
'HTOP_DUST_CLD' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 22 ;
	 constituentType = 62001 ;
	}

#paramId: 503332
#Top for given threshold of air concentration of radionuclides
'HTOP_RADIONUC_CLD' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 24 ;
	}

#paramId: 503333
#Emission rate of dust for mode 2
'EMISS_DUSTB' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 3 ;
	 constituentType = 62001 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503334
#Emission rate of dust for mode 3
'EMISS_DUSTC' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 3 ;
	 constituentType = 62001 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503335
#Emission rate of dust for mode 1
'EMISS_DUSTA' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 3 ;
	 constituentType = 62001 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503336
#Accumulated dust Emission for mode 2
'ACCEMISS_DUSTB' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503337
#Accumulated dust Emission for mode 1
'ACCEMISS_DUSTA' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503338
#Accumulated dust Emission for mode 3
'ACCEMISS_DUSTC' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503340
#Base for given threshold of air concentration of radionuclides
'HBAS_RADIONUC_CLD' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 23 ;
	}

#paramId: 503341
#Maximum amplitude (positive or negative) of updraft helicity  (over given time interval)
'UH_MAX' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 15 ;
	 typeOfStatisticalProcessing = 2 ;
	}

#paramId: 503344
#Maximum total-column integrated condensed water above -10 C isotherm (over given time interval)
'TCOND10_MX' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 81 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfFirstFixedSurface = 20 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfFirstFixedSurface = 26315 ;
	}

#paramId: 503345
#Maximum total-column integrated condensed  water (over given time interval)
'TCOND_MAX' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 81 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503346
#Composite reflectivity - observation
'DBZCMP_OBS' = {
	 discipline = 0 ;
	 parameterCategory = 16 ;
	 parameterNumber = 5 ;
	 typeOfGeneratingProcess = 8 ;
	}

#paramId: 503347
#Composite reflectivity - forecast (simulation)
'DBZCMP_SIM' = {
	 discipline = 0 ;
	 parameterCategory = 16 ;
	 parameterNumber = 5 ;
	}

#paramId: 503349
#Maximum reflectivity track (over given time interval and entire atmosphere)
'DBZ_CTMAX' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503350
#relative vorticity
'RELV' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 12 ;
	}

#paramId: 503352
#2m Temperature, restricted to land
'T_2M_L' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfSecondFixedSurface = 181 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 503353
#2m Dew Point Temperature, restricted to land
'TD_2M_L' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	 typeOfSecondFixedSurface = 181 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 503354
#2m Relative Humidity, restricted to land
'RELHUM_2M_L' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	 typeOfSecondFixedSurface = 181 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 503357
#Maximum 10m wind speed without  gust
'VABSMX_10M' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	}

#paramId: 503360
#Birch (betula) pollen concentration
'BETU' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 59 ;
	 constituentType = 62101 ;
	}

#paramId: 503362
#Fraction of land occupied by birch (betula)
'BETUfr' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62101 ;
	}

#paramId: 503368
#Precipitation reservoir (liquid water on the flowers, preventing them from flowering) of birch (betula)
'BETUrprec' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 13 ;
	 constituentType = 62101 ;
	}

#paramId: 503375
#Alder (alnus) pollen concentration
'ALNU' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 59 ;
	 constituentType = 62100 ;
	}

#paramId: 503376
#Fraction of land occupied by alder (alnus)
'ALNUfr' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62100 ;
	}

#paramId: 503382
#Precipitation reservoir (liquid water on the flowers, preventing them from flowering) of alder (alnus)
'ALNUrprec' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 13 ;
	 constituentType = 62100 ;
	}

#paramId: 503390
#Grasses (poaceae) pollen concentration
'POAC' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 59 ;
	 constituentType = 62300 ;
	}

#paramId: 503391
#Fraction of land occupied by grasses (poaceae)
'POACfr' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62300 ;
	}

#paramId: 503397
#Precipitation reservoir (liquid water on the flowers, preventing them from flowering) of grasses (poaceae)
'POACrprec' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 13 ;
	 constituentType = 62300 ;
	}

#paramId: 503405
#ragweed  (ambrosia) pollen concentration
'AMBR' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 59 ;
	 constituentType = 62200 ;
	}

#paramId: 503406
#Fraction of land occupied by ragweed  (ambrosia)
'AMBRfr' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62200 ;
	}

#paramId: 503412
#Precipitation reservoir (liquid water on the flowers, preventing them from flowering) of ragweed  (ambrosia)
'AMBRrprec' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 13 ;
	 constituentType = 62200 ;
	}

#paramId: 503421
#Echotop-pressure: smallest pressure where radar reflectivity above a threshold is present
'ECHOTOP' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 25 ;
	}

#paramId: 503422
#Echotop-height: largest height where radar reflectivity above a threshold is present
'ECHOTOPinM' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 25 ;
	}

#paramId: 503423
#Maximum horizontal moisture convergence track (over given time interval and column)
'MCNV_CTMAX' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 26 ;
	 typeOfStatisticalProcessing = 2 ;
	}

#paramId: 503431
#Accumulated dry deposition (surface) of dust for mode 1
'ACCDRYDEPO_DUSTA' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503432
#Accumulated dry deposition (surface) of dust for mode 2
'ACCDRYDEPO_DUSTB' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503433
#Accumulated dry deposition (surface) of dust for mode 3
'ACCDRYDEPO_DUSTC' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503434
#Accumulated wet deposition by grid scale precipitation of dust for mode 1
'ACCWETDEPO_GSP_DUSTA' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 9 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503435
#Accumulated wet deposition by grid scale precipitation of dust for mode 2
'ACCWETDEPO_GSP_DUSTB' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 9 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503436
#Accumulated wet deposition by grid scale precipitation of dust for mode 3
'ACCWETDEPO_GSP_DUSTC' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 9 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503437
#Accumulated wet deposition by convective precipitation of dust for mode 1
'ACCWETDEPO_CON_DUSTA' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503438
#Accumulated wet deposition by convective precipitation of dust for mode 2
'ACCWETDEPO_CON_DUSTB' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503439
#Accumulated wet deposition by convective precipitation of dust for mode 3
'ACCWETDEPO_CON_DUSTC' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503443
#Accumulated sedimentation of dust for mode 1
'ACCSEDIM_DUSTA' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 11 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503444
#Accumulated sedimentation of dust for mode 2
'ACCSEDIM_DUSTB' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 11 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503445
#Accumulated sedimentation of dust for mode 3
'ACCSEDIM_DUSTC' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 11 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503458
#Attenuated backscatter from satellite for dust (for given wave length)
'SAT_BSC_DUST' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 107 ;
	 aerosolType = 62001 ;
	}

#paramId: 503459
#Attenuated backscatter from ground (ceilometer) for dust (for given wave length)
'CEIL_BSC_DUST' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 108 ;
	 aerosolType = 62001 ;
	}

#paramId: 503461
#Attenuated backscatter from satellite for volcanic ash (for given wave length)
'SAT_BSC_ASH' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 107 ;
	 aerosolType = 62025 ;
	}

#paramId: 503462
#Attenuated backscatter from ground (ceilometer) for volcanic ash (for given wave length)
'CEIL_BSC_ASH' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 108 ;
	 aerosolType = 62025 ;
	}

#paramId: 503467
#2m Temperature analysis increment, filtered in time
'T_2M_FILTBIAS' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 typeOfGeneratingProcess = 206 ;
	}

#paramId: 503468
#Cs137 - total (wet + dry) deposition
'Cs-137t' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 13 ;
	 constituentType = 30172 ;
	}

#paramId: 503469
#Prognostic specific activity concentration of Caesium 137
'Cs_137' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 14 ;
	 constituentType = 30172 ;
	}

#paramId: 503470
#Averaged air concentration of Caesium 137
'ACs-137' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 30172 ;
	}

#paramId: 503471
#Accumulated air concentration of Caesium 137
'ACCCs-137' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 30172 ;
	}

#paramId: 503480
#Prognostic specific activity concentration of Krypton 85
'Kr_85' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 14 ;
	 constituentType = 30059 ;
	}

#paramId: 503481
#Kr85 - total (wet + dry) deposition
'Kr-85t' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 13 ;
	 constituentType = 30059 ;
	}

#paramId: 503482
#Averaged air concentration of Krypton 85
'AKr-85' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 30059 ;
	}

#paramId: 503483
#Accumulated air concentration of Krypton 85
'ACCKr-85' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 30059 ;
	}

#paramId: 503484
#Prognostic specific activity concentration of Strontium 90
'Sr_90' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 14 ;
	 constituentType = 30067 ;
	}

#paramId: 503485
#Averaged air concentration of Strontium 90
'ASr-90' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 30067 ;
	}

#paramId: 503486
#Accumulated air concentration of Strontium 90
'ACCSr-90' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 30067 ;
	}

#paramId: 503487
#Sr90 - total (wet + dry) deposition
'Sr-90t' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 13 ;
	 constituentType = 30067 ;
	}

#paramId: 503489
#I131a - total (wet + dry) deposition
'I-131at' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 13 ;
	 constituentType = 30141 ;
	}

#paramId: 503490
#Averaged air concentration of Iodine 131 aerosol
'AI-131a' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 30141 ;
	}

#paramId: 503491
#Accumulated air concentration of Iodine 131 aerosol
'ACCI-131a' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 30141 ;
	}

#paramId: 503492
#Averaged air concentration of Cobalt 60
'ACo-60' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 30042 ;
	}

#paramId: 503493
#Accumulated air concentration of Cobalt 60
'ACCCo-60' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 30042 ;
	}

#paramId: 503494
#Prognostic specific activity concentration of Cobalt 60
'Co_60' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 14 ;
	 constituentType = 30042 ;
	}

#paramId: 503495
#Co-60 - wet deposition
'Co-60w' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 11 ;
	 constituentType = 30042 ;
	}

#paramId: 503496
#Co60 - total (wet + dry) deposition
'Co-60t' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 13 ;
	 constituentType = 30042 ;
	}

#paramId: 503497
#Ru103 - total (wet + dry) deposition
'Ru-103t' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 13 ;
	 constituentType = 30102 ;
	}

#paramId: 503499
#Averaged air concentration of Ruthenium 103
'ARu-103' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 30102 ;
	}

#paramId: 503500
#Accumulated air concentration of Ruthenium 103
'ACCRu-103' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 30102 ;
	}

#paramId: 503501
#Prognostic specific activity concentration of Tellurium 132
'Te_132' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 14 ;
	 constituentType = 30129 ;
	}

#paramId: 503502
#Averaged air concentration of Tellurium 132
'ATe-132' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 30129 ;
	}

#paramId: 503503
#Accumulated air concentration of Tellurium 132
'ACCTe-132' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 30129 ;
	}

#paramId: 503504
#Zr95 - total (wet + dry) deposition
'Zr-95t' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 13 ;
	 constituentType = 30079 ;
	}

#paramId: 503505
#Averaged air concentration of Zirconium 95
'AZr-95' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 30079 ;
	}

#paramId: 503506
#Accumulated air concentration of Zirconium 95
'ACCZr-95' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 30079 ;
	}

#paramId: 503507
#TRACER - total (wet + dry) deposition
'Tr-2t' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 13 ;
	 constituentType = 30000 ;
	}

#paramId: 503508
#Prognostic specific activity concentration of TRACER
'Tr_2' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 14 ;
	 constituentType = 30000 ;
	}

#paramId: 503509
#Averaged air concentration of TRACER
'ATr-2' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 30000 ;
	}

#paramId: 503510
#Accumulated air concentration of TRACER
'ACCTr-2' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 30000 ;
	}

#paramId: 503511
#Averaged air concentration of Xenon 133
'AXe-133' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 30161 ;
	}

#paramId: 503512
#Accumulated air concentration of Xenon 133
'ACCXe-133' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 30161 ;
	}

#paramId: 503513
#Xe133 - total (wet + dry) deposition
'Xe-133t' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 13 ;
	 constituentType = 30161 ;
	}

#paramId: 503514
#Air concentration of Iodine 131
'I-131' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 constituentType = 30137 ;
	}

#paramId: 503515
#I131 - dry deposition
'I-131d' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 12 ;
	 constituentType = 30137 ;
	}

#paramId: 503516
#Averaged air concentration of Iodine 131
'AI-131' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 30137 ;
	}

#paramId: 503517
#Accumulated air concentration of Iodine 131
'ACCI-131' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 30137 ;
	}

#paramId: 503518
#Prognostic specific activity concentration of Iodine 131
'I_131' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 14 ;
	 constituentType = 30137 ;
	}

#paramId: 503519
#I131 - wet deposition
'I-131w' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 11 ;
	 constituentType = 30137 ;
	}

#paramId: 503520
#I131 - total (wet + dry) deposition
'I-131t' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 13 ;
	 constituentType = 30137 ;
	}

#paramId: 503522
#Averaged air concentration of Iodine 131 elementary gaseous
'AI-131g' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 30138 ;
	}

#paramId: 503523
#Accumulated air concentration of Iodine 131 elementary gaseous
'ACCI-131g' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 30138 ;
	}

#paramId: 503524
#I131g - total (wet + dry) deposition
'I-131gt' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 13 ;
	 constituentType = 30138 ;
	}

#paramId: 503525
#Averaged air concentration of Iodine 131 organic bounded
'AI-131o' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 30139 ;
	}

#paramId: 503526
#Accumulated air concentration of Iodine 131 organic bounded
'ACCI-131o' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 30139 ;
	}

#paramId: 503527
#I131o - total (wet + dry) deposition
'I-131ot' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 13 ;
	 constituentType = 30139 ;
	}

#paramId: 503528
#Ba140 - total (wet + dry) deposition
'Ba-140t' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 13 ;
	 constituentType = 30175 ;
	}

#paramId: 503529
#Averaged air concentration of Barium 140
'ABa-140' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 30175 ;
	}

#paramId: 503530
#Accumulated air concentration of Barium 140
'ACCBa-140' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 30175 ;
	}

#paramId: 503531
#Air concentration of Ruthenium 106
'Ru-106' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 constituentType = 30104 ;
	}

#paramId: 503532
#Ru106 - total (wet + dry) deposition
'Ru-106t' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 13 ;
	 constituentType = 30104 ;
	}

#paramId: 503533
#Prognostic specific activity concentration of Ruthenium 106
'Ru_106' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 14 ;
	 constituentType = 30104 ;
	}

#paramId: 503534
#Ru106 - dry deposition
'Ru-106d' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 12 ;
	 constituentType = 30104 ;
	}

#paramId: 503535
#Ru106 - wet deposition
'Ru-106w' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 11 ;
	 constituentType = 30104 ;
	}

#paramId: 503536
#Averaged air concentration of Ruthenium 106
'ARu-106' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 30104 ;
	}

#paramId: 503537
#Accumulated air concentration of Ruthenium 106
'ACCRu-106' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 30104 ;
	}

#paramId: 503538
#Co-60 - dry deposition
'Co-60d' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 12 ;
	 constituentType = 30042 ;
	}

#paramId: 503539
#Air concentration of Cobalt 60
'Co-60' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 constituentType = 30042 ;
	}

#paramId: 503542
#Kr85m - wet deposition
'Kr-85mw' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 11 ;
	 constituentType = 30060 ;
	}

#paramId: 503543
#Kr85m - total (wet + dry) deposition
'Kr-85mt' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 13 ;
	 constituentType = 30060 ;
	}

#paramId: 503544
#Prognostic specific activity concentration of Krypton 85m
'Kr_85m' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 14 ;
	 constituentType = 30060 ;
	}

#paramId: 503545
#Kr85m - dry deposition
'Kr-85md' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 12 ;
	 constituentType = 30060 ;
	}

#paramId: 503546
#Averaged air concentration of Krypton 85m
'AKr-85m' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 30060 ;
	}

#paramId: 503547
#Accumulated air concentration of Krypton 85m
'ACCKr-85m' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 30060 ;
	}

#paramId: 503548
#Air concentration of Krypton 85m
'Kr-85m' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 constituentType = 30060 ;
	}

#paramId: 503551
#Birch (betula) pollen specific number concentration
'BETUsnc' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 60 ;
	 constituentType = 62101 ;
	}

#paramId: 503552
#Alder (alnus) pollen specific number concentration
'ALNUsnc' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 60 ;
	 constituentType = 62100 ;
	}

#paramId: 503553
#Grasses (poaceae) pollen specific number concentration
'POACsnc' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 60 ;
	 constituentType = 62300 ;
	}

#paramId: 503554
#Ragweed (ambrosia) pollen specific number concentration
'AMBRsnc' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 60 ;
	 constituentType = 62200 ;
	}

#paramId: 503560
#Total lightning flash density - instantaneous
'LFD_TOT' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 4 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503561
#Total lightning flash density - time average
'LFD_TOT_AV' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503563
#Temperature tendency perturbation due to stochastic model of model error
'DT_SMME' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 26 ;
	 typeOfGeneratingProcess = 221 ;
	}

#paramId: 503564
#Zonal wind tendency perturbation due to stochastic model of model error
'DU_SMME' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 39 ;
	 typeOfGeneratingProcess = 221 ;
	}

#paramId: 503565
#Meridional wind tendency perturbation due to stochastic model of model error
'DV_SMME' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 40 ;
	 typeOfGeneratingProcess = 221 ;
	}

#paramId: 503566
#Effective radius of cloud water
'RECLOUD' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 129 ;
	}

#paramId: 503567
#Effective radius of rain
'RERAIN' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 130 ;
	}

#paramId: 503568
#Effective radius of cloud ice
'REICE' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 131 ;
	}

#paramId: 503569
#Effective radius of snow
'RESNOW' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 132 ;
	}

#paramId: 503570
#Effective radius of graupel
'REGRAUPEL' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 133 ;
	}

#paramId: 503571
#Effective radius of hail
'REHAIL' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 134 ;
	}

#paramId: 503572
#Effective radius of subgrid liquid clouds
'RECLOUD_SGS' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 135 ;
	}

#paramId: 503573
#Effective radius of subgrid ice clouds
'REICE_SGS' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 136 ;
	}

#paramId: 503574
#Effective aspect ratio of rain
'ARRAIN' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 137 ;
	}

#paramId: 503575
#Effective aspect ratio of cloud ice
'ARICE' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 138 ;
	}

#paramId: 503576
#Effective aspect ratio of snow
'ARSNOW' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 139 ;
	}

#paramId: 503577
#Effective aspect ratio of graupel
'ARGRAUPEL' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 140 ;
	}

#paramId: 503578
#Effective aspect ratio of hail
'ARHAIL' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 141 ;
	}

#paramId: 503579
#Effective aspect ratio of subgrid ice clouds
'ARICE_SGS' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 142 ;
	}

#paramId: 503580
#Relative Humidity in lowest model layer - time-filtered assimilation increment
'RELHUM_LML_FILTINC' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	 typeOfSecondFixedSurface = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 typeOfGeneratingProcess = 207 ;
	}

#paramId: 503581
#Temperature in lowest model layer - time-filtered assimilation increment
'T_LML_FILTINC' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfSecondFixedSurface = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 typeOfGeneratingProcess = 207 ;
	}

#paramId: 503583
#Wind speed (time average)
'SP_AV' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}

#paramId: 503584
#10m wind speed (time average)
'SP_10M_AV' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	}

#paramId: 503587
#Total cloud cover (time average)
'CLCT_AV' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}

#paramId: 503593
#Clear-sky net solar radiation flux (at the surface)
'SOBS_RAD_CS' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503594
#Clear-sky net thermal radiation flux (at the surface)
'THBS_RAD_CS' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503595
#Clear-sky net solar radiation flux (on model top)
'SOBT_RAD_CS' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 8 ;
	}

#paramId: 503596
#Clear-sky net thermal radiation flux (on model top)
'THBT_RAD_CS' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 8 ;
	}

#paramId: 503597
#Clear-sky net solar radiation flux (at the surface) - time average
'ASOB_S_CS' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 11 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503598
#Clear-sky net thermal radiation flux (at the surface) - time average
'ATHB_S_CS' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 6 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503599
#Clear-sky net solar radiation flux (on model top) - time average
'ASOB_T_CS' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 11 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 8 ;
	}

#paramId: 503600
#Clear-sky net thermal radiation flux (on model top) - time average
'ATHB_T_CS' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 6 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 8 ;
	}

#paramId: 503601
#TOA downward solar radiation (time average)
'ASOD_T' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 8 ;
	}

#paramId: 503602
#Volumetric saturation of soil moisture
'W_SO_SAT' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 16 ;
	 typeOfSecondFixedSurface = 106 ;
	 typeOfFirstFixedSurface = 106 ;
	}

#paramId: 503616
#Pressure in lowest model layer - time-filtered assimilation increment
'P_LML_FILTINC' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfSecondFixedSurface = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 typeOfGeneratingProcess = 207 ;
	}

#paramId: 503617
#Maximum amplitude of updraft helicity in tropospheric column of low height
'UH_MAX_LOW' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 15 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfSecondFixedSurface = 102 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 3000 ;
	 typeOfFirstFixedSurface = 102 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	}

#paramId: 503618
#Maximum amplitude of updraft helicity in tropospheric column of medium height
'UH_MAX_MED' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 15 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfSecondFixedSurface = 102 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 5000 ;
	 typeOfFirstFixedSurface = 102 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2000 ;
	}

#paramId: 503621
#Large-scale precipitation rate
'PR_GSP' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 54 ;
	}

#paramId: 503624
#Total lightning flash density - maximum
'LFD_TOT_MX' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503628
#Smoke - high absorption (mass mixing ratio)
'SMOKE_HA' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62020 ;
	}

#paramId: 503629
#Smoke - high absorption (mass density)
'SMOKE_DEN_HA' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 0 ;
	 constituentType = 62020 ;
	}

#paramId: 503630
#Smoke - high absorption (specific number concentration)
'SMOKE0_HA' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 60 ;
	 constituentType = 62020 ;
	}

#paramId: 503631
#Smoke - low absorption (mass mixing ratio)
'SMOKE_LA' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62021 ;
	}

#paramId: 503632
#Smoke - low absorption (mass density)
'SMOKE_DEN_LA' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 0 ;
	 constituentType = 62021 ;
	}

#paramId: 503633
#Smoke - low absorption (specific number concentration)
'SMOKE0_LA' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 60 ;
	 constituentType = 62021 ;
	}

#paramId: 503634
#Sulphur dioxide (SO2) - volume mixing ratio
'SO2' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 52 ;
	 constituentType = 8 ;
	}

#paramId: 503635
#Sulphur dioxide (SO2) - mass density
'SO2_DEN' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 0 ;
	 constituentType = 8 ;
	}

#paramId: 503636
#Hazel (corylus) pollen concentration
'CORY' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 59 ;
	 constituentType = 62104 ;
	}

#paramId: 503637
#Fraction of land occupied by hazel (corylus)
'CORYfr' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62104 ;
	}

#paramId: 503643
#Precipitation reservoir (liquid water on the flowers, preventing them from flowering) of hazel (corylus)
'CORYrprec' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 13 ;
	 constituentType = 62104 ;
	}

#paramId: 503651
#Hazel (corylus) pollen specific number concentration
'CORYsnc' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 60 ;
	 constituentType = 62104 ;
	}

#paramId: 503657
#Temperature in lowest model layer - time-filtered assimilation increment, weighted with cos(2pi loc.time/day)
'T_LML_COSWGT_FILTINC' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfSecondFixedSurface = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 typeOfGeneratingProcess = 208 ;
	}

#paramId: 503662
#Thickness of snow layer - multi level
'DZ_SNOW_M' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 11 ;
	 typeOfSecondFixedSurface = 114 ;
	 typeOfFirstFixedSurface = 114 ;
	}

#paramId: 503664
#Snow temperature of layer (defined at layer top) - multi level
'TofSNW_LTOP_M' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 28 ;
	 typeOfSecondFixedSurface = 114 ;
	 typeOfFirstFixedSurface = 114 ;
	}

#paramId: 503672
#Lightning Potential Index from convection scheme
'LPI_CON' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 5 ;
	}

#paramId: 503673
#Maximum Lightning Potential Index from convection scheme
'LPI_CON_MAX' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 2 ;
	}

#paramId: 503674
#Wind speed in lowest model layer - time-filtered assimilation increment
'SP_LML_FILTINC' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfSecondFixedSurface = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 typeOfGeneratingProcess = 207 ;
	}

#paramId: 503675
#Eddy Dissipation Parameter
'EDP' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 30 ;
	}

#paramId: 503676
#Icing Severity (0=None, 1=Trace, 2=Light, 3=Moderate, 4=Severe)
'ICE_SEV' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 37 ;
	}

#paramId: 503677
#U-component surface Stokes drift
'UST' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 21 ;
	}

#paramId: 503678
#V-component surface Stokes drift
'VST' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 22 ;
	}

#paramId: 503679
#Peak wave direction
'PWD' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 46 ;
	}

#paramId: 503680
#Significant wave height of first swell partition
'SWH1' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 47 ;
	}

#paramId: 503681
#Significant wave height of second swell partition
'SWH2' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 48 ;
	}

#paramId: 503682
#Significant wave height of third swell partition
'SWH3' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 49 ;
	}

#paramId: 503683
#Mean wave period of first swell partition
'MWP1' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 50 ;
	}

#paramId: 503684
#Mean wave period of second swell partition
'MWP2' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 51 ;
	}

#paramId: 503685
#Mean wave period of third swell partition
'MWP3' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 52 ;
	}

#paramId: 503686
#Mean wave direction of first swell partition
'MWD1' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 53 ;
	}

#paramId: 503687
#Mean wave direction of second swell partition
'MWD2' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 54 ;
	}

#paramId: 503688
#Mean wave direction of third swell partition
'MWD3' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 55 ;
	}

#paramId: 503689
#Diagnostic total mass concentration of mineral dust aerosol
'DUST_TOTAL_MC' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 0 ;
	 constituentType = 62001 ;
	}

#paramId: 503690
#Diagnostic total mass concentration of sea salt aerosol
'SEAS_TOTAL_MC' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 0 ;
	 constituentType = 62008 ;
	}

#paramId: 503691
#Diagnostic total mass concentration of black carbon aerosol (soot)
'BCARB_TOTAL_MC' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 0 ;
	 constituentType = 62009 ;
	}

#paramId: 503692
#Diagnostic black carbon aerosol (soot) optical depth
'AOD_BCARB' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 aerosolType = 62009 ;
	}

#paramId: 503693
#Total atmosphere optical depth due to mineral dust aerosol
'TAOD_DUST' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 typeOfFirstFixedSurface = 10 ;
	 aerosolType = 62001 ;
	}

#paramId: 503694
#Total atmosphere optical depth due to sea salt aerosol
'TAOD_SEAS' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 typeOfFirstFixedSurface = 10 ;
	 aerosolType = 62008 ;
	}

#paramId: 503695
#Total atmosphere optical depth due to volcanic ash aerosol
'TAOD_ASH' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 typeOfFirstFixedSurface = 10 ;
	 aerosolType = 62025 ;
	}

#paramId: 503696
#Total atmosphere optical depth due to black carbon aerosol (soot)
'TAOD_BCARB' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 typeOfFirstFixedSurface = 10 ;
	 aerosolType = 62009 ;
	}

#paramId: 503697
#Modal prognostic mass mixing ratio of mineral dust aerosol (all modes)
'DUST' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62001 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503698
#Modal prognostic mass mixing ratio of sea salt aerosol (all modes)
'SEAS' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62008 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503699
#Modal prognostic mass mixing ratio of black carbon aerosol (soot) (all modes)
'BCARB' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62009 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503700
#Modal prognostic specific number concentration of black carbon aerosol (soot) (all modes)
'BCARB0' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 60 ;
	 constituentType = 62009 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503701
#Modal prognostic mass mixing ratio of volcanic ash aerosol (all modes)
'ASH' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62025 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503702
#Modal prognostic specific number concentration of total aerosol (all modes)
'SNC_AERO' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 60 ;
	 constituentType = 62000 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503703
#Base reflectivity - low layer maximum
'DBZLMX_LOW' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 4 ;
	 typeOfSecondFixedSurface = 103 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 500 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2500 ;
	}

#paramId: 503706
#Sea water density
'SWDEN' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 16 ;
	}

#paramId: 503707
#Sea water potential temperature
'SWPT' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 18 ;
	}

#paramId: 503708
#Sea water potential density
'SWPDEN' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 19 ;
	}

#paramId: 503709
#Sea water practical salinity
'SWPSAL' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 21 ;
	}

#paramId: 503722
#Diagnostic total column of mass concentration of mineral dust aerosol
'DUST_TOTAL_MC_VI' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 10 ;
	 constituentType = 62001 ;
	}

#paramId: 503723
#Diagnostic vertical maximum total mass concentration of mineral dust aerosol in a layer
'DUST_MAX_TOTAL_MC_LAYER' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 61 ;
	 constituentType = 62001 ;
	}

#paramId: 503724
#Diagnostic temporal maximum activity concentration of Caesium 137 in a time range
'MAXCs-137' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 2 ;
	 constituentType = 30172 ;
	}

#paramId: 503725
#Diagnostic temporal maximum activity concentration of Iodine 131 in a time range
'MAXI-131' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 2 ;
	 constituentType = 30137 ;
	}

#paramId: 503726
#Diagnostic temporal maximum activity concentration of Caesium 137 in a time range and vertical maximum in a layer
'MAXCs-137_LMAX' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 15 ;
	 typeOfStatisticalProcessing = 2 ;
	 constituentType = 30172 ;
	}

#paramId: 503727
#Diagnostic temporal maximum activity concentration of Iodine 131 in a time range and vertical maximum in a layer
'MAXI-131_LMAX' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 15 ;
	 typeOfStatisticalProcessing = 2 ;
	 constituentType = 30137 ;
	}

#paramId: 503728
#Total accumulated dry deposition (surface) of dust (sum of all modes)
'TOT_ACCDRYDEPO_DUST' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	}

#paramId: 503729
#Total accumulated dust emission (sum of all modes)
'TOT_ACCEMISS_DUST' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	}

#paramId: 503730
#Total accumulated sedimentation of dust (sum of all modes)
'TOT_ACCSEDIM_DUST' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 11 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	}

#paramId: 503731
#Total accumulated wet deposition of dust (sum of all modes)
'TOT_ACCWETDEPO_DUST' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	}

#paramId: 503737
#Maximum total precipitation rate
'TOT_PR_MAX' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfStatisticalProcessing = 2 ;
	}

#paramId: 503738
#Top of persistent contrails
'PERSCONTT' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 48 ;
	}

#paramId: 503739
#Base of persistent contrails
'PERSCONTB' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 49 ;
	}

#paramId: 503743
#U-component of 10m wind - time average
'U_10M_AV' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	}

#paramId: 503744
#V-component of 10m wind - time average
'V_10M_AV' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	}

#paramId: 503759
#Zonal component of sea water velocity (west-east direction counted positive)
'USEA' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 23 ;
	}

#paramId: 503760
#Meridional component of sea water velocity (south-north direction counted positive)
'VSEA' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 24 ;
	}

#paramId: 503763
#Mixed layer depth in ocean
'MLD_SEA' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 52 ;
	}

#paramId: 503764
#Normal component of sea water velocity (normal in relation to local grid cell edge)
'VNSEA' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 53 ;
	}

#paramId: 500092
#Solar radiation heating rate
'SOHR_RAD' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 192 ;
	}

#paramId: 500093
#Thermal radiation heating rate
'THHR_RAD' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 192 ;
	}

#paramId: 500094
#Latent heat flux from bare soil
'ALHFL_BS' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 193 ;
	 typeOfStatisticalProcessing = 0 ;
	}

#paramId: 500095
#Latent heat flux from plants
'ALHFL_PL' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 194 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 106 ;
	}

#paramId: 500097
#Stomatal resistance
'RSTOM' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 195 ;
	}

#paramId: 500109
#Vertical integral of divergence of total water content - accumulation
'TDIV_HUM' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 192 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 500110
#Sub-grid scale cloud water
'QC_RAD' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 193 ;
	}

#paramId: 500111
#Sub-grid scale cloud ice
'QI_RAD' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 194 ;
	}

#paramId: 500115
#Cloud base above MSL, shallow convection
'HBAS_SC' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 192 ;
	 typeOfSecondFixedSurface = 101 ;
	 typeOfFirstFixedSurface = 2 ;
	}

#paramId: 500116
#Cloud top above MSL, shallow convection
'HTOP_SC' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 193 ;
	 typeOfSecondFixedSurface = 101 ;
	 typeOfFirstFixedSurface = 3 ;
	}

#paramId: 500117
#Specific cloud liquid water content, convective cloud
'CLW_CON' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 195 ;
	}

#paramId: 500120
#Base index (vertical level) of main convective cloud
'BAS_CON' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 194 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500121
#Top index (vertical level) of main convective cloud
'TOP_CON' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 195 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500122
#Temperature tendency due to convection
'DT_CON' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 192 ;
	}

#paramId: 500123
#Specific humidity tendency due to convection
'DQV_CON' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 197 ;
	}

#paramId: 500124
#Zonal wind tendency due to convection
'DU_CON' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 192 ;
	}

#paramId: 500125
#Meridional wind tendency due to convection
'DV_CON' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 193 ;
	}

#paramId: 500126
#Height of top of dry convection above MSL
'HTOP_DC' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 196 ;
	 typeOfSecondFixedSurface = 101 ;
	 typeOfFirstFixedSurface = 3 ;
	}

#paramId: 500128
#Height of snow fall limit above MSL
'SNOWLMT' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 204 ;
	 typeOfSecondFixedSurface = 101 ;
	 typeOfFirstFixedSurface = 4 ;
	}

#paramId: 500129
#Tendency of specific cloud liquid water content due to convection
'DQC_CON' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 198 ;
	}

#paramId: 500130
#Tendency of specific cloud ice content due to convection
'DQI_CON' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 199 ;
	}

#paramId: 500131
#Specific content of precipitation particles (needed for water loading)
'Q_SEDIM' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 196 ;
	}

#paramId: 500140
#Temperature tendency due to grid scale precipitation
'DT_GSP' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 193 ;
	}

#paramId: 500141
#Specific humidity tendency due to grid scale precipitation
'DQV_GSP' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 200 ;
	}

#paramId: 500142
#Tendency of specific cloud liquid water content due to grid scale precipitation
'DQC_GSP' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 201 ;
	}

#paramId: 500143
#Fresh snow factor (weighting function for albedo indicating freshness of snow)
'FRESHSNW' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 203 ;
	}

#paramId: 500144
#Tendency of specific cloud ice content due to grid scale precipitation
'DQI_GSP' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 202 ;
	}

#paramId: 500148
#Pressure perturbation
'PP' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 192 ;
	}

#paramId: 500149
#Supercell detection index 1 (rot. up- and downdrafts)
'SDI_1' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 192 ;
	}

#paramId: 500150
#Supercell detection index 2 (only rot. updrafts)
'SDI_2' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 193 ;
	}

#paramId: 500151
#Convective Available Potential Energy, most unstable
'CAPE_MU' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 193 ;
	}

#paramId: 500152
#Convective Inhibition, most unstable
'CIN_MU' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 193 ;
	}

#paramId: 500153
#Convective Available Potential Energy, mean layer
'CAPE_ML' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 192 ;
	}

#paramId: 500154
#Convective Inhibition, mean layer
'CIN_ML' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 192 ;
	}

#paramId: 500156
#Tendency of turbulent kinetic energy
'TKETENS' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 192 ;
	}

#paramId: 500157
#Kinetic energy
'KE' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 196 ;
	}

#paramId: 500176
#Solution of 2-d Helmholtz equations - needed for restart
'DTTDIV' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 192 ;
	}

#paramId: 500177
#Effective transmissivity of solar radiation
'SOTR_RAD' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 193 ;
	}

#paramId: 500178
#Sum of contributions to evaporation
'EVATRA_SUM' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 192 ;
	}

#paramId: 500179
#Total transpiration from all soil layers
'TRA_SUM' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 193 ;
	}

#paramId: 500180
#Total forcing at soil surface
'TOTFORCE_S' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 194 ;
	}

#paramId: 500181
#Residuum of soil moisture
'RESID_WSO' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 195 ;
	}

#paramId: 500182
#Mass flux at convective cloud base
'MFLX_CON' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 205 ;
	 typeOfFirstFixedSurface = 2 ;
	}

#paramId: 500184
#Moisture convergence for Kuo-type closure
'QCVG_CON' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 206 ;
	}

#paramId: 500195
#Analysis error (standard deviation), geopotential (gpm)
'ANA_ERR_FI' = {
	 discipline = 0 ;
	 parameterCategory = 194 ;
	 parameterNumber = 5 ;
	 typeOfGeneratingProcess = 7 ;
	}

#paramId: 500196
#Analysis error (standard deviation), u-comp. of wind
'ANA_ERR_U' = {
	 discipline = 0 ;
	 parameterCategory = 194 ;
	 parameterNumber = 2 ;
	 typeOfGeneratingProcess = 7 ;
	}

#paramId: 500197
#Analysis error (standard deviation), v-comp. of wind
'ANA_ERR_V' = {
	 discipline = 0 ;
	 parameterCategory = 194 ;
	 parameterNumber = 3 ;
	 typeOfGeneratingProcess = 7 ;
	}

#paramId: 500198
#Zonal wind tendency due to sub-grid scale oro.
'DU_SSO' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 194 ;
	}

#paramId: 500199
#Meridional wind tendency due to sub-grid scale oro.
'DV_SSO' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 195 ;
	}

#paramId: 500204
#Surface emissivity
'EMIS_RAD' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 199 ;
	}

#paramId: 500205
#Soil type (1...9, local soilType.table)
'SOILTYP' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 196 ;
	}

#paramId: 500208
#Height of ozone maximum (climatological)
'HMO3' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 192 ;
	}

#paramId: 500209
#Vertically integrated ozone content (climatological)
'VIO3' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 193 ;
	}

#paramId: 500221
#Ratio of monthly mean NDVI (normalized differential vegetation index) to annual maximum
'NDVI_MRAT' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 192 ;
	 typeOfStatisticalProcessing = 0 ;
	}

#paramId: 500222
#Ratio of NDVI (normalized differential vegetation index) to annual maximum
'NDVIRATIO' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 192 ;
	}

#paramId: 500233
#Tendency of specific humidity
'DQVDT' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 207 ;
	}

#paramId: 500234
#Water vapor flux
'QVSFLX' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 208 ;
	}

#paramId: 500235
#Coriolis parameter
'FC' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 193 ;
	}

#paramId: 500239
#Delay of the GPS signal through the (total) atmos.
'ZTD' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 192 ;
	}

#paramId: 500240
#Delay of the GPS signal through wet atmos.
'ZWD' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 193 ;
	}

#paramId: 500241
#Delay of the GPS signal through dry atmos.
'ZHD' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 194 ;
	}

#paramId: 500279
#U-momentum flux due to SSO-effects (mean over forecast time)
'AUSTR_SSO' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 193 ;
	 typeOfStatisticalProcessing = 0 ;
	}

#paramId: 500280
#U-momentum flux due to SSO-effects
'USTR_SSO' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 193 ;
	}

#paramId: 500281
#V-momentum flux due to SSO-effects (mean over forecast time)
'AVSTR_SSO' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 194 ;
	 typeOfStatisticalProcessing = 0 ;
	}

#paramId: 500282
#V-momentum flux due to SSO-effects
'VSTR_SSO' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 194 ;
	}

#paramId: 500288
#Absolute vorticity advection
'VABS' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 197 ;
	}

#paramId: 500289
#Kombination Niederschlag-Bewoelkung-Blauthermik (cl_typ.tab)
'CL_TYP' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 194 ;
	}

#paramId: 500291
#Hoehe der Konvektionsuntergrenze ueber nn
'CCL_NN' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 24 ;
	 typeOfSecondFixedSurface = 101 ;
	 typeOfFirstFixedSurface = 2 ;
	}

#paramId: 500293
#geostrophische Vorticityadvektion
'ADVORG' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 0 ;
	}

#paramId: 500294
#Geostrophic thickness advection
'ADVOR' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 1 ;
	}

#paramId: 500295
#Schichtdickenadvektion
'ADRTG' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 2 ;
	}

#paramId: 500296
#Winddivergenz
'WDIV' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 3 ;
	}

#paramId: 500297
#Q-Vektor senkrecht zu den Isothermen
'QVN' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 4 ;
	}

#paramId: 500298
#Isentrope potentielle Vorticity
'IPV' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 25 ;
	 typeOfFirstFixedSurface = 107 ;
	}

#paramId: 500299
#Wind X-Komponente auf isentropen Flaechen
'UP' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 5 ;
	}

#paramId: 500300
#Wind Y-Komponente auf isentropen Flaechen
'VP' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 6 ;
	}

#paramId: 500306
#Modified cloud depth for media
'CLDEPTH' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 198 ;
	}

#paramId: 500307
#Modified cloud cover for media
'CLCT_MOD' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 199 ;
	}

#paramId: 500322
#RMS of difference "first guess - analysis" of kinetic energy
'EFA-KE' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 196 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 201 ;
	}

#paramId: 500323
#RMS of difference "initialized analysis - analysis" of kinetic energy
'EIA-KE' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 196 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 200 ;
	}

#paramId: 500437
#Probability of 1h total precipitation >= 10mm
'W_SKRR_01' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500438
#Probability of 1h total precipitation >= 25mm
'U_SKRRH_01' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500439
#Probability of 6h total precipitation >= 20mm
'W_SKRR_06' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 14 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500440
#Probability of 6h total precipitation >= 35mm
'U_SKRRH_06' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 17 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500441
#Probability of 12h total precipitation >= 25mm
'W_DRR_12' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 26 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500442
#Probability of 12h total precipitation >= 40mm
'U_DRRER_12' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 29 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500443
#Probability of 12h total precipitation >= 70mm
'E_DR_12' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 32 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500444
#Probability of 6h accumulated snow >=0.5cm
'W_SFL_06' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 69 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500445
#Probability of 6h accumulated snow >= 5cm
'W_SF_06' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 70 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500446
#Probability of 6h accumulated snow >= 10cm
'U_SFSK_06' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 71 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500447
#Probability of 12h accumulated snow >=0.5cm
'W_SFL_12' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 72 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500448
#Probability of 12h accumulated snow >= 10cm
'W_SF_12' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 74 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500449
#Probability of 12h accumulated snow >= 15cm
'U_SFSK_12' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 75 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500450
#Probability of 12h accumulated snow >= 25cm
'E_SF_12' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500451
#Probability of 1h maximum wind gust speed >= 14m/s
'W_WND_01' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 132 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500452
#Probability of 1h maximum wind gust speed >= 18m/s
'W_STM_01' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 134 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500453
#Probability of 1h maximum wind gust speed >= 25m/s
'W_STMSW_01' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 136 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500454
#Probability of 1h maximum wind gust speed >= 29m/s
'U_ORKAR_01' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 137 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500455
#Probability of 1h maximum wind gust speed >= 33m/s
'U_ORK_01' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 138 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500456
#Probability of 1h maximum wind gust speed >= 39m/s
'E_ORK_01' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 139 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500457
#Probability of black ice during 1h
'W_GLEIS_01' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 191 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500458
#Probability of thunderstorm during 1h
'W_GEW_01' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 197 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500459
#Probability of heavy thunderstorm during 1h
'W_GEWSK_01' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 198 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500460
#Probability of severe thunderstorm during 1h
'U_GEWSW_01' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 199 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500461
#Probability of snowdrift during 12h
'W_SVW_12' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 212 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500462
#Probability of strong snowdrift during 12h
'U_SVWSK_12' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 213 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500463
#Probability of temperature < 0 deg C during 1h
'W_FR_01' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 232 ;
	 typeOfStatisticalProcessing = 3 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500464
#Probability of temperature <= -10 deg C during 6h
'W_FRSTR_06' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 236 ;
	 typeOfStatisticalProcessing = 3 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500465
#UV Index, clear sky; corrected for albedo, aerosol and altitude
'UVI_CS_COR' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 195 ;
	}

#paramId: 500466
#Basic UV Index, clear sky; MSL, fixed albedo, fixed aerosol
'UVI_B_CS' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 196 ;
	}

#paramId: 500467
#UV Index, clouded sky; corrected for albedo, aerosol, altitude and clouds
'UVI_CL_COR' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 197 ;
	}

#paramId: 500471
#Time of maximum of UV Index, clouded
'UVI_MAX_H' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 194 ;
	 typeOfStatisticalProcessing = 2 ;
	}

#paramId: 500472
#Type of convection (0..4)
'C_TYPE' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 201 ;
	}

#paramId: 500473
#perceived temperature
'PT1M' = {
	 discipline = 0 ;
	 parameterCategory = 192 ;
	 parameterNumber = 1 ;
	}

#paramId: 500478
#probability to perceive sultriness
'SUL_PROB' = {
	 discipline = 0 ;
	 parameterCategory = 192 ;
	 parameterNumber = 3 ;
	}

#paramId: 500479
#value of isolation of clothes
'CLO' = {
	 discipline = 0 ;
	 parameterCategory = 192 ;
	 parameterNumber = 2 ;
	}

#paramId: 500480
#Downward direct short wave radiation flux at surface (mean over forecast time)
'ASWDIR_S' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 198 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500481
#Downward diffusive short wave radiation flux at surface (mean over forecast time)
'ASWDIFD_S' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 199 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500503
#Icing Base (hft) - Icing Degree Composit
'PIDC_BASE_HFT' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 195 ;
	 typeOfGeneratingProcess = 2 ;
	}

#paramId: 500504
#Icing Max Base (hft) - Icing Degree Composit
'PIDC_MAX_BASE_HFT' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 196 ;
	 typeOfGeneratingProcess = 2 ;
	}

#paramId: 500505
#Icing Max Top (hft) - Icing Degree Composit
'PIDC_MAX_TOP_HFT' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 197 ;
	 typeOfGeneratingProcess = 2 ;
	}

#paramId: 500506
#Icing Top (hft) - Icing Degree Composit
'PIDC_TOP_HFT' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 198 ;
	 typeOfGeneratingProcess = 2 ;
	}

#paramId: 500507
#Icing Vertical Code (1=continuous,2=discontinuous) - Icing Degree Composit
'PIDC_VERT_CODE' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 199 ;
	 typeOfGeneratingProcess = 2 ;
	}

#paramId: 500508
#Icing Max Code (1=light,2=moderate,3=severe) - Icing Degree Composit
'PIDC_MAX_CODE' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 200 ;
	 typeOfGeneratingProcess = 2 ;
	}

#paramId: 500509
#Icing Base (hft) - Icing Scenario Composit
'PISC_BASE_HFT' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 201 ;
	 typeOfGeneratingProcess = 2 ;
	}

#paramId: 500510
#Icing Signifikant Base (hft) - Icing Scenario Composit
'PISC_SIG_BASE_HFT' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 202 ;
	 typeOfGeneratingProcess = 2 ;
	}

#paramId: 500511
#Icing Signifikant Top (hft) - Icing Scenario Composit
'PISC_SIG_TOP_HFT' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 203 ;
	 typeOfGeneratingProcess = 2 ;
	}

#paramId: 500512
#Icing Top (hft) - Icing Scenario Composit
'PISC_TOP_HFT' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 204 ;
	 typeOfGeneratingProcess = 2 ;
	}

#paramId: 500513
#Icing Vertical Code (1=continuous,2=discontinuous) - Icing Scenario Composit
'PISC_VERT_CODE' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 205 ;
	 typeOfGeneratingProcess = 2 ;
	}

#paramId: 500514
#Icing Signifikant Code (1=general,2=convective,3=stratiform,4=freezing) - Icing Scenario Composit
'PISC_SIG_CODE' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 206 ;
	 typeOfGeneratingProcess = 2 ;
	}

#paramId: 500515
#Icing Base (hft) - Icing Degree Composit
'DIDC_BASE_HFT' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 195 ;
	 typeOfGeneratingProcess = 0 ;
	}

#paramId: 500516
#Icing Max Base (hft) - Icing Degree Composit
'DIDC_MAX_BASE_HFT' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 196 ;
	 typeOfGeneratingProcess = 0 ;
	}

#paramId: 500517
#Icing Max Top (hft) - Icing Degree Composit
'DIDC_MAX_TOP_HFT' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 197 ;
	 typeOfGeneratingProcess = 0 ;
	}

#paramId: 500518
#Icing Top (hft) - Icing Degree Composit
'DIDC_TOP_HFT' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 198 ;
	 typeOfGeneratingProcess = 0 ;
	}

#paramId: 500519
#Icing Vertical Code (1=continuous,2=discontinuous) - Icing Degree Composit
'DIDC_VERT_CODE' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 199 ;
	 typeOfGeneratingProcess = 0 ;
	}

#paramId: 500520
#Icing Max Code (1=light,2=moderate,3=severe) - Icing Degree Composit
'DIDC_MAX_CODE' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 200 ;
	 typeOfGeneratingProcess = 0 ;
	}

#paramId: 500521
#Icing Base (hft) - Icing Scenario Composit
'DISC_BASE_HFT' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 201 ;
	 typeOfGeneratingProcess = 0 ;
	}

#paramId: 500522
#Icing Signifikant Base (hft) - Icing Scenario Composit
'DISC_SIG_BASE_HFT' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 202 ;
	 typeOfGeneratingProcess = 0 ;
	}

#paramId: 500523
#Icing Signifikant Top (hft) - Icing Scenario Composit
'DISC_SIG_TOP_HFT' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 203 ;
	 typeOfGeneratingProcess = 0 ;
	}

#paramId: 500524
#Icing Top (hft) - Icing Scenario Composit
'DISC_TOP_HFT' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 204 ;
	 typeOfGeneratingProcess = 0 ;
	}

#paramId: 500525
#Icing Vertical Code (1=continuous,2=discontinuous) - Icing Scenario Composit
'DISC_VERT_CODE' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 205 ;
	 typeOfGeneratingProcess = 0 ;
	}

#paramId: 500526
#Icing Signifikant Code (1=general,2=convective,3=stratiform,4=freezing) - Icing Scenario Composit
'DISC_SIG_CODE' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 206 ;
	 typeOfGeneratingProcess = 0 ;
	}

#paramId: 500527
#Icing Degree Code (1=light,2=moderate,3=severe)
'PID_CODE' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 207 ;
	 typeOfGeneratingProcess = 2 ;
	}

#paramId: 500528
#Icing Scenario Code (1=general,2=convective,3=stratiform,4=freezing)
'PIS_CODE' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 208 ;
	 typeOfGeneratingProcess = 2 ;
	}

#paramId: 500529
#Icing Degree Code (1=light,2=moderate,3=severe)
'DID_CODE' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 207 ;
	 typeOfGeneratingProcess = 0 ;
	}

#paramId: 500530
#Icing Scenario Code (1=general,2=convective,3=stratiform,4=freezing)
'DIS_CODE' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 208 ;
	 typeOfGeneratingProcess = 0 ;
	}

#paramId: 500531
#current weather (symbol number: 0..9)
'WW_0-9' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 209 ;
	}

#paramId: 500538
#cloud type
'CL_TYPE_SAT' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 192 ;
	}

#paramId: 500540
#cloud top temperature
'CL_TOP_TEMP' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 192 ;
	}

#paramId: 500541
#Relative vorticity, u-component
'VORTIC_U' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 198 ;
	}

#paramId: 500542
#Relative vorticity, v-component
'VORTIC_V' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 199 ;
	}

#paramId: 500550
#Potentielle Vorticity (auf Druckflaechen, nicht isentrop)
'PVP' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 23 ;
	}

#paramId: 500551
#geostrophische Vorticity
'VORG' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 7 ;
	}

#paramId: 500552
#Forcing rechte Seite Omegagleichung
'FORCOMEGA' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 8 ;
	}

#paramId: 500553
#Q-Vektor X-Komponente (geostrophisch)
'QVX' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 9 ;
	}

#paramId: 500554
#Q-Vektor Y-Komponente (geostrophisch)
'QVY' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 10 ;
	}

#paramId: 500555
#Divergenz Q (geostrophisch)
'DIVGEO' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 11 ;
	}

#paramId: 500556
#Q-Vektor senkrecht zu d. Isothermen (geostrophisch)
'QVNGEO' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 12 ;
	}

#paramId: 500557
#Q-Vektor parallel zu d. Isothermen (geostrophisch)
'QVSGEO' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 13 ;
	}

#paramId: 500558
#Divergenz Qn geostrophisch
'DIVQNGEO' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 14 ;
	}

#paramId: 500559
#Divergenz Qs geostrophisch
'DIVQSGEO' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 15 ;
	}

#paramId: 500560
#Frontogenesefunktion
'FRONTO' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 16 ;
	}

#paramId: 500562
#Divergenz
'DIVQ' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 17 ;
	}

#paramId: 500563
#Q-Vektor parallel zu den Isothermen
'QVS' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 18 ;
	}

#paramId: 500564
#Divergenz Qn
'DIVQN' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 19 ;
	}

#paramId: 500565
#Divergenz Qs
'DIVQS' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 20 ;
	}

#paramId: 500566
#Frontogenesis function
'FRONTOF' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 21 ;
	}

#paramId: 500567
#Clear Air Turbulence Index
'CATIX' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 22 ;
	}

#paramId: 500570
#Dry convection top index
'TOP_DCON' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 202 ;
	}

#paramId: 500572
#Tidal tendencies
'TIDAL' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 192 ;
	}

#paramId: 500573
#Sea surface temperature interpolated in time in C
'SST_IC' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 192 ;
	}

#paramId: 500575
#3 hour pressure change
'PPP' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 195 ;
	}

#paramId: 500577
#Variance of soil moisture content
'WVAR' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 197 ;
	 typeOfGeneratingProcess = 6 ;
	}

#paramId: 500578
#Covariance of soil moisture content
'WCOV' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 198 ;
	 typeOfGeneratingProcess = 6 ;
	}

#paramId: 500585
#Eddy Dissipation Rate
'EDP' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 216 ;
	}

#paramId: 500586
#Ellrod Index
'ELD' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 217 ;
	}

#paramId: 500591
#Niederschlagsdargebot: potential water supply (rain and snow melt) from snowpack - accumulation
'RR_SNOW' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 209 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 500620
#Prob Gewitter
'TS' = {
	 discipline = 0 ;
	 parameterCategory = 196 ;
	 parameterNumber = 1 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500621
#Prob Starkes Gewitter
'TSX' = {
	 discipline = 0 ;
	 parameterCategory = 196 ;
	 parameterNumber = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500622
#Prob Schweres Gewitter
'TSXX' = {
	 discipline = 0 ;
	 parameterCategory = 196 ;
	 parameterNumber = 3 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500623
#Prob Dauerregen
'RA25' = {
	 discipline = 0 ;
	 parameterCategory = 196 ;
	 parameterNumber = 4 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500624
#Prob Ergiebiger Dauerregen
'RA40' = {
	 discipline = 0 ;
	 parameterCategory = 196 ;
	 parameterNumber = 5 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500625
#Prob Extrem ergiebiger Dauerregen
'RA70' = {
	 discipline = 0 ;
	 parameterCategory = 196 ;
	 parameterNumber = 6 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500626
#Prob Schneeverwehung
'BLSN6' = {
	 discipline = 0 ;
	 parameterCategory = 196 ;
	 parameterNumber = 7 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500627
#Prob Starke Schneeverwehung
'BLSN8' = {
	 discipline = 0 ;
	 parameterCategory = 196 ;
	 parameterNumber = 8 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500628
#Prob Glaette
'FZ' = {
	 discipline = 0 ;
	 parameterCategory = 196 ;
	 parameterNumber = 9 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500629
#Prob oertlich Glatteis
'FZRA' = {
	 discipline = 0 ;
	 parameterCategory = 196 ;
	 parameterNumber = 10 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500630
#Prob Glatteis
'FZRAX' = {
	 discipline = 0 ;
	 parameterCategory = 196 ;
	 parameterNumber = 11 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500631
#Prob Nebel (ueberoertl. Sichtweite < 150 m)
'FG' = {
	 discipline = 0 ;
	 parameterCategory = 196 ;
	 parameterNumber = 12 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500632
#Prob Tauwetter
'TAU' = {
	 discipline = 0 ;
	 parameterCategory = 196 ;
	 parameterNumber = 13 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500633
#Prob Starkes Tauwetter
'TAUX' = {
	 discipline = 0 ;
	 parameterCategory = 196 ;
	 parameterNumber = 14 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500634
#Wake-production of TKE due to sub-grid scale orography
'DTKE_SSO' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 220 ;
	}

#paramId: 500635
#Shear-production of TKE due to separated horizontal shear modes
'DTKE_HSH' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 221 ;
	}

#paramId: 500636
#Buoyancy-production of TKE due to sub-grid scale convection
'DTKE_CON' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 219 ;
	}

#paramId: 500637
#Production of TKE
'DTKE' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 218 ;
	}

#paramId: 500638
#Atmospheric resistance
'ATM_RSTC' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 200 ;
	}

#paramId: 500639
#Height of thermals above MSL
'HTOP_THERM' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 197 ;
	}

#paramId: 500640
#Mass concentration of dust (minimum mode)
'VSOILA' = {
	 discipline = 0 ;
	 parameterCategory = 197 ;
	 parameterNumber = 33 ;
	}

#paramId: 500643
#Mass concentration of dust (medium mode)
'VSOILB' = {
	 discipline = 0 ;
	 parameterCategory = 197 ;
	 parameterNumber = 34 ;
	}

#paramId: 500644
#Mass concentration of dust (maximum mode)
'VSOILC' = {
	 discipline = 0 ;
	 parameterCategory = 197 ;
	 parameterNumber = 35 ;
	}

#paramId: 500645
#Number concentration of dust (minimum mode)
'VSOILA0' = {
	 discipline = 0 ;
	 parameterCategory = 197 ;
	 parameterNumber = 72 ;
	}

#paramId: 500646
#Number concentration of dust (medium mode)
'VSOILB0' = {
	 discipline = 0 ;
	 parameterCategory = 197 ;
	 parameterNumber = 73 ;
	}

#paramId: 500647
#Number concentration of dust (maximum mode)
'VSOILC0' = {
	 discipline = 0 ;
	 parameterCategory = 197 ;
	 parameterNumber = 74 ;
	}

#paramId: 500648
#Mass concentration of dust (sum of all modes)
'VSOILS' = {
	 discipline = 0 ;
	 parameterCategory = 197 ;
	 parameterNumber = 251 ;
	}

#paramId: 500649
#Number concentration of dust (sum of all modes)
'VSOILS0' = {
	 discipline = 0 ;
	 parameterCategory = 197 ;
	 parameterNumber = 252 ;
	}

#paramId: 500650
#DUMMY_1
'DUMMY_1' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 1 ;
	}

#paramId: 500651
#DUMMY_2
'DUMMY_2' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 2 ;
	}

#paramId: 500652
#DUMMY_3
'DUMMY_3' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 3 ;
	}

#paramId: 500654
#DUMMY_4
'DUMMY_4' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 4 ;
	}

#paramId: 500655
#DUMMY_5
'DUMMY_5' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 5 ;
	}

#paramId: 500656
#DUMMY_6
'DUMMY_6' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 6 ;
	}

#paramId: 500657
#DUMMY_7
'DUMMY_7' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 7 ;
	}

#paramId: 500658
#DUMMY_8
'DUMMY_8' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 8 ;
	}

#paramId: 500659
#DUMMY_9
'DUMMY_9' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 9 ;
	}

#paramId: 500660
#DUMMY_10
'DUMMY_10' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 10 ;
	}

#paramId: 500661
#DUMMY_11
'DUMMY_11' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 11 ;
	}

#paramId: 500662
#DUMMY_12
'DUMMY_12' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 12 ;
	}

#paramId: 500663
#DUMMY_13
'DUMMY_13' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 13 ;
	}

#paramId: 500664
#DUMMY_14
'DUMMY_14' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 14 ;
	}

#paramId: 500665
#DUMMY_15
'DUMMY_15' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 15 ;
	}

#paramId: 500666
#DUMMY_16
'DUMMY_16' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 16 ;
	}

#paramId: 500667
#DUMMY_17
'DUMMY_17' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 17 ;
	}

#paramId: 500668
#DUMMY_18
'DUMMY_18' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 18 ;
	}

#paramId: 500669
#DUMMY_19
'DUMMY_19' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 19 ;
	}

#paramId: 500670
#DUMMY_20
'DUMMY_20' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 20 ;
	}

#paramId: 500671
#DUMMY_21
'DUMMY_21' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 21 ;
	}

#paramId: 500672
#DUMMY_22
'DUMMY_22' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 22 ;
	}

#paramId: 500673
#DUMMY_23
'DUMMY_23' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 23 ;
	}

#paramId: 500674
#DUMMY_24
'DUMMY_24' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 24 ;
	}

#paramId: 500675
#DUMMY_25
'DUMMY_25' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 25 ;
	}

#paramId: 500676
#DUMMY_26
'DUMMY_26' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 26 ;
	}

#paramId: 500677
#DUMMY_27
'DUMMY_27' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 27 ;
	}

#paramId: 500678
#DUMMY_28
'DUMMY_28' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 28 ;
	}

#paramId: 500679
#DUMMY_29
'DUMMY_29' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 29 ;
	}

#paramId: 500680
#DUMMY_30
'DUMMY_30' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 30 ;
	}

#paramId: 500681
#DUMMY_31
'DUMMY_31' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 31 ;
	}

#paramId: 500682
#DUMMY_32
'DUMMY_32' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 32 ;
	}

#paramId: 500683
#DUMMY_33
'DUMMY_33' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 33 ;
	}

#paramId: 500684
#DUMMY_34
'DUMMY_34' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 34 ;
	}

#paramId: 500685
#DUMMY_35
'DUMMY_35' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 35 ;
	}

#paramId: 500686
#DUMMY_36
'DUMMY_36' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 36 ;
	}

#paramId: 500687
#DUMMY_37
'DUMMY_37' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 37 ;
	}

#paramId: 500688
#DUMMY_38
'DUMMY_38' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 38 ;
	}

#paramId: 500689
#DUMMY_39
'DUMMY_39' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 39 ;
	}

#paramId: 500690
#DUMMY_40
'DUMMY_40' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 40 ;
	}

#paramId: 500691
#DUMMY_41
'DUMMY_41' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 41 ;
	}

#paramId: 500692
#DUMMY_42
'DUMMY_42' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 42 ;
	}

#paramId: 500693
#DUMMY_43
'DUMMY_43' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 43 ;
	}

#paramId: 500694
#DUMMY_44
'DUMMY_44' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 44 ;
	}

#paramId: 500695
#DUMMY_45
'DUMMY_45' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 45 ;
	}

#paramId: 500696
#DUMMY_46
'DUMMY_46' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 46 ;
	}

#paramId: 500697
#DUMMY_47
'DUMMY_47' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 47 ;
	}

#paramId: 500698
#DUMMY_48
'DUMMY_48' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 48 ;
	}

#paramId: 500699
#DUMMY_49
'DUMMY_49' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 49 ;
	}

#paramId: 500700
#DUMMY_50
'DUMMY_50' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 50 ;
	}

#paramId: 500701
#DUMMY_51
'DUMMY_51' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 51 ;
	}

#paramId: 500702
#DUMMY_52
'DUMMY_52' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 52 ;
	}

#paramId: 500703
#DUMMY_53
'DUMMY_53' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 53 ;
	}

#paramId: 500704
#DUMMY_54
'DUMMY_54' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 54 ;
	}

#paramId: 500705
#DUMMY_55
'DUMMY_55' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 55 ;
	}

#paramId: 500706
#DUMMY_56
'DUMMY_56' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 56 ;
	}

#paramId: 500707
#DUMMY_57
'DUMMY_57' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 57 ;
	}

#paramId: 500708
#DUMMY_58
'DUMMY_58' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 58 ;
	}

#paramId: 500709
#DUMMY_59
'DUMMY_59' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 59 ;
	}

#paramId: 500710
#DUMMY_60
'DUMMY_60' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 60 ;
	}

#paramId: 500711
#DUMMY_61
'DUMMY_61' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 61 ;
	}

#paramId: 500712
#DUMMY_62
'DUMMY_62' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 62 ;
	}

#paramId: 500713
#DUMMY_63
'DUMMY_63' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 63 ;
	}

#paramId: 500714
#DUMMY_64
'DUMMY_64' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 64 ;
	}

#paramId: 500715
#DUMMY_65
'DUMMY_65' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 65 ;
	}

#paramId: 500716
#DUMMY_66
'DUMMY_66' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 66 ;
	}

#paramId: 500717
#DUMMY_67
'DUMMY_67' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 67 ;
	}

#paramId: 500718
#DUMMY_68
'DUMMY_68' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 68 ;
	}

#paramId: 500719
#DUMMY_69
'DUMMY_69' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 69 ;
	}

#paramId: 500720
#DUMMY_70
'DUMMY_70' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 70 ;
	}

#paramId: 500721
#DUMMY_71
'DUMMY_71' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 71 ;
	}

#paramId: 500722
#DUMMY_72
'DUMMY_72' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 72 ;
	}

#paramId: 500723
#DUMMY_73
'DUMMY_73' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 73 ;
	}

#paramId: 500724
#DUMMY_74
'DUMMY_74' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 74 ;
	}

#paramId: 500725
#DUMMY_75
'DUMMY_75' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 75 ;
	}

#paramId: 500726
#DUMMY_76
'DUMMY_76' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 76 ;
	}

#paramId: 500727
#DUMMY_77
'DUMMY_77' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 77 ;
	}

#paramId: 500728
#DUMMY_78
'DUMMY_78' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 78 ;
	}

#paramId: 500729
#DUMMY_79
'DUMMY_79' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 79 ;
	}

#paramId: 500730
#DUMMY_80
'DUMMY_80' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 80 ;
	}

#paramId: 500731
#DUMMY_81
'DUMMY_81' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 81 ;
	}

#paramId: 500732
#DUMMY_82
'DUMMY_82' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 82 ;
	}

#paramId: 500733
#DUMMY_83
'DUMMY_83' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 83 ;
	}

#paramId: 500734
#DUMMY_84
'DUMMY_84' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 84 ;
	}

#paramId: 500735
#DUMMY_85
'DUMMY_85' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 85 ;
	}

#paramId: 500736
#DUMMY_86
'DUMMY_86' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 86 ;
	}

#paramId: 500737
#DUMMY_87
'DUMMY_87' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 87 ;
	}

#paramId: 500738
#DUMMY_88
'DUMMY_88' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 88 ;
	}

#paramId: 500739
#DUMMY_89
'DUMMY_89' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 89 ;
	}

#paramId: 500740
#DUMMY_90
'DUMMY_90' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 90 ;
	}

#paramId: 500741
#DUMMY_91
'DUMMY_91' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 91 ;
	}

#paramId: 500742
#DUMMY_92
'DUMMY_92' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 92 ;
	}

#paramId: 500743
#DUMMY_93
'DUMMY_93' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 93 ;
	}

#paramId: 500744
#DUMMY_94
'DUMMY_94' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 94 ;
	}

#paramId: 500745
#DUMMY_95
'DUMMY_95' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 95 ;
	}

#paramId: 500746
#DUMMY_96
'DUMMY_96' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 96 ;
	}

#paramId: 500747
#DUMMY_97
'DUMMY_97' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 97 ;
	}

#paramId: 500748
#DUMMY_98
'DUMMY_98' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 98 ;
	}

#paramId: 500749
#DUMMY_99
'DUMMY_99' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 99 ;
	}

#paramId: 500750
#DUMMY_100
'DUMMY_100' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 100 ;
	}

#paramId: 500751
#DUMMY_101
'DUMMY_101' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 101 ;
	}

#paramId: 500752
#DUMMY_102
'DUMMY_102' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 102 ;
	}

#paramId: 500753
#DUMMY_103
'DUMMY_103' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 103 ;
	}

#paramId: 500754
#DUMMY_104
'DUMMY_104' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 104 ;
	}

#paramId: 500755
#DUMMY_105
'DUMMY_105' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 105 ;
	}

#paramId: 500756
#DUMMY_106
'DUMMY_106' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 106 ;
	}

#paramId: 500757
#DUMMY_107
'DUMMY_107' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 107 ;
	}

#paramId: 500758
#DUMMY_108
'DUMMY_108' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 108 ;
	}

#paramId: 500759
#DUMMY_109
'DUMMY_109' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 109 ;
	}

#paramId: 500760
#DUMMY_110
'DUMMY_110' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 110 ;
	}

#paramId: 500761
#DUMMY_111
'DUMMY_111' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 111 ;
	}

#paramId: 500762
#DUMMY_112
'DUMMY_112' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 112 ;
	}

#paramId: 500763
#DUMMY_113
'DUMMY_113' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 113 ;
	}

#paramId: 500764
#DUMMY_114
'DUMMY_114' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 114 ;
	}

#paramId: 500765
#DUMMY_115
'DUMMY_115' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 115 ;
	}

#paramId: 500766
#DUMMY_116
'DUMMY_116' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 116 ;
	}

#paramId: 500767
#DUMMY_117
'DUMMY_117' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 117 ;
	}

#paramId: 500768
#DUMMY_118
'DUMMY_118' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 118 ;
	}

#paramId: 500769
#DUMMY_119
'DUMMY_119' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 119 ;
	}

#paramId: 500770
#DUMMY_120
'DUMMY_120' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 120 ;
	}

#paramId: 500771
#DUMMY_121
'DUMMY_121' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 121 ;
	}

#paramId: 500772
#DUMMY_122
'DUMMY_122' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 122 ;
	}

#paramId: 500773
#DUMMY_123
'DUMMY_123' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 123 ;
	}

#paramId: 500774
#DUMMY_124
'DUMMY_124' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 124 ;
	}

#paramId: 500775
#DUMMY_125
'DUMMY_125' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 125 ;
	}

#paramId: 500776
#DUMMY_126
'DUMMY_126' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 126 ;
	}

#paramId: 500777
#DUMMY_127
'DUMMY_127' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 127 ;
	}

#paramId: 500778
#DUMMY_128
'DUMMY_128' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 128 ;
	}

#paramId: 500779
#DUMMY_129
'DUMMY_129' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 129 ;
	}

#paramId: 500780
#DUMMY_130
'DUMMY_130' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 130 ;
	}

#paramId: 500781
#DUMMY_131
'DUMMY_131' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 131 ;
	}

#paramId: 500782
#DUMMY_132
'DUMMY_132' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 132 ;
	}

#paramId: 500783
#DUMMY_133
'DUMMY_133' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 133 ;
	}

#paramId: 500784
#DUMMY_134
'DUMMY_134' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 134 ;
	}

#paramId: 500785
#DUMMY_135
'DUMMY_135' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 135 ;
	}

#paramId: 500786
#DUMMY_136
'DUMMY_136' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 136 ;
	}

#paramId: 500787
#DUMMY_137
'DUMMY_137' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 137 ;
	}

#paramId: 500788
#DUMMY_138
'DUMMY_138' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 138 ;
	}

#paramId: 500789
#DUMMY_139
'DUMMY_139' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 139 ;
	}

#paramId: 500790
#DUMMY_140
'DUMMY_140' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 140 ;
	}

#paramId: 500791
#DUMMY_141
'DUMMY_141' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 141 ;
	}

#paramId: 500792
#DUMMY_142
'DUMMY_142' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 142 ;
	}

#paramId: 500793
#DUMMY_143
'DUMMY_143' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 143 ;
	}

#paramId: 500794
#DUMMY_144
'DUMMY_144' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 144 ;
	}

#paramId: 500795
#DUMMY_145
'DUMMY_145' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 145 ;
	}

#paramId: 500796
#DUMMY_146
'DUMMY_146' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 146 ;
	}

#paramId: 500797
#DUMMY_147
'DUMMY_147' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 147 ;
	}

#paramId: 500798
#DUMMY_148
'DUMMY_148' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 148 ;
	}

#paramId: 500799
#DUMMY_149
'DUMMY_149' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 149 ;
	}

#paramId: 500800
#DUMMY_150
'DUMMY_150' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 150 ;
	}

#paramId: 500801
#DUMMY_151
'DUMMY_151' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 151 ;
	}

#paramId: 500802
#DUMMY_152
'DUMMY_152' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 152 ;
	}

#paramId: 500803
#DUMMY_153
'DUMMY_153' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 153 ;
	}

#paramId: 500804
#DUMMY_154
'DUMMY_154' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 154 ;
	}

#paramId: 500805
#DUMMY_155
'DUMMY_155' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 155 ;
	}

#paramId: 500806
#DUMMY_156
'DUMMY_156' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 156 ;
	}

#paramId: 500807
#DUMMY_157
'DUMMY_157' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 157 ;
	}

#paramId: 500808
#DUMMY_158
'DUMMY_158' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 158 ;
	}

#paramId: 500809
#DUMMY_159
'DUMMY_159' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 159 ;
	}

#paramId: 500810
#DUMMY_160
'DUMMY_160' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 160 ;
	}

#paramId: 500811
#DUMMY_161
'DUMMY_161' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 161 ;
	}

#paramId: 500812
#DUMMY_162
'DUMMY_162' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 162 ;
	}

#paramId: 500813
#DUMMY_163
'DUMMY_163' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 163 ;
	}

#paramId: 500814
#DUMMY_164
'DUMMY_164' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 164 ;
	}

#paramId: 500815
#DUMMY_165
'DUMMY_165' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 165 ;
	}

#paramId: 500816
#DUMMY_166
'DUMMY_166' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 166 ;
	}

#paramId: 500817
#DUMMY_167
'DUMMY_167' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 167 ;
	}

#paramId: 500818
#DUMMY_168
'DUMMY_168' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 168 ;
	}

#paramId: 500819
#DUMMY_169
'DUMMY_169' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 169 ;
	}

#paramId: 500820
#DUMMY_170
'DUMMY_170' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 170 ;
	}

#paramId: 500821
#DUMMY_171
'DUMMY_171' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 171 ;
	}

#paramId: 500822
#DUMMY_172
'DUMMY_172' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 172 ;
	}

#paramId: 500823
#DUMMY_173
'DUMMY_173' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 173 ;
	}

#paramId: 500824
#DUMMY_174
'DUMMY_174' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 174 ;
	}

#paramId: 500825
#DUMMY_175
'DUMMY_175' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 175 ;
	}

#paramId: 500826
#DUMMY_176
'DUMMY_176' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 176 ;
	}

#paramId: 500827
#DUMMY_177
'DUMMY_177' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 177 ;
	}

#paramId: 500828
#DUMMY_178
'DUMMY_178' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 178 ;
	}

#paramId: 500829
#DUMMY_179
'DUMMY_179' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 179 ;
	}

#paramId: 500830
#DUMMY_180
'DUMMY_180' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 180 ;
	}

#paramId: 500831
#DUMMY_181
'DUMMY_181' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 181 ;
	}

#paramId: 500832
#DUMMY_182
'DUMMY_182' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 182 ;
	}

#paramId: 500833
#DUMMY_183
'DUMMY_183' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 183 ;
	}

#paramId: 500834
#DUMMY_184
'DUMMY_184' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 184 ;
	}

#paramId: 500835
#DUMMY_185
'DUMMY_185' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 185 ;
	}

#paramId: 500836
#DUMMY_186
'DUMMY_186' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 186 ;
	}

#paramId: 500837
#DUMMY_187
'DUMMY_187' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 187 ;
	}

#paramId: 500838
#DUMMY_188
'DUMMY_188' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 188 ;
	}

#paramId: 500839
#DUMMY_189
'DUMMY_189' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 189 ;
	}

#paramId: 500840
#DUMMY_190
'DUMMY_190' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 190 ;
	}

#paramId: 500841
#DUMMY_191
'DUMMY_191' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 191 ;
	}

#paramId: 500842
#DUMMY_192
'DUMMY_192' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 192 ;
	}

#paramId: 500843
#DUMMY_193
'DUMMY_193' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 193 ;
	}

#paramId: 500844
#DUMMY_194
'DUMMY_194' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 194 ;
	}

#paramId: 500845
#DUMMY_195
'DUMMY_195' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 195 ;
	}

#paramId: 500846
#DUMMY_196
'DUMMY_196' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 196 ;
	}

#paramId: 500847
#DUMMY_197
'DUMMY_197' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 197 ;
	}

#paramId: 500848
#DUMMY_198
'DUMMY_198' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 198 ;
	}

#paramId: 500849
#DUMMY_199
'DUMMY_199' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 199 ;
	}

#paramId: 500850
#DUMMY_200
'DUMMY_200' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 200 ;
	}

#paramId: 500851
#DUMMY_201
'DUMMY_201' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 201 ;
	}

#paramId: 500852
#DUMMY_202
'DUMMY_202' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 202 ;
	}

#paramId: 500853
#DUMMY_203
'DUMMY_203' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 203 ;
	}

#paramId: 500854
#DUMMY_204
'DUMMY_204' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 204 ;
	}

#paramId: 500855
#DUMMY_205
'DUMMY_205' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 205 ;
	}

#paramId: 500856
#DUMMY_206
'DUMMY_206' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 206 ;
	}

#paramId: 500857
#DUMMY_207
'DUMMY_207' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 207 ;
	}

#paramId: 500858
#DUMMY_208
'DUMMY_208' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 208 ;
	}

#paramId: 500859
#DUMMY_209
'DUMMY_209' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 209 ;
	}

#paramId: 500860
#DUMMY_210
'DUMMY_210' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 210 ;
	}

#paramId: 500861
#DUMMY_211
'DUMMY_211' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 211 ;
	}

#paramId: 500862
#DUMMY_212
'DUMMY_212' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 212 ;
	}

#paramId: 500863
#DUMMY_213
'DUMMY_213' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 213 ;
	}

#paramId: 500864
#DUMMY_214
'DUMMY_214' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 214 ;
	}

#paramId: 500865
#DUMMY_215
'DUMMY_215' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 215 ;
	}

#paramId: 500866
#DUMMY_216
'DUMMY_216' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 216 ;
	}

#paramId: 500867
#DUMMY_217
'DUMMY_217' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 217 ;
	}

#paramId: 500868
#DUMMY_218
'DUMMY_218' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 218 ;
	}

#paramId: 500869
#DUMMY_219
'DUMMY_219' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 219 ;
	}

#paramId: 500870
#DUMMY_220
'DUMMY_220' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 220 ;
	}

#paramId: 500871
#DUMMY_221
'DUMMY_221' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 221 ;
	}

#paramId: 500872
#DUMMY_222
'DUMMY_222' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 222 ;
	}

#paramId: 500873
#DUMMY_223
'DUMMY_223' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 223 ;
	}

#paramId: 500874
#DUMMY_224
'DUMMY_224' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 224 ;
	}

#paramId: 500875
#DUMMY_225
'DUMMY_225' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 225 ;
	}

#paramId: 500876
#DUMMY_226
'DUMMY_226' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 226 ;
	}

#paramId: 500877
#DUMMY_227
'DUMMY_227' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 227 ;
	}

#paramId: 500878
#DUMMY_228
'DUMMY_228' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 228 ;
	}

#paramId: 500879
#DUMMY_229
'DUMMY_229' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 229 ;
	}

#paramId: 500880
#DUMMY_230
'DUMMY_230' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 230 ;
	}

#paramId: 500881
#DUMMY_231
'DUMMY_231' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 231 ;
	}

#paramId: 500882
#DUMMY_232
'DUMMY_232' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 232 ;
	}

#paramId: 500883
#DUMMY_233
'DUMMY_233' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 233 ;
	}

#paramId: 500884
#DUMMY_234
'DUMMY_234' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 234 ;
	}

#paramId: 500885
#DUMMY_235
'DUMMY_235' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 235 ;
	}

#paramId: 500886
#DUMMY_236
'DUMMY_236' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 236 ;
	}

#paramId: 500887
#DUMMY_237
'DUMMY_237' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 237 ;
	}

#paramId: 500888
#DUMMY_238
'DUMMY_238' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 238 ;
	}

#paramId: 500889
#DUMMY_239
'DUMMY_239' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 239 ;
	}

#paramId: 500890
#DUMMY_240
'DUMMY_240' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 240 ;
	}

#paramId: 500891
#DUMMY_241
'DUMMY_241' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 241 ;
	}

#paramId: 500892
#DUMMY_242
'DUMMY_242' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 242 ;
	}

#paramId: 500893
#DUMMY_243
'DUMMY_243' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 243 ;
	}

#paramId: 500894
#DUMMY_244
'DUMMY_244' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 244 ;
	}

#paramId: 500895
#DUMMY_245
'DUMMY_245' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 245 ;
	}

#paramId: 500896
#DUMMY_246
'DUMMY_246' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 246 ;
	}

#paramId: 500897
#DUMMY_247
'DUMMY_247' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 247 ;
	}

#paramId: 500898
#DUMMY_248
'DUMMY_248' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 248 ;
	}

#paramId: 500899
#DUMMY_249
'DUMMY_249' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 249 ;
	}

#paramId: 500900
#DUMMY_250
'DUMMY_250' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 250 ;
	}

#paramId: 500901
#DUMMY_251
'DUMMY_251' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 251 ;
	}

#paramId: 500902
#DUMMY_252
'DUMMY_252' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 252 ;
	}

#paramId: 500903
#DUMMY_253
'DUMMY_253' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 253 ;
	}

#paramId: 500904
#DUMMY_254
'DUMMY_254' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 254 ;
	}

#paramId: 502332
#Liquid water content in snow - multi level
'WLIQ_SNOW_M' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 210 ;
	 typeOfFirstFixedSurface = 114 ;
	}

#paramId: 502339
#Downward direct short wave radiation flux at surface
'SWDIRS_RAD' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 198 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 502344
#Albedo - diffusive solar - time average (UV: 0.3 - 0.7 m-6)
'ALB_UV12' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 222 ;
	 typeOfStatisticalProcessing = 0 ;
	}

#paramId: 502345
#Albedo - diffusive solar (UV: 0.3 - 0.7 m-6)
'ALB_UV' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 222 ;
	}

#paramId: 502346
#Albedo - near infrared - time average (0.7 - 5.0 m-6)
'ALB_NI12' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 223 ;
	 typeOfStatisticalProcessing = 0 ;
	}

#paramId: 502347
#Albedo - near infrared (0.7 - 5.0 m-6)
'ALB_NI' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 223 ;
	}

#paramId: 502352
#Eddy Dissipation Rate Total Col-Max. Upper FIR
'EDP_MAX_UFIR' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 224 ;
	}

#paramId: 502353
#Eddy Dissipation Rate Total Col-Max. Lower UIR
'EDP_MAX_LUIR' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 225 ;
	}

#paramId: 502354
#Eddy Dissipation Rate Total Col-Max. Upper UIR
'EDP_MAX_UUIR' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 226 ;
	}

#paramId: 503049
#Eddy dissipitation rate of TKE
'EDR' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 227 ;
	}

#paramId: 503050
#Radar precipitation rate
'RAD_PRECIP' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 195 ;
	}

#paramId: 503052
#Radar quality information
'RAD_QUAL' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 196 ;
	}

#paramId: 503053
#Radar blacklist
'RAD_BL' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 197 ;
	}

#paramId: 503054
#Height of radar beam above ground
'RAD_HEIGHT' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 198 ;
	}

#paramId: 503055
#Specific humidity (diagnostic)
'QV_DIA' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 211 ;
	}

#paramId: 503056
#Specific cloud water content (diagnostic)
'QC_DIA' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 212 ;
	}

#paramId: 503057
#Specific cloud ice content (diagnostic)
'QI_DIA' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 213 ;
	}

#paramId: 503058
#Total column integrated water vapour (diagnostic)
'TQV_DIA' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 214 ;
	}

#paramId: 503059
#Total column integrated cloud water (diagnostic)
'TQC_DIA' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 215 ;
	}

#paramId: 503060
#Total column integrated cloud ice (diagnostic)
'TQI_DIA' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 216 ;
	}

#paramId: 503061
#Downward diffusive short wave radiation flux at surface (mean over forecast time)
'SWDIFDS_RAD' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 199 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503068
#precipitation, qualified,BRD
'RADAR_RQ' = {
	 discipline = 0 ;
	 parameterCategory = 16 ;
	 parameterNumber = 192 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 503069
#precipitation,BRD
'RADAR_RS' = {
	 discipline = 0 ;
	 parameterCategory = 16 ;
	 parameterNumber = 193 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 503070
#precipitation phase,BRD
'RADAR_RE' = {
	 discipline = 0 ;
	 parameterCategory = 16 ;
	 parameterNumber = 194 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 503071
#hail flag,BRD
'RADAR_RH' = {
	 discipline = 0 ;
	 parameterCategory = 16 ;
	 parameterNumber = 195 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 503072
#snow_rate,BRD
'RADAR_FS' = {
	 discipline = 0 ;
	 parameterCategory = 16 ;
	 parameterNumber = 196 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 503073
#snow_rate,qualified,BRD
'RADAR_FQ' = {
	 discipline = 0 ;
	 parameterCategory = 16 ;
	 parameterNumber = 197 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 503074
#Area weights for regular lon-lat grid
'AW' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 193 ;
	}

#paramId: 503078
#Relative humidity over mixed phase
'RH_MIX_EC' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 220 ;
	}

#paramId: 503079
#Soil moisture index (multilayers)
'SMI' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 200 ;
	 typeOfSecondFixedSurface = 106 ;
	 typeOfFirstFixedSurface = 106 ;
	}

#paramId: 503096
#Peak frequency (interpolated)
'PFRQ' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 201 ;
	}

#paramId: 503115
#Specific number concentration of rain
'NCRAIN' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 228 ;
	}

#paramId: 503116
#Number density of rain
'NDRAIN' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 229 ;
	}

#paramId: 503117
#Specific number concentration of snow
'NCSNOW' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 217 ;
	}

#paramId: 503118
#Specific number concentration of graupel
'NCGRAUPEL' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 218 ;
	}

#paramId: 503119
#Specific number concentration of hail
'NCHAIL' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 219 ;
	}

#paramId: 503120
#Number density of snow
'NDSNOW' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 221 ;
	}

#paramId: 503121
#Number density of graupel
'NDGRAUPEL' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 222 ;
	}

#paramId: 503122
#Number density of hail
'NDHAIL' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 223 ;
	}

#paramId: 503123
#Mass density of rain
'DENR' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 224 ;
	}

#paramId: 503124
#Mass density of snow
'DENS' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 225 ;
	}

#paramId: 503125
#Mass density of graupel
'DENG' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 226 ;
	}

#paramId: 503126
#Mass density of cloud droplets
'DENC' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 203 ;
	}

#paramId: 503127
#Mass density of cloud ice
'DENI' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 204 ;
	}

#paramId: 503128
#Mass density of hail
'DENH' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 227 ;
	}

#paramId: 503137
#Eddy Dissipation Rate Total Col-Max. Lower FIR
'EDP_MAX_LFIR' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 228 ;
	}

#paramId: 503142
#Lightning Potential Index
'LPI' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 192 ;
	}

#paramId: 503143
#Rain drain from snowpack - accumulation
'RD_SNOW' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 230 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 503146
#Height of -10 degree Celsius isotherm
'HMIN10CL' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 196 ;
	}

#paramId: 503147
# probability density function of EDP for turbulence  greater well defined threshold and model grid box
'EDPP' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 229 ;
	}

#paramId: 503148
#Adedokun 2 Index
'ADEDO2' = {
	 discipline = 215 ;
	 parameterCategory = 7 ;
	 parameterNumber = 0 ;
	}

#paramId: 503149
#Downward direct short wave radiation flux at surface on horizontal plane (time average)
'ASWDIR_SH' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 198 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 201 ;
	}

#paramId: 503150
#Gauss Boaga Coordinates West to East,East Sector
'BOAGAE_WE' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 194 ;
	}

#paramId: 503151
#Gauss Boaga Coordinates South to North,East Sector
'BOAGAE_SN' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 195 ;
	}

#paramId: 503152
#Gauss Boaga Coordinates West to East, West Sector
'BOAGAW_WE' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 196 ;
	}

#paramId: 503153
#Gauss Boaga Coordinates South to North, West Sector
'BOAGAW_SN' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 197 ;
	}

#paramId: 503156
#Ellrod and Knapp turbulence index1
'CAT_TI1' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 230 ;
	}

#paramId: 503157
#Ellrod and Knapp turbulence index2
'CAT_TI2' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 231 ;
	}

#paramId: 503158
#Deformation of horizontal wind field
'WDEF_H' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 29 ;
	}

#paramId: 503159
#Divergence trend (scaled divergence tendency needed for CAT_DVI)
'CAT_DVT' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 232 ;
	}

#paramId: 503160
#Divergence modified turbulence index (Ellrod and Knox)
'CAT_DTI' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 233 ;
	}

#paramId: 503161
#Cloud ice ratio qi/(qc+qi)
'CLI_RATIO' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 231 ;
	}

#paramId: 503162
#Percentage of convective precipitation (from total prec)
'CONV_PERCENT' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 232 ;
	}

#paramId: 503163
#Deep convection index
'DCI' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 194 ;
	 typeOfFirstFixedSurface = 10 ;
	}

#paramId: 503164
#Wind direction in azimuth class
'DDCLASS' = {
	 discipline = 215 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	}

#paramId: 503165
#Wind direction in azimuth class
'DDCLASS_10M' = {
	 discipline = 215 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	}

#paramId: 503167
#Possible astronomical maximum of sunshine
'DURSUN_M' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 205 ;
	 typeOfStatisticalProcessing = 11 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503168
#Relative duration of sunshine (DURSUN * 100 / DURSUN_M)
'DURSUN_R' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 206 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503171
#Enthalpy
'ENTH' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 195 ;
	}

#paramId: 503172
#2m Enthalpy
'ENTH_2M' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 195 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 503175
#Downward short wave radiation flux at surface on horizontal plane (time average)
'ASOD_SH' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 201 ;
	}

#paramId: 503176
#Downward short wave radiation flux at surface on vertical surface facing east (time average)
'ASOD_SvE' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 202 ;
	}

#paramId: 503177
#Downward short wave radiation flux at surface on vertical surface facing north (time average)
'ASOD_SvN' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 203 ;
	}

#paramId: 503178
#Downward short wave radiation flux at surface on vertical surface facing south (time average)
'ASOD_SvS' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 204 ;
	}

#paramId: 503179
#Downward short wave radiation flux at surface on vertical surface facing west (time average)
'ASOD_SvW' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 205 ;
	}

#paramId: 503180
#Along-wind Lagrangian time scale (Hanna)
'LAGTIMEU' = {
	 discipline = 215 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	}

#paramId: 503181
#Cross-wind Lagrangian time scale (Hanna)
'LAGTIMEV' = {
	 discipline = 215 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	}

#paramId: 503182
#Vertical Lagrangian time scale (Hanna)
'LAGTIMEW' = {
	 discipline = 215 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	}

#paramId: 503183
#Zonal Lagrangian time scale (direct) (Hanna)
'LAGTIMEX' = {
	 discipline = 215 ;
	 parameterCategory = 2 ;
	 parameterNumber = 4 ;
	}

#paramId: 503184
#Meridional Lagrangian time scale (direct) (Hanna)
'LAGTIMEY' = {
	 discipline = 215 ;
	 parameterCategory = 2 ;
	 parameterNumber = 5 ;
	}

#paramId: 503185
#Vertical Lagrangian time scale (direct) (Hanna)
'LAGTIMEZ' = {
	 discipline = 215 ;
	 parameterCategory = 2 ;
	 parameterNumber = 6 ;
	}

#paramId: 503187
#Height of level of free convection of mixed (mean) layer parcel
'LFC_ML' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	 typeOfSecondFixedSurface = 192 ;
	 typeOfFirstFixedSurface = 194 ;
	}

#paramId: 503188
#Luminosity
'LUM' = {
	 discipline = 215 ;
	 parameterCategory = 19 ;
	 parameterNumber = 0 ;
	}

#paramId: 503189
#Downward long-wave radiation flux at surface based on T_2M (time average)
'ATHD_S_T2M' = {
	 discipline = 215 ;
	 parameterCategory = 5 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503190
#Downward long-wave radiation flux at surface based on T_G (time average)
'ATHD_S_TG' = {
	 discipline = 215 ;
	 parameterCategory = 5 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503191
#Downward long-wave radiation flux at surface based on T_SO(0) (time average)
'ATHD_S_TS' = {
	 discipline = 215 ;
	 parameterCategory = 5 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503194
#Pressure difference between cloud base and cloud top
'PDIFF_CON' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 197 ;
	 typeOfSecondFixedSurface = 2 ;
	 typeOfFirstFixedSurface = 3 ;
	}

#paramId: 503198
#Along-wind velocity fluctuation (Hanna)
'SIGMAU' = {
	 discipline = 215 ;
	 parameterCategory = 2 ;
	 parameterNumber = 7 ;
	}

#paramId: 503199
#Cross-wind velocity fluctuation (Hanna)
'SIGMAV' = {
	 discipline = 215 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	}

#paramId: 503200
#Vertical velocity fluctuation (Hanna)
'SIGMAW' = {
	 discipline = 215 ;
	 parameterCategory = 2 ;
	 parameterNumber = 9 ;
	}

#paramId: 503201
#Zonal velocity fluctuation (Hanna)
'SIGMAX' = {
	 discipline = 215 ;
	 parameterCategory = 2 ;
	 parameterNumber = 10 ;
	}

#paramId: 503202
#Meridional velocity fluctuation (Hanna)
'SIGMAY' = {
	 discipline = 215 ;
	 parameterCategory = 2 ;
	 parameterNumber = 11 ;
	}

#paramId: 503203
#Vertical velocity fluctuation (Hanna)
'SIGMAZ' = {
	 discipline = 215 ;
	 parameterCategory = 2 ;
	 parameterNumber = 12 ;
	}

#paramId: 503205
#Percentage of precipitation in snow (from total prec.)
'SNOW_PERCENT' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 233 ;
	}

#paramId: 503206
#Thunderstorm index for Switzerland (night time)
'SWISS00' = {
	 discipline = 215 ;
	 parameterCategory = 7 ;
	 parameterNumber = 1 ;
	}

#paramId: 503207
#Thunderstorm index for Switzerland (day time)
'SWISS12' = {
	 discipline = 215 ;
	 parameterCategory = 7 ;
	 parameterNumber = 2 ;
	}

#paramId: 503208
#Swiss coordinate (south-north)
'SWISS_SN' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 198 ;
	}

#paramId: 503209
#Swiss coordinate (west-east)
'SWISS_WE' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 199 ;
	}

#paramId: 503217
#2m temperature, corrected in presence of snow
'T_2M_SNOWC' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 195 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 503218
#Universal thermal climate index without direct incident short wave radiation
'UTCI_SHADOW' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 194 ;
	}

#paramId: 503222
#Relative geostrophic vorticity
'RELV_G' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 26 ;
	}

#paramId: 503223
#Relative geostrophic vorticity advection
'RELV_ADV_G' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 27 ;
	}

#paramId: 503226
#Wind divergence (3D)
'WDIV_3D' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 28 ;
	}

#paramId: 503227
#Mean vertical wind shear for specified layer or layer-mean vertical wind shear
'WSHEAR_INT' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 201 ;
	}

#paramId: 503228
#Norm of (vertical) wind shear vector between two levels
'WSHEAR_DIFF' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 202 ;
	}

#paramId: 503282
#Diagnostic total column of activity concentration of radionuclides
'RADIONUC_AC_VI' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 192 ;
	 typeOfFirstFixedSurface = 10 ;
	}

#paramId: 503283
#Liquid water potential temperature variance
'THLTHLCOV' = {
	 discipline = 0 ;
	 parameterCategory = 198 ;
	 parameterNumber = 0 ;
	}

#paramId: 503284
#Total water specific humidity variance
'QTQTCOV' = {
	 discipline = 0 ;
	 parameterCategory = 198 ;
	 parameterNumber = 1 ;
	}

#paramId: 503285
#Liquid water potential temperature - total water specific humidity covariance
'THLQTCOV' = {
	 discipline = 0 ;
	 parameterCategory = 198 ;
	 parameterNumber = 2 ;
	}

#paramId: 503286
#Impervious (paved or sealed) surface fraction
'FR_PAVED' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 196 ;
	}

#paramId: 503287
#Antropogenic heat flux (e.g. urban heating, traffic)
'AHF' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 197 ;
	}

#paramId: 503292
#Sea ice albedo - diffusive solar (0.3 - 5.0 m-6)
'ALB_SEAICE' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 234 ;
	}

#paramId: 503299
#Sky-view-factor
'SKYVIEW' = {
	 discipline = 0 ;
	 parameterCategory = 199 ;
	 parameterNumber = 0 ;
	}

#paramId: 503300
#Horizon angle - topography
'HORIZON' = {
	 discipline = 0 ;
	 parameterCategory = 199 ;
	 parameterNumber = 1 ;
	}

#paramId: 503301
#Slope aspect - topography
'SLO_ASP' = {
	 discipline = 0 ;
	 parameterCategory = 199 ;
	 parameterNumber = 3 ;
	}

#paramId: 503302
#Slope angle - topography
'SLO_ANG' = {
	 discipline = 0 ;
	 parameterCategory = 199 ;
	 parameterNumber = 2 ;
	}

#paramId: 503339
#Threshold friction velocity
'USTAR_THRES' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 203 ;
	}

#paramId: 503342
#Maximum rotation amplitude (positive or negative) (over given time interval and column)
'VORW_CTMAX' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 206 ;
	 typeOfStatisticalProcessing = 2 ;
	}

#paramId: 503343
#Maximum updraft track (over given time interval and column)
'W_CTMAX' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 207 ;
	 typeOfStatisticalProcessing = 2 ;
	}

#paramId: 503348
#Maximum of Lightning Potential Index (over given time interval)
'LPI_MAX' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 192 ;
	 typeOfStatisticalProcessing = 2 ;
	}

#paramId: 503351
#mean radiation temperature of an environment assumed black body related to standing human
'T_MRT' = {
	 discipline = 0 ;
	 parameterCategory = 192 ;
	 parameterNumber = 4 ;
	}

#paramId: 503355
#Maximum 10m dynamical gust
'VGUST_DYN_10M' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 204 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	}

#paramId: 503356
#Maximum 10m convective gust
'VGUST_CON_10M' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 205 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	}

#paramId: 503358
#Standard deviation of saturation deficit
'RCLD' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 234 ;
	}

#paramId: 503359
#Evaporation of plants (integrated since "nightly reset")
'EVAP_PL' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 198 ;
	}

#paramId: 503363
#Number of birch (betula) pollen in the reservoir (previous timestep)
'BETUreso' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 192 ;
	 constituentType = 62101 ;
	}

#paramId: 503364
#Number of birch (betula) pollen released into the reservoir (new)
'BETUresn' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 193 ;
	 constituentType = 62101 ;
	}

#paramId: 503365
#Sum of released birch (betula) pollen into the reservoir (daily sum)
'BETUress' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 193 ;
	 typeOfStatisticalProcessing = 11 ;
	 constituentType = 62101 ;
	}

#paramId: 503366
#State of the birch (betula) season (eq.zero before and after season, the higher, the more plants are flowering)
'BETUsdes' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 194 ;
	 constituentType = 62101 ;
	}

#paramId: 503367
#Height correction for emission (decreasing emission with height) for birch (betula)
'BETUhcem' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 195 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62101 ;
	}

#paramId: 503369
#Cumulated weighted 2m temperature sum of daily values for birch (betula) pollen
'BETUctsum' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 196 ;
	 constituentType = 62101 ;
	}

#paramId: 503370
#Cumulated 2m temperature sum threshold for the start of birch (betula) pollen season (climatological)
'BETUtthrs' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 197 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62101 ;
	}

#paramId: 503371
#Cumulated 2m temperature sum threshold for the end of birch (betula) pollen season (climatological)
'BETUtthre' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 198 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62101 ;
	}

#paramId: 503372
#Number of days since the start of birch (betula) pollen season (if present day is outside the season: length of current season)
'BETUsaisa' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 200 ;
	 constituentType = 62101 ;
	}

#paramId: 503373
#Length of birch (betula) pollen season
'BETUsaisl' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 201 ;
	 constituentType = 62101 ;
	}

#paramId: 503374
#Pollen number emission flux for birch (betula)
'BETUfe' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 202 ;
	 constituentType = 62101 ;
	}

#paramId: 503377
#Number of alder (alnus) pollen in the reservoir (previous timestep)
'ALNUreso' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 192 ;
	 constituentType = 62100 ;
	}

#paramId: 503378
#Number of alder (alnus) pollen released into the reservoir (new)
'ALNUresn' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 193 ;
	 constituentType = 62100 ;
	}

#paramId: 503379
#Sum of released alder (alnus) pollen into the reservoir (daily sum)
'ALNUress' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 193 ;
	 typeOfStatisticalProcessing = 11 ;
	 constituentType = 62100 ;
	}

#paramId: 503380
#State of the alder (alnus) season (eq.zero before and after season, the higher, the more plants are flowering)
'ALNUsdes' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 194 ;
	 constituentType = 62100 ;
	}

#paramId: 503381
#Height correction for emission (decreasing emission with height) for alder (alnus)
'ALNUhcem' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 195 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62100 ;
	}

#paramId: 503383
#Cumulated weighted 2m temperature sum of daily values for alder (alnus) pollen
'ALNUctsum' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 196 ;
	 constituentType = 62100 ;
	}

#paramId: 503384
#Cumulated 2m temperature sum threshold for the start of  alder (alnus) pollen season (climatological)
'ALNUtthrs' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 197 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62100 ;
	}

#paramId: 503385
#Cumulated 2m temperature sum threshold for the end of  alder (alnus) pollen season (climatological)
'ALNUtthre' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 198 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62100 ;
	}

#paramId: 503386
#Number of days since the start of alder (alnus) pollen season (if present day is in the season: zero outside season)
'ALNUsaisn' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 199 ;
	 constituentType = 62100 ;
	}

#paramId: 503387
#Number of days since the start of alder (alnus) pollen season (if present day is outside the season: length of current season)
'ALNUsaisa' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 200 ;
	 constituentType = 62100 ;
	}

#paramId: 503388
#Length of alder (alnus) pollen season
'ALNUsaisl' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 201 ;
	 constituentType = 62100 ;
	}

#paramId: 503389
#Pollen number emission flux for alder (alnus)
'ALNUfe' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 202 ;
	 constituentType = 62100 ;
	}

#paramId: 503392
#Number of grasses (poaceae) pollen in the reservoir (previous timestep)
'POACreso' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 192 ;
	 constituentType = 62300 ;
	}

#paramId: 503393
#Number of grasses (poaceae) pollen released into the reservoir (new)
'POACresn' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 193 ;
	 constituentType = 62300 ;
	}

#paramId: 503394
#Sum of released grasses (poaceae) pollen into the reservoir (daily sum)
'POACress' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 193 ;
	 typeOfStatisticalProcessing = 11 ;
	 constituentType = 62300 ;
	}

#paramId: 503395
#State of the grasses (poaceae) season (eq.zero before and after season, the higher, the more plants are flowering)
'POACsdes' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 194 ;
	 constituentType = 62300 ;
	}

#paramId: 503396
#Height correction for emission (decreasing emission with height) for grasses (poaceae)
'POAChcem' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 195 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62300 ;
	}

#paramId: 503398
#Cumulated weighted 2m temperature sum of daily values for grasses (poaceae) pollen
'POACctsum' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 196 ;
	 constituentType = 62300 ;
	}

#paramId: 503399
#Cumulated 2m temperature sum threshold for the start of  grasses (poaceae) pollen season (climatological)
'POACtthrs' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 197 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62300 ;
	}

#paramId: 503400
#Cumulated 2m temperature sum threshold for the end of  grasses (poaceae) pollen season (climatological)
'POACtthre' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 198 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62300 ;
	}

#paramId: 503401
#Number of days since the start of grasses (poaceae) pollen season (if present day is in the season: zero outside season)
'POACsaisn' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 199 ;
	 constituentType = 62300 ;
	}

#paramId: 503402
#Number of days since the start of grasses (poaceae) pollen season (if present day is outside the season: length of current season)
'POACsaisa' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 200 ;
	 constituentType = 62300 ;
	}

#paramId: 503403
#Length of grasses (poaceae) pollen season
'POACsaisl' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 201 ;
	 constituentType = 62300 ;
	}

#paramId: 503404
#Pollen number emission flux for grasses (poaceae)
'POACfe' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 202 ;
	 constituentType = 62300 ;
	}

#paramId: 503407
#Number of ragweed  (ambrosia) pollen in the reservoir (previous timestep)
'AMBRreso' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 192 ;
	 constituentType = 62200 ;
	}

#paramId: 503408
#Number of ragweed  (ambrosia) pollen released into the reservoir (new)
'AMBRresn' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 193 ;
	 constituentType = 62200 ;
	}

#paramId: 503409
#Sum of released ragweed  (ambrosia) pollen into the reservoir (daily sum)
'AMBRress' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 193 ;
	 typeOfStatisticalProcessing = 11 ;
	 constituentType = 62200 ;
	}

#paramId: 503410
#State of the ragweed  (ambrosia) season (eq.zero before and after season, the higher, the more plants are flowering)
'AMBRsdes' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 194 ;
	 constituentType = 62200 ;
	}

#paramId: 503411
#Height correction for emission (decreasing emission with height) for ragweed  (ambrosia)
'AMBRhcem' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 195 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62200 ;
	}

#paramId: 503413
#Cumulated weighted 2m temperature sum of daily values for ragweed  (ambrosia) pollen
'AMBRctsum' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 196 ;
	 constituentType = 62200 ;
	}

#paramId: 503414
#Cumulated 2m temperature sum threshold for the start of  ragweed  (ambrosia) pollen season (climatological)
'AMBRtthrs' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 197 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62200 ;
	}

#paramId: 503415
#Cumulated 2m temperature sum threshold for the end of  ragweed  (ambrosia) pollen season (climatological)
'AMBRtthre' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 198 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62200 ;
	}

#paramId: 503416
#Number of days since the start of ragweed  (ambrosia) pollen season (if present day is in the season: zero outside season)
'AMBRsaisn' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 199 ;
	 constituentType = 62200 ;
	}

#paramId: 503417
#Number of days since the start of ragweed  (ambrosia) pollen season (if present day is outside the season: length of current season)
'AMBRsaisa' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 200 ;
	 constituentType = 62200 ;
	}

#paramId: 503418
#Length of ragweed  (ambrosia) pollen season
'AMBRsaisl' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 201 ;
	 constituentType = 62200 ;
	}

#paramId: 503419
#Pollen number emission flux for ragweed  (ambrosia)
'AMBRfe' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 202 ;
	 constituentType = 62200 ;
	}

#paramId: 503420
#Number of days since the start of birch (betula) pollen season (if present day is in the season: zero outside season)
'BETUsaisn' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 199 ;
	 constituentType = 62101 ;
	}

#paramId: 503424
#Random pattern for  the stochastically perturbed parametrization tendencies (SPPT) scheme at levels without tapering. If multi-scale random patterns are used, RAPA_SPPT is the sum of those.
'RAPA_SPPT' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 235 ;
	}

#paramId: 503425
#Skin conductivity (ratio ground heat flux to temperature difference soil-skin layer)
'SKC' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 199 ;
	}

#paramId: 503426
#Maximum snow height during contiguous accumulating snow period (coupled with snow age)
'HSNOW_MAX' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 235 ;
	}

#paramId: 503427
#U-component of (vertical) wind shear vector between two levels
'WSHEAR_U' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 208 ;
	}

#paramId: 503428
#V-component of (vertical) wind shear vector between two levels
'WSHEAR_V' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 209 ;
	}

#paramId: 503440
#Accumulated wet deposition of dust if rain reaches the surface for mode 1
'ACCWETDEPO_RAIN_DUSTA' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 203 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503441
#Accumulated wet deposition of dust if rain reaches the surface for mode 2
'ACCWETDEPO_RAIN_DUSTB' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 203 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503442
#Accumulated wet deposition of dust if rain reaches the surface for mode 3
'ACCWETDEPO_RAIN_DUSTC' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 203 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503446
#Accumulated dry deposition of dust number concentration for mode 1
'ACCDRYDEPO_DUSTA0' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 204 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503447
#Accumulated dry deposition of dust number concentration for mode 2
'ACCDRYDEPO_DUSTB0' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 204 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503448
#Accumulated dry deposition of dust number concentration for mode 3
'ACCDRYDEPO_DUSTC0' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 204 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503449
#Accumulated wet deposition by grid scale precipitation of dust number concentration for mode 1
'ACCWETDEPO_GSP_DUSTA0' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 205 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503450
#Accumulated wet deposition by grid scale precipitation of dust number concentration for mode 2
'ACCWETDEPO_GSP_DUSTB0' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 205 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503451
#Accumulated wet deposition by grid scale precipitation of dust number concentration for mode 3
'ACCWETDEPO_GSP_DUSTC0' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 205 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503452
#Accumulated wet deposition of dust number concentration  if rain reaches the surface for mode 1
'ACCWETDEPO_RAIN_DUSTA0' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 207 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503453
#Accumulated wet deposition of dust number concentration  if rain reaches the surface for mode 2
'ACCWETDEPO_RAIN_DUSTB0' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 207 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503454
#Accumulated wet deposition of dust number concentration  if rain reaches the surface for mode 3
'ACCWETDEPO_RAIN_DUSTC0' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 207 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503455
#Accumulated sedimentation of dust number concentration for mode 1
'ACCSEDIM_DUSTA0' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 208 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503456
#Accumulated sedimentation of dust number concentration for mode 2
'ACCSEDIM_DUSTB0' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 208 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503457
#Accumulated sedimentation of dust number concentration for mode 3
'ACCSEDIM_DUSTC0' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 208 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503460
#Mineral dust backscatter (not attenuated, for given wave length)
'BSC_DUST' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 209 ;
	 aerosolType = 62001 ;
	}

#paramId: 503463
#Volcanic ash backscatter (not attenuated, for given wave length)
'BSC_ASH' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 209 ;
	 aerosolType = 62025 ;
	}

#paramId: 503464
#Accumulated wet deposition by convective precipitation of dust number concentration for mode 3
'ACCWETDEPO_CON_DUSTC0' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 206 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503465
#Accumulated wet deposition by convective precipitation of dust number concentration for mode 2
'ACCWETDEPO_CON_DUSTB0' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 206 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503466
#Accumulated wet deposition by convective precipitation of dust number concentration for mode 1
'ACCWETDEPO_CON_DUSTA0' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 206 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503549
#Swiss coordinate LV 95 (south-north)
'SWISS_LV95_SN' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 200 ;
	}

#paramId: 503550
#Swiss coordinate LV 95 (west-east)
'SWISS_LV95_WE' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 201 ;
	}

#paramId: 503555
#Average hail diameter
'DHAIL_AV' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 238 ;
	 typeOfStatisticalProcessing = 0 ;
	}

#paramId: 503556
#Standard deviation of hail diameter
'DHAIL_SD' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 238 ;
	 typeOfStatisticalProcessing = 6 ;
	}

#paramId: 503557
#Maximum hail diameter
'DHAIL_MX' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 238 ;
	 typeOfStatisticalProcessing = 2 ;
	}

#paramId: 503558
#Duration of updraft
'W_UP_DUR' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 210 ;
	}

#paramId: 503559
#Updraft mask
'W_UP_MASK' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 211 ;
	}

#paramId: 503582
#Frequency of winds in defined wind sector for defined time interval
'DD_10M_SECFREQ' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 11 ;
	 typeOfSecondFixedSurface = 233 ;
	 typeOfFirstFixedSurface = 233 ;
	}

#paramId: 503585
#10m wind speed in wind sector (time average)
'SP_10M_SECAV' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfSecondFixedSurface = 233 ;
	 typeOfFirstFixedSurface = 233 ;
	}

#paramId: 503586
#10m wind speed in wind sector (time maximum)
'SP_10M_SECMAX' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfSecondFixedSurface = 233 ;
	 typeOfFirstFixedSurface = 233 ;
	}

#paramId: 503588
#Downward direct short-wave radiation flux at surface on a plane normal to the sun (time average)
'ASWDIR_SN' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 198 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 206 ;
	}

#paramId: 503589
#Downward direct short-wave radiation flux at surface on a plane normal to the sun without orographic shading (time average)
'ASWDIR_SNO' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 198 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 207 ;
	}

#paramId: 503590
#Solar elevation angle
'SUN_EL' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 202 ;
	}

#paramId: 503591
#Solar azimuth angle
'SUN_AZI' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 203 ;
	}

#paramId: 503592
#Turbulence intensity (time maximum)
'TURB_INTENS_MAX' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 236 ;
	 typeOfStatisticalProcessing = 2 ;
	}

#paramId: 503603
#Soil water mass flux at layer interfaces (sum of conductive and diffusive fluxes)
'WSOIL_FLX' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 201 ;
	 typeOfFirstFixedSurface = 106 ;
	}

#paramId: 503604
#Ground water runoff rate, aquifer
'Q_ROFF' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 195 ;
	 typeOfSecondFixedSurface = 106 ;
	 typeOfFirstFixedSurface = 106 ;
	}

#paramId: 503605
#Water table depth
'WT_DEPTH' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 193 ;
	 typeOfFirstFixedSurface = 177 ;
	}

#paramId: 503606
#Soil moisture saturation level
'W_SO_SL' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 194 ;
	 typeOfFirstFixedSurface = 177 ;
	}

#paramId: 503607
#Slope of orography (using average of maximum gradient in different directions)
'S_ORO_MAX' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 198 ;
	}

#paramId: 503608
#Total column zonal water flux
'TWATFLXU' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 236 ;
	 typeOfFirstFixedSurface = 10 ;
	}

#paramId: 503609
#Total column meridional water flux
'TWATFLXV' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 237 ;
	 typeOfFirstFixedSurface = 10 ;
	}

#paramId: 503610
#Total column zonal water flux - time average
'ATWATFLXU' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 236 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 10 ;
	}

#paramId: 503611
#Total column meridional water flux - time average
'ATWATFLXV' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 237 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 10 ;
	}

#paramId: 503612
#Number of active clouds per horizontal unit area
'NCL_PUA_ACT' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 210 ;
	 typeOfFirstFixedSurface = 2 ;
	}

#paramId: 503613
#Number of passive clouds per horizontal unit area
'NCL_PUA_PSV' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 211 ;
	 typeOfFirstFixedSurface = 2 ;
	}

#paramId: 503614
#Cloud base mass flux associated with active clouds
'CBMFLX_ACT' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 200 ;
	 typeOfFirstFixedSurface = 2 ;
	}

#paramId: 503615
#Cloud base mass flux associated with passive clouds
'CBMFLX_PSV' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 199 ;
	 typeOfFirstFixedSurface = 2 ;
	}

#paramId: 503619
#Single scan reflectivity - observation
'DBZSCAN_OBS' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 200 ;
	 typeOfGeneratingProcess = 8 ;
	}

#paramId: 503620
#Single scan reflectivity - simulation
'DBZSCAN_SIM' = {
	 discipline = 0 ;
	 parameterCategory = 16 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 198 ;
	}

#paramId: 503622
#Lightning Potential Index from convection scheme, modified by convection index
'LPI_CON_CI' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 193 ;
	}

#paramId: 503623
#Maximum Lightning Potential Index from convection scheme, modified by convection index
'LPI_CON_CI_MAX' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 193 ;
	 typeOfStatisticalProcessing = 2 ;
	}

#paramId: 503625
#Mass median diameter of dust for mode 1
'MMD_DUSTA' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 220 ;
	 constituentType = 62001 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503626
#Mass median diameter of dust for mode 2
'MMD_DUSTB' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 220 ;
	 constituentType = 62001 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503627
#Mass median diameter of dust for mode 3
'MMD_DUSTC' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 220 ;
	 constituentType = 62001 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503638
#Number of hazel (corylus) pollen in the reservoir (previous timestep)
'CORYreso' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 192 ;
	 constituentType = 62104 ;
	}

#paramId: 503639
#Number of hazel (corylus) pollen released into the reservoir (new)
'CORYresn' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 193 ;
	 constituentType = 62104 ;
	}

#paramId: 503640
#State of the hazel (corylus) season (eq.zero before and after season, the higher, the more plants are flowering)
'CORYsdes' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 194 ;
	 constituentType = 62104 ;
	}

#paramId: 503641
#Height correction for emission (decreasing emission with height) for hazel (corylus)
'CORYhcem' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 195 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62104 ;
	}

#paramId: 503642
#Sum of released hazel (corylus) pollen into the reservoir (daily sum)
'CORYress' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 193 ;
	 typeOfStatisticalProcessing = 11 ;
	 constituentType = 62104 ;
	}

#paramId: 503644
#Cumulated weighted 2m temperature sum of daily values for hazel (corylus) pollen
'CORYctsum' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 196 ;
	 constituentType = 62104 ;
	}

#paramId: 503645
#Cumulated 2m temperature sum threshold for the start of hazel (corylus) pollen season (climatological)
'CORYtthrs' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 197 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62104 ;
	}

#paramId: 503646
#Cumulated 2m temperature sum threshold for the end of hazel (corylus) pollen season (climatological)
'CORYtthre' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 198 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62104 ;
	}

#paramId: 503647
#Number of days since the start of hazel (corylus) pollen season (if present day is in the season: zero outside season)
'CORYsaisn' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 199 ;
	 constituentType = 62104 ;
	}

#paramId: 503648
#Length of hazel (corylus) pollen season
'CORYsaisl' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 201 ;
	 constituentType = 62104 ;
	}

#paramId: 503649
#Pollen number emission flux for hazel (corylus)
'CORYfe' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 202 ;
	 constituentType = 62104 ;
	}

#paramId: 503650
#Number of days since the start of hazel (corylus) pollen season (if present day is outside the season: length of current season)
'CORYsaisa' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 200 ;
	 constituentType = 62104 ;
	}

#paramId: 503652
#Emission tuning factor for birch (betula) pollen
'BETUtune' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 211 ;
	 constituentType = 62101 ;
	}

#paramId: 503653
#Emission tuning factor for alder (alnus) pollen
'ALNUtune' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 211 ;
	 constituentType = 62100 ;
	}

#paramId: 503654
#Emission tuning factor for grasses (poaceae) pollen
'POACtune' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 211 ;
	 constituentType = 62300 ;
	}

#paramId: 503655
#Emission tuning factor for ragweed (ambrosia) pollen
'AMBRtune' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 211 ;
	 constituentType = 62200 ;
	}

#paramId: 503656
#Emission tuning factor for hazel (corylus) pollen
'CORYtune' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 211 ;
	 constituentType = 62104 ;
	}

#paramId: 503658
#Height of new snow (without settling)
'H_NEWSNOW_M' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 207 ;
	}

#paramId: 503659
#Volumetric ice content of snow layer - multi level
'ICEinSNW_VC_M' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 210 ;
	 typeOfSecondFixedSurface = 114 ;
	 typeOfFirstFixedSurface = 114 ;
	 constituentType = 63000 ;
	}

#paramId: 503660
#Volumetric water content of snow layer - multi level
'H2OinSNW_VC_M' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 210 ;
	 typeOfSecondFixedSurface = 114 ;
	 typeOfFirstFixedSurface = 114 ;
	 constituentType = 62002 ;
	}

#paramId: 503661
#Volumetric air content of snow layer - multi level
'AIRinSNW_VC_M' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 210 ;
	 typeOfSecondFixedSurface = 114 ;
	 typeOfFirstFixedSurface = 114 ;
	 constituentType = 63001 ;
	}

#paramId: 503663
#Number of snow layer - multi level
'N_SNOW_M' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 206 ;
	}

#paramId: 503665
#Building area fraction (proportion: 0=no building, 1=whole urban area)
'URB_FR_BLD' = {
	 discipline = 2 ;
	 parameterCategory = 192 ;
	 parameterNumber = 0 ;
	}

#paramId: 503666
#Street canyon aspect (height - width) ratio
'URB_H2W' = {
	 discipline = 2 ;
	 parameterCategory = 192 ;
	 parameterNumber = 1 ;
	}

#paramId: 503667
#Height of building
'URB_H_BLD' = {
	 discipline = 2 ;
	 parameterCategory = 192 ;
	 parameterNumber = 2 ;
	}

#paramId: 503668
#Urban material thermal albedo
'URB_ALB_TH' = {
	 discipline = 2 ;
	 parameterCategory = 192 ;
	 parameterNumber = 3 ;
	}

#paramId: 503669
#Urban material shortwave (solar) albedo
'URB_ALB_SO' = {
	 discipline = 2 ;
	 parameterCategory = 192 ;
	 parameterNumber = 4 ;
	}

#paramId: 503670
#Volumetric heat capacity of urban material (capacity x density)
'URB_HCAP' = {
	 discipline = 2 ;
	 parameterCategory = 192 ;
	 parameterNumber = 5 ;
	}

#paramId: 503671
#Heat conductivity of urban material
'URB_HCON' = {
	 discipline = 2 ;
	 parameterCategory = 192 ;
	 parameterNumber = 6 ;
	}

#paramId: 503704
#Potential flight distance PFD (gliding)
'POT_FLT_DIST' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 240 ;
	}

#paramId: 503705
#Lifting ratio VST (gliding)
'LIFT_RATIO' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 241 ;
	}

#paramId: 503710
#U-component of mean wind (vertical mean over specified layer)
'U_MEAN' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 212 ;
	}

#paramId: 503711
#V-component of mean wind (vertical mean over specified layer)
'V_MEAN' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 213 ;
	}

#paramId: 503712
#Extreme weather index of snow amount, grid-scale plus convective
'TOT_SNOW_EWI' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 240 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 503713
#Extreme weather index of maximum Wind 10m
'VMAX_10M_EWI' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 214 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	}

#paramId: 503714
#Extreme weather index of total precipitation (Accumulation)
'TOT_PREC_EWI' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 239 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 503715
#Cloud cover for use in radiative transfer (modified where large hydrometeors are present)
'CLC_RAD' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 215 ;
	}

#paramId: 503716
#Snow temperature at node (i.e. at snow layer interface or boundary) - multi level
'TofSNW_NODE_M' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 208 ;
	 typeOfFirstFixedSurface = 114 ;
	}

#paramId: 503717
#Volumetric ice content of snow layer (for use in tile approach) - multi level
'ICEinSNW_VC_T_M' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 209 ;
	 typeOfSecondFixedSurface = 114 ;
	 typeOfFirstFixedSurface = 114 ;
	}

#paramId: 503718
#Volumetric water content of snow layer (for use in tile approach) - multi level
'H2OinSNW_VC_T_M' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 210 ;
	 typeOfSecondFixedSurface = 114 ;
	 typeOfFirstFixedSurface = 114 ;
	}

#paramId: 503719
#Volumetric air content of snow layer (for use in tile approach) - multi level
'AIRinSNW_VC_T_M' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 211 ;
	 typeOfSecondFixedSurface = 114 ;
	 typeOfFirstFixedSurface = 114 ;
	}

#paramId: 503720
#Probability for freezing precipitation/wet snow
'FP' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 242 ;
	}

#paramId: 503721
#Probability for freezing precipitation with wind
'FPW' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 243 ;
	}

#paramId: 503732
#NowCastMIX-AutoWARN (Warnpolygone: Gewitter, Starkregen, Schnee, gefrierender Regen)
'NCM_AW_WP' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 220 ;
	}

#paramId: 503733
#NowCastMIX-AutoWARN (Schneepolygon-Attribute)
'NCM_AW_SPA' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 221 ;
	}

#paramId: 503734
#NowCastMIX-Aviation (Konvektiver Status, Radolan-Gebiet)
'NCM_A_RADOLAN' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 222 ;
	}

#paramId: 503735
#NowCastMIX-Aviation (Konvektiver Status, EuCOM-Gebiet)
'NCM_A_EUCOM' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 223 ;
	}

#paramId: 503736
#NowCastMIX-Winterwetter (Schnee, gefrierender Regen, Radolan-Gebiet)
'NCM_A_WINTER_W' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 224 ;
	}

#paramId: 503740
#NowCastMIX-AutoWARN (Gewitter-Warnkeulen mit variablen L??ngen)
'NCM_AW_WKVL' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 225 ;
	}

#paramId: 503741
#NowCastMIX-Aviation (Starkregen, Radolan-Gebiet)
'NCM_A_STARKREGEN' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 226 ;
	}

#paramId: 503742
#NowCastMIX-AutoWARN (Schneefallgrenze)
'NCM_AW_SFG' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 227 ;
	}

#paramId: 503745
#Net short wave radiation flux at surface on horizontal plane including orographic shading
'SOBS_RAD_OS' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 208 ;
	}

#paramId: 503746
#Net short wave radiation flux at surface on tangent plane to terrain including orographic shading
'SOBS_RAD_TAN_OS' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 209 ;
	}

#paramId: 503747
#Upward diffusive short wave radiation flux at surface on horizontal plane including orographic shading
'SWDIFUS_RAD_OS' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 208 ;
	}

#paramId: 503748
#Upward diffusive short wave radiation flux at surface on tangent plane to terrain including orographic shading
'SWDIFUS_RAD_TAN_OS' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 209 ;
	}

#paramId: 503749
#Photosynthetically active radiation at surface on tangent plane to terrain including orographic shading
'PABS_RAD_TAN_OS' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 209 ;
	}

#paramId: 503750
#Net short wave radiation flux at surface on horizontal plane including orographic shading - time average
'ASOB_S_OS' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 208 ;
	}

#paramId: 503751
#Net short wave radiation flux at surface on tangent plane to terrain including orographic shading - time average
'ASOB_S_TAN_OS' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 209 ;
	}

#paramId: 503752
#Downward direct short wave radiation flux at surface on horizontal plane including orographic shading - time average
'ASWDIR_S_OS' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 198 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 208 ;
	}

#paramId: 503753
#Downward direct short wave radiation flux at surface on tangent plane to terrain including orographic shading - time average
'ASWDIR_S_TAN_OS' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 198 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 209 ;
	}

#paramId: 503754
#Downward short wave radiation flux at surface on horizontal plane including orographic shading - time average
'ASOD_S_OS' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 208 ;
	}

#paramId: 503755
#Downward short wave radiation flux at surface on tangent plane to terrain including orographic shading - time average
'ASOD_S_TAN_OS' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 209 ;
	}

#paramId: 503756
#Upward diffusive short wave radiation flux at surface on horizontal plane including orographic shading - time average
'ASWDIFU_S_OS' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 208 ;
	}

#paramId: 503757
#Upward diffusive short wave radiation flux at surface on tangent plane to terrain including orographic shading - time average
'ASWDIFU_S_TAN_OS' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 209 ;
	}

#paramId: 503758
#Photosynthetically active radiation at surface on tangent plane to terrain including orographic shading - time average
'APAB_S_TAN_OS' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 209 ;
	}

#paramId: 503761
#Snow depth over sea ice (total depth)
'H_SNOW_SEAICE' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 192 ;
	}

#paramId: 503762
#Stretching factor of rescaled height coordinate zstar - ocean modelling
'HSTRF_SEA' = {
	 discipline = 10 ;
	 parameterCategory = 192 ;
	 parameterNumber = 20 ;
	}

#paramId: 503765
#Temperature in lowest model layer - time-filtered assimilation increment, daytime weighting
'T_LML_DTWGT_FILTINC' = {
	 discipline = 0 ;
	 parameterCategory = 210 ;
	 parameterNumber = 0 ;
	 typeOfSecondFixedSurface = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 typeOfGeneratingProcess = 207 ;
	}

#paramId: 503766
#Relative Humidity in lowest model layer - time-filtered assimilation increment, daytime weighting
'RELHUM_LML_DTWGT_FILTINC' = {
	 discipline = 0 ;
	 parameterCategory = 210 ;
	 parameterNumber = 1 ;
	 typeOfSecondFixedSurface = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 typeOfGeneratingProcess = 207 ;
	}

